/* regsI86.h - I80x86 registers */

/* Copyright 1984-1993 Wind River Systems, Inc. */

/*
modification history
--------------------
01h,16apr98,hdn  added support for Pentium, PentiumPro.
01g,30dec97,dbt  added common names for registers
01f,21sep95,hdn  added X86CPU_NS486.
01e,01nov94,hdn  added X86CPU_386, X86CPU_486, X86CPU_PENTIUM.
01d,27oct94,hdn  added CR0_CD_NOT and CR0_NW_NOT.
01c,08jun93,hdn  added support for c++. updated to 5.1.
01b,26mar93,hdn  added some defines for 486.
01a,28feb92,hdn  written based on TRON, 68k version.
*/

#ifndef	__INCregsI86h
#define	__INCregsI86h

#ifdef __cplusplus
extern "C" {
#endif

#ifndef	_ASMLANGUAGE

#define GREG_NUM	8	/* has 8 32-bit general registers */

typedef struct			/* REG_SET - 80x86 register set */
    {
    ULONG edi;			/* general register */
    ULONG esi;			/* general register */
    ULONG ebp;			/* frame pointer register */
    ULONG esp;			/* stack pointer register */
    ULONG ebx;			/* general register */
    ULONG edx;			/* general register */
    ULONG ecx;			/* general register */
    ULONG eax;			/* general register */
    ULONG eflags;		/* status register (must be second to last) */
    INSTR *pc;			/* program counter (must be last) */
    } REG_SET;

typedef struct			/* CPUID - 80x86 cpuid version/feature */
    {
    int version;		/* version information */
    int feature;		/* feature information */
    int vendor[3];		/* vendor identification string */
    } CPUID;

typedef struct mtrr_fix		/* MTRR - fixed range register */
    {
    char type[8];
    } MTRR_FIX;

typedef struct mtrr_var		/* MTRR - variable range register */
    {
    long long int base;
    long long int mask;
    } MTRR_VAR;

typedef struct mtrr		/* MTRR */
    {
    int cap[2];			/* MTRR cap register */
    int deftype[2];		/* MTRR defType register */
    MTRR_FIX fix[11];		/* MTRR fixed range registers */
    MTRR_VAR var[8];		/* MTRR variable range registers */
    } MTRR;

/* some common names for registers */

#define fpReg		ebp	/* frame pointer */
#define	spReg		esp	/* stack pointer */
#define reg_pc		pc	/* program counter */
#define reg_sp		spReg	/* stack pointer */
#define reg_fp		fpReg	/* frame pointer */

#define  G_REG_BASE	0x00	/* data reg's base offset to REG_SET */
#define  G_REG_OFFSET(n)	(G_REG_BASE + (n)*sizeof(ULONG))
#define  SR_OFFSET		G_REG_OFFSET(GREG_NUM)
#define  PC_OFFSET		(SR_OFFSET + sizeof(ULONG))
#endif	/* _ASMLANGUAGE */


#define X86CPU_386	0	/* CPU: 80386 */
#define X86CPU_486	1	/* CPU: 80486 */
#define X86CPU_PENTIUM	2	/* CPU: Pentium */
#define X86CPU_NS486	3	/* CPU: NS486 */
#define X86CPU_PENTIUMPRO 4	/* CPU: Pentiumpro */
#define X86FPU_387	1	/* FPU: 80387 */
#define X86FPU_487	2	/* FPU: 80487 */

#define	EFLAGS_BRANDNEW	0x200	/* brand new EFLAGS */
#define	CODE_SELECTOR	0x0008	/* brand new code selector */

/* control and test registers */

#define CR0		1
#define CR1		2
#define CR2		3
#define CR3		4
#define TR3		5
#define TR4		6
#define TR5		7
#define TR6		8
#define TR7		9

/* bits on CR0 */

#define CR0_PE		0x00000001	/* protection enable */
#define CR0_MP		0x00000002	/* math present */
#define CR0_EM		0x00000004	/* emulation */
#define CR0_TS		0x00000008	/* task switch */
#define CR0_NE		0x00000020	/* numeric error */
#define CR0_WP		0x00010000	/* write protect */
#define CR0_AM		0x00040000	/* alignment mask */
#define CR0_NW		0x20000000	/* not write through */
#define CR0_CD		0x40000000	/* cache disable */
#define CR0_PG		0x80000000	/* paging */
#define CR0_NW_NOT	0xdfffffff	/* write through */
#define CR0_CD_NOT	0xbfffffff	/* cache disable */

/* bits on CR4 */

#define CR4_VME		0x00000001	/* virtual-8086 mode extensions */
#define CR4_PVI		0x00000002	/* protected-mode virtual interrupts */
#define CR4_TSD		0x00000004	/* timestamp disable */
#define CR4_DE		0x00000008	/* debugging extensions */
#define CR4_PSE		0x00000010	/* page size extensions */
#define CR4_PAE		0x00000020	/* physical address extension */
#define CR4_MCE		0x00000040	/* machine check enable */
#define CR4_PGE		0x00000080	/* page global enable */
#define CR4_PCE		0x00000100	/* performance-monitoring enable */

/* CPUID version and feature */

#define CPUID_STEPID	0x0000000f	/* processor stepping id mask */
#define CPUID_MODEL	0x000000f0	/* processor model mask */
#define CPUID_FAMILY	0x00000f00	/* processor family mask */
#define CPUID_TYPE	0x00003000	/* processor type mask */
#define CPUID_FPU	0x00000001	/* FPU on chip */
#define CPUID_VME	0x00000002	/* virtual 8086 mode enhancement */
#define CPUID_DE	0x00000004	/* debugging extensions */
#define CPUID_PSE	0x00000008	/* page size extension */
#define CPUID_TSC	0x00000010	/* time stamp counter */
#define CPUID_MSR	0x00000020	/* RDMSR and WRMSR support */
#define CPUID_PAE	0x00000040	/* physical address extensions */
#define CPUID_MCE	0x00000080	/* machine check exception */
#define CPUID_CXS	0x00000100	/* CMPXCHG8 inst */
#define CPUID_APIC	0x00000200	/* APIC on chip */
#define CPUID_MTRR	0x00001000	/* MTRR */
#define CPUID_PGE	0x00002000	/* PTE global bit */
#define CPUID_MCA	0x00004000	/* machine check arch. */
#define CPUID_CMOV	0x00008000	/* cond. move/cmp. inst */
#define CPUID_486	0x00000400	/* family: 486 */
#define CPUID_PENTIUM	0x00000500	/* family: Pentium */
#define CPUID_PENTIUMPRO 0x00000600	/* family: Pentium PRO */
#define CPUID_ORIG      0x00000000	/* type: original OEM */
#define CPUID_OVERD     0x00001000	/* type: overdrive */
#define CPUID_DUAL      0x00002000	/* type: dual */

/* MSR, Model Specific Registers */

#define MSR_P5_MC_ADDR		0x0000
#define MSR_P5_MC_TYPE		0x0001
#define MSR_TSC			0x0010
#define MSR_APICBASE		0x001b
#define MSR_EBL_CR_POWERON	0x002a
#define MSR_BIOS_UPDT_TRIG	0x0079
#define MSR_BIOS_SIGN		0x008b
#define MSR_PERFCTR0		0x00c1
#define MSR_PERFCTR1		0x00c2
#define MSR_MTRR_CAP		0x00fe
#define MSR_MCG_CAP		0x0179
#define MSR_MCG_STATUS		0x017a
#define MSR_MCG_CTL		0x017b
#define MSR_EVNTSEL0		0x0186
#define MSR_EVNTSEL1		0x0187
#define MSR_DEBUGCTLMSR		0x01d9
#define MSR_LASTBRANCH_FROMIP	0x01db
#define MSR_LASTBRANCH_TOIP	0x01dc
#define MSR_LASTINT_FROMIP	0x01dd
#define MSR_LASTINT_TOIP	0x01de
#define MSR_ROB_CR_BKUPTMPDR6	0x01e0
#define MSR_MTRR_PHYS_BASE0	0x0200
#define MSR_MTRR_PHYS_MASK0	0x0201
#define MSR_MTRR_PHYS_BASE1	0x0202
#define MSR_MTRR_PHYS_MASK1	0x0203
#define MSR_MTRR_PHYS_BASE2	0x0204
#define MSR_MTRR_PHYS_MASK2	0x0205
#define MSR_MTRR_PHYS_BASE3	0x0206
#define MSR_MTRR_PHYS_MASK3	0x0207
#define MSR_MTRR_PHYS_BASE4	0x0208
#define MSR_MTRR_PHYS_MASK4	0x0209
#define MSR_MTRR_PHYS_BASE5	0x020a
#define MSR_MTRR_PHYS_MASK5	0x020b
#define MSR_MTRR_PHYS_BASE6	0x020c
#define MSR_MTRR_PHYS_MASK6	0x020d
#define MSR_MTRR_PHYS_BASE7	0x020e
#define MSR_MTRR_PHYS_MASK7	0x020f
#define MSR_MTRR_FIX_00000	0x0250
#define MSR_MTRR_FIX_80000	0x0258
#define MSR_MTRR_FIX_A0000	0x0259
#define MSR_MTRR_FIX_C0000	0x0268
#define MSR_MTRR_FIX_C8000	0x0269
#define MSR_MTRR_FIX_D0000	0x026a
#define MSR_MTRR_FIX_D8000	0x026b
#define MSR_MTRR_FIX_E0000	0x026c
#define MSR_MTRR_FIX_E8000	0x026d
#define MSR_MTRR_FIX_F0000	0x026e
#define MSR_MTRR_FIX_F8000	0x026f
#define MSR_MTRR_DEFTYPE	0x02ff
#define MSR_MC0_CTL		0x0400
#define MSR_MC0_STATUS		0x0401
#define MSR_MC0_ADDR		0x0402
#define MSR_MC0_MISC		0x0403
#define MSR_MC1_CTL		0x0404
#define MSR_MC1_STATUS		0x0405
#define MSR_MC1_ADDR		0x0406
#define MSR_MC1_MISC		0x0407
#define MSR_MC2_CTL		0x0408
#define MSR_MC2_STATUS		0x0409
#define MSR_MC2_ADDR		0x040a
#define MSR_MC2_MISC		0x040b
#define MSR_MC4_CTL		0x040c
#define MSR_MC4_STATUS		0x040d
#define MSR_MC4_ADDR		0x040e
#define MSR_MC4_MISC		0x040f
#define MSR_MC3_CTL		0x0410
#define MSR_MC3_STATUS		0x0411
#define MSR_MC3_ADDR		0x0412
#define MSR_MC3_MISC		0x0413

/* PMC, Performance Monitoring Event Select MSR bits */

#define	PMC_USR			0x00010000
#define	PMC_OS			0x00020000
#define	PMC_E			0x00040000
#define	PMC_PC			0x00080000
#define	PMC_INT			0x00100000
#define	PMC_EN			0x00400000
#define	PMC_INV			0x00800000

/* PMC, Performance Monitoring Events */

#define	PMC_DATA_MEM_REFS		0x43
#define	PMC_DCU_LINES_IN		0x45
#define	PMC_DCU_M_LINES_IN		0x46
#define	PMC_DCU_M_LINES_OUT		0x47
#define	PMC_DCU_MISS_OUTSTANDING	0x48
#define	PMC_IFU_IFETCH			0x80
#define	PMC_IFU_IFETCH_MISS		0x81
#define	PMC_ITLB_MISS			0x85
#define	PMC_IFU_MEM_STALL		0x86
#define	PMC_IDL_STALL			0x87
#define	PMC_L2_IFETCH			0x28
#define	PMC_L2_LD			0x29
#define	PMC_L2_ST			0x2a
#define	PMC_L2_LINES_IN			0x24
#define	PMC_L2_LINES_OUT		0x26
#define	PMC_L2_M_LINES_INM		0x25
#define	PMC_L2_M_LINES_OUTM		0x27
#define	PMC_L2_RQSTS			0x2e
#define	PMC_L2_ADS			0x21
#define	PMC_L2_DBUS_BUSY		0x22
#define	PMC_L2_DBUS_BUSY_RD		0x23
#define	PMC_BUS_DRDY_CLOCKS		0x62
#define	PMC_BUS_LOCK_CLOCKS		0x63
#define	PMC_BUS_REQ_OUTSTANDING		0x60
#define	PMC_BUS_TRAN_BRD		0x65
#define	PMC_BUS_TRAN_RFO		0x66
#define	PMC_BUS_TRANS_WB		0x67
#define	PMC_BUS_TRAN_IFETCH		0x68
#define	PMC_BUS_TRAN_INVAL		0x69
#define	PMC_BUS_TRAN_PWR		0x6a
#define	PMC_BUS_TRANS_P			0x6b
#define	PMC_BUS_TRANS_IO		0x6c
#define	PMC_BUS_TRAN_DEF		0x6d
#define	PMC_BUS_TRAN_BURST		0x6e
#define	PMC_BUS_TRAN_ANY		0x70
#define	PMC_BUS_TRAN_MEM		0x6f
#define	PMC_BUS_DATA_RCV		0x64
#define	PMC_BUS_BNR_DRV			0x61
#define	PMC_BUS_HIT_DRV			0x7a
#define	PMC_BUS_HITM_DRV		0x7b
#define	PMC_BUS_SNOOP_STALL		0x7e
#define	PMC_FLOPS			0xc1
#define	PMC_FP_COMP_OPS_EXE		0x10
#define	PMC_FP_ASSIST			0x11
#define	PMC_MUL				0x12
#define	PMC_DIV				0x13
#define	PMC_CYCLES_DIV_BUSY		0x14
#define	PMC_LD_BLOCKS			0x03
#define	PMC_SB_DRAINS			0x04
#define	PMC_MISALIGN_MEM_REF		0x05
#define	PMC_INST_RETIRED		0xc0
#define	PMC_UOPS_RETIRED		0xc2
#define	PMC_INST_DECODER		0xd0
#define	PMC_HW_INT_RX			0xc8
#define	PMC_CYCLES_INT_MASKED		0xc6
#define	PMC_CYCLES_INT_PENDING_AND_MASKED 0xc7
#define	PMC_BR_INST_RETIRED		0xc4
#define	PMC_BR_MISS_PRED_RETIRED	0xc5
#define	PMC_BR_TAKEN_RETIRED		0xc9
#define	PMC_BR_MISS_PRED_TAKEN_RETIRED	0xca
#define	PMC_BR_INST_DECODED		0xe0
#define	PMC_BTB_MISSES			0xe2
#define	PMC_BR_BOGUS			0xe4
#define	PMC_BACLEARS			0xe6
#define	PMC_RESOURCE_STALLS		0xa2
#define	PMC_PARTIAL_RAT_STALLS		0xd2
#define	PMC_SEGMENT_REG_LOADS		0x06
#define	PMC_CPU_CLK_UNHALTED		0x79
#define	PMC_UMASK_00			0x00
#define	PMC_UMASK_0F			0x0f
#define	PMC_UMASK_SELF			0x00
#define	PMC_UMASK_ANY			0x20

/* MTRR related defines */

#define MTRR_UC				0x00
#define MTRR_WC				0x01
#define MTRR_WT				0x04
#define MTRR_WP				0x05
#define MTRR_WB				0x06
#define MTRR_E				0x00000800
#define MTRR_FE				0x00000400
#define MTRR_VCNT			0x000000FF
#define MTRR_FIX_SUPPORT		0x00000100
#define MTRR_WC_SUPPORT			0x00000400

/* MCA related defines */

#define	MCG_CTL_P			0x00000100
#define	MCG_COUNT			0x000000ff
#define	MCG_MCIP			0x00000004
#define	MCG_EIPV			0x00000002
#define	MCG_RIPV			0x00000001
#define	MCI_VAL				0x80000000
#define	MCI_OVER			0x40000000
#define	MCI_UC				0x20000000
#define	MCI_EN				0x10000000
#define	MCI_MISCV			0x08000000
#define	MCI_ADDRV			0x04000000
#define	MCI_PCC				0x02000000

#ifdef __cplusplus
}
#endif

#endif	/* __INCregsI86h */
