/* excPcLib.h - PowerPC exception library header */

/* Copyright 1984-1998 Wind River Systems, Inc. */

/*
modification history
--------------------
01j,18aug98,tpr added PowerPC EC 603 support.
01i,06aug97,tam added macro _EXC_NEW_OFF_PIT and _EXC_NEW_OFF_FIT. 
01h,20mar97,tam added prototype for excIntCrtConnect (PPC403 specific). 
01g,26feb97,tam added support for the 403GC and 403GCX cpus. 
01f,20apr96,tpr added excConnect(), excIntConnect(),excVecSet(),excVecGet(),
		excVecBaseSet() and excVecBaseGet() prototype.
01e,04mar96,tam added PPC403 support.
01d,14feb96,tpr added PPC604 support.
01c,09feb95,yao added excCrtStub () for PPC403.
01b,07nov94,yao changed PPC403GA to PPC403.  cleanup.
01a,07jul94,yao written.
*/

#ifndef __INCexcPcLibh
#define __INCexcPcLibh

#ifdef __cplusplus
extern "C" {
#endif

#ifndef _ASMLANGUAGE

typedef struct
    {
    UINT32	valid;		/* 0x118: indicators that following fields 
				 *        are valid */
    UINT32	vecOff;		/* 0x11c: vector offset */
    _RType	cia;		/* 0x120: save/restore reg0 - exception 
				 *        address */
    _RType	msr;		/* 0x124/0x128: save/restore register1 - msr */
#if	(CPU == PPC403)
    _RType	dear;		/* data exception adress register */
#else	/* (CPU == PPC403) */
    _RType	dar;		/* 0x128/0x130: data access register */
#endif	/* (CPU == PPC403) */
    UINT32      cr;		/* 0x12c/0x134: condition register */
    UINT32	xer;		/* 0x130/0x138: fixed point exception reg */
#if	(CPU == PPC403)
    UINT32	bear;		/* bus error adress register */
    UINT32	besr;		/* bus error syndrome register */
#else
    UINT32	fpcsr;		/* 0x134/0x13c: floating point status reg */
    UINT32	dsisr;		/* 0x138/0x140: data storage interrupt
				 * status reg */
#endif	/* (CPU == PPC403) */
    } EXC_INFO;

#endif 	/* _ASMLANGUAGE */

/* exception information valid bits */

#define _EXC_INFO_VEC	0x001	/* vector offset valid */
#define _EXC_INFO_CIA	0x002	/* curent exception address(pc) valid */
#define _EXC_INFO_MSR	0x004	/* machine status register valid */
#define _EXC_INFO_DAR	0x008	/* data access register valid */
#define _EXC_INFO_DEAR	0x008	/* data exception access register valid */
#define _EXC_INFO_XER	0x010	/* fixed point register valid */
#define _EXC_INFO_CR	0x020	/* condition register valid */
#define _EXC_INFO_FPCSR	0x040	/* fp status register valid */
#define _EXC_INFO_BEAR	0x040	/* bus error adress register valid */
#define _EXC_INFO_DSISR	0x080	/* data storage interrupt status reg valid */
#define _EXC_INFO_BESR	0x080	/* bus error syndrome register valid */
#define _EXC_INFO_NIA	0x8000	/* pc saved in cia is nia */

#define _EXC_INFO_DEFAULT	(_EXC_INFO_VEC|_EXC_INFO_CIA|_EXC_INFO_MSR| \
				 _EXC_INFO_CR)
#define _EXC_CODE_SIZE	16	/* size of exc code */

#define EXC_VEC_LOW	0x00000	/* lowest vector enctry */
#define EXC_VEC_HIGH	0x02fff	/* highest vector enctry */

#define _PPC_EXC_VEC_BASE_LOW	0x00000000
#define _PPC_EXC_VEC_BASE_HIGH	0xfff00000

/* exception vector offset */

#define _EXC_OFF_RES0	 	0x00000		/* reseerved */
#define _EXC_OFF_RESET	 	0x00100		/* system reset */
#define _EXC_OFF_MACH	 	0x00200		/* machine check */
#define _EXC_OFF_DATA	 	0x00300		/* data access */
#define _EXC_OFF_INST	 	0x00400		/* instruction access */
#define _EXC_OFF_INTR	 	0x00500		/* external interrupt */
#define _EXC_OFF_ALIGN	 	0x00600		/* alignment */
#define _EXC_OFF_PROG	 	0x00700		/* program */
#define _EXC_OFF_FPU	 	0x00800		/* floating point unavailable */
#define _EXC_OFF_DECR	 	0x00900		/* decrementer */
#define _EXC_OFF_RES1	 	0x00a00		/* reserved */
#define _EXC_OFF_RES2	 	0x00b00		/* reserved */
#define _EXC_OFF_SYSCALL 	0x00c00		/* system call */
#define _EXC_OFF_TRACE	 	0x00d00		/* trace */
#define _EXC_OFF_RES3	 	0x00e00		/* reserved */
						/* exception for PPC601) */
#if	(CPU == PPC601)
#undef	_EXC_OFF_RES1
#define _EXC_OFF_IOERR	 	0x00a00		/* I/O controller interface error */
#undef 	_EXC_OFF_TRACE
#define _EXC_OFF_RES4	 	0x00d00		/* reserved for mpc601 */
#define _EXC_OFF_RUN_TRACE 	0x02000		/* run-mode/trace exception */
#endif	/* (CPU == PPC601) */

#if	((CPU == PPC603) || (CPU == PPCEC603))
#define _EXC_OFF_INST_MISS	0x01000	/* instruction translation miss */
#define _EXC_OFF_LOAD_MISS	0x01100	/* data load translation miss */
#define _EXC_OFF_STORE_MISS	0x01200	/* data store translation miss */
#endif	/* ((CPU == PPC603) || (CPU == PPCEC603)) */

#if	((CPU == PPC603) || (CPU == PPCEC603) || (CPU == PPC604))
#define _EXC_OFF_INST_BRK	0x01300 /* instruction breakpoint exception */
#define _EXC_OFF_SYS_MNG	0x01400	/* system management exception */
#endif	/* ((CPU == PPC603) || (CPU == PPCEC603) || (CPU == PPC604)) */

#if	(CPU == PPC403)
#undef 	_EXC_OFF_RESET	
#undef  _EXC_OFF_DATA
#undef 	_EXC_OFF_DECR
#undef 	_EXC_OFF_TRACE

#define _EXC_OFF_CRTL	 	0x00100	/* critical interrupt */
#define _EXC_OFF_PROT	 	0x00300	/* protection violation exception */
#define _EXC_OFF_PIT		0x01000	/* programmable interval timer */
#define _EXC_OFF_FIT		0x01010	/* fixed interval timer */
#define _EXC_OFF_WD		0x01020	/* watchdog timer */
#define _EXC_OFF_DBG		0x02000	/* debug exception */
#define _EXC_OFF_DATA_MISS	0x01100	/* data translation miss (403GC) */
#define _EXC_OFF_INST_MISS	0x01200	/* data translation miss (403GC) */

/*
 * the FIT and PIT excConnectCode stub won't fit at their default location
 * so we need to put them where we've got some available space and jump
 * to it from_EXC_OFF_PIT and _EXC_OFF_FIT.
 */

#define _EXC_NEW_OFF_PIT	0x01080	/* programmable interval timer */
#define _EXC_NEW_OFF_FIT	0x010C0	/* fixed interval timer */

/* definition for single step support */

#define BRANCH_MASK             0xF0000000
#define OP_BRANCH               0x40000000
#define BCCTR_MASK              0xFC0007FE
#define BCLR_MASK               0xFC0007FE
#define AA_MASK                 0x00000002

#define BO_NB_BIT               5               /* nb bits of BO field    */
#define CR_NB_BIT               32              /* nb bits of CR register */

#define _OP(opcd, xo)           ((opcd << 26) + (xo << 1))

#define INST_BCCTR              _OP(19, 528)    /* BCCTR instruction opcode */
#define INST_BCLR               _OP(19, 16)     /* BCLR instruction opcode */

#define _IFIELD_LI(x)           ((0x02000000 & x) ? ((0xf6000000 | x) & ~3) : \
                                                    ((0x03fffffc & x) & ~3))
#define _IFIELD_BD(x)           ((0x00008000 & x) ? (0xffff0000 | (x & ~3)) : \
                                                    (0x0000fffc & x))
                                                /* ^ signed branch displ */
#define _IFIELD_BO(x)           ((0x03e00000 & x) >> 21)  /* branch options */
#define _IFIELD_BI(x)           ((0x001f0000 & x) >> 16)  /* branch condition */

#define _REG32_BIT(reg, no)     (0x00000001 & (reg >> (no)))
                        /* value of no th bit of the 32 bits register reg */
                        /* bit 0 is the LSB */
#endif	/* (CPU == PPC403) */

/* SRR1 bit defintion for program exception */

#define _EXC_PROG_SRR1_FPU	0x00100000	/* floating-point enabled */
#define _EXC_PROG_SRR1_ILL	0x00080000	/* illegal instruction */
#define _EXC_PROG_SRR1_PRIV	0x00040000	/* previliged instruction */
#define _EXC_PROG_SRR1_TRAP	0x00020000	/* trap exception */
#define _EXC_PROG_SRR1_NIA	0x00010000	/* SRR0 contains nia */

#ifndef _ASMLANGUAGE

/* variable declarations */

extern FUNCPTR  excExcepHook;   /* add'l rtn to call when exceptions occur */


/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern STATUS		excConnect (VOIDFUNCPTR *, VOIDFUNCPTR);
extern STATUS  		excIntConnect (VOIDFUNCPTR *, VOIDFUNCPTR);
extern void		excVecSet (FUNCPTR *, FUNCPTR);
extern FUNCPTR		excVecGet (FUNCPTR *);
extern void		excVecBaseSet (FUNCPTR *);
extern FUNCPTR *	excVecBaseGet (void);

#if	(CPU == PPC403)
extern STATUS		excCrtConnect (VOIDFUNCPTR *, VOIDFUNCPTR);
extern STATUS		excIntCrtConnect (VOIDFUNCPTR *, VOIDFUNCPTR);
extern STATUS  		excIntConnectTimer (VOIDFUNCPTR *, VOIDFUNCPTR);
#endif	/* (CPU == PPC403) */

#else	/* __STDC__ */

extern STATUS		excConnect ();
extern STATUS		excIntConnect ();
extern void		excVecSet ();
extern FUNCPTR		excVecGet ();
extern void		excVecBaseSet ();
extern FUNCPTR *	excVecBaseGet ();

#if	(CPU == PPC403)
extern STATUS		excCrtConnect ();
extern STATUS		excIntCrtConnect ();
extern STATUS		excIntConnectTimer ();
#endif	/* (CPU == PPC403) */

#endif	/* __STDC__ */

#endif /* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCexcPpcLibh */
