/* loadElfLib.h - object module dependant loader library header */

/* Copyright 1984-1992 Wind River Systems, Inc. */
/*
modification history
--------------------
01a,20jun96,dbt  written from /host/include/loadelf.h v01c
		 and /host/include/elfppc.h v01c
*/

#ifndef __INCloadElfLibh
#define __INCloadElfLibh

#ifdef __cplusplus
extern "C" {
#endif

#include "vwModNum.h"
#include "symLib.h"
#include "elf.h"

/* Defines */

#define MAX_SEC_LEN     256

#define SDA_SCN_TYPE    unsigned char
#define NOT_SDA_SCN     0
#define SDA_SCN         1
#define SDA2_SCN        2

/* misc definitions */

#define CHECK_LOW14(val)        (((val & 0xffff8000) == 0) ||           \
                                 ((val & 0xffff8000) == 0xffff8000))

#define CHECK_LOW16(val)        (((val & 0xffff8000) == 0) ||           \
                                 ((val & 0xffff8000) == 0xffff8000))

#define CHECK_LOW16_STRICT(val) (((val & 0xffff0000) == 0) ||           \
                                 ((val & 0xffff0000) == 0xffff0000))

#define CHECK_LOW24(val)        (((val & 0xfe000000) == 0) ||           \
                                 ((val & 0xfe000000) == 0xfe000000))

#define INSERT(buf,value,mask)  (buf = ((buf & ~mask) | (value & mask)))

#define LOW24_INSERT(buf,value) INSERT (buf, value, 0x03fffffc)

#define LOW16_INSERT(buf,value) INSERT (buff, value, 0x0000ffff)

#define LOW14_INSERT(buf,value) INSERT (buf, value, 0x0000fffc)

#define LO_VALUE(val)           ((val) & 0x0000ffff)

#define HI_VALUE(val)           (((val) >> 16) & 0x0000ffff)

#define HA_VALUE(val)           ((((val) >> 16)+(((val) >> 15) & 0x1)) & 0xffff)

#define STORE_MASKED_VALUE(address, mask, value) \
    *(address) = ((*(address)) & ~(mask)) | ((value) & (mask))

/* macro to check if the alignment is a power of 2 */

#define CHECK_2_ALIGN(x)        (((x) & ((x) - 1)) == 0)

/* status codes */

#define S_loadElfLib_HDR_READ			(M_loadElfLib | 1)
#define S_loadElfLib_HDR_ERROR			(M_loadElfLib | 2)
#define S_loadElfLib_PHDR_MALLOC		(M_loadElfLib | 3)
#define S_loadElfLib_PHDR_READ			(M_loadElfLib | 4)
#define S_loadElfLib_SHDR_MALLOC		(M_loadElfLib | 5)
#define S_loadElfLib_SHDR_READ			(M_loadElfLib | 6)
#define S_loadElfLib_READ_SECTIONS		(M_loadElfLib | 7)
#define S_loadElfLib_LOAD_SECTIONS		(M_loadElfLib | 8)
#define S_loadElfLib_LOAD_PROG			(M_loadElfLib | 9)
#define S_loadElfLib_SYMTAB			(M_loadElfLib | 10)
#define S_loadElfLib_RELA_SECTION		(M_loadElfLib | 11)
#define S_loadElfLib_SCN_READ			(M_loadElfLib | 12)
#define S_loadElfLib_SDA_MALLOC			(M_loadElfLib | 13)
#define S_loadElfLib_SST_READ			(M_loadElfLib | 15)

#define S_loadElfLib_JMPADDR_ERROR		(M_loadElfLib | 20)
#define S_loadElfLib_GPREL_REFERENCE		(M_loadElfLib | 21)
#define S_loadElfLib_UNRECOGNIZED_RELOCENTRY	(M_loadElfLib | 22)
#define S_loadElfLib_RELOC			(M_loadElfLib | 23)
#define S_loadElfLib_UNSUPPORTED		(M_loadElfLib | 24)
#define S_loadElfLib_REL_SECTION		(M_loadElfLib | 25)

typedef enum    /* RTYPE_SPARC - sparc relocation types */
    {
    RELOC_8,        RELOC_16,        RELOC_32,          /* simplest relocs */
    RELOC_DISP8,    RELOC_DISP16,    RELOC_DISP32,      /* Disp's (pc-rel) */
    RELOC_WDISP30,  RELOC_WDISP22,                      /* SR word disp's */
    RELOC_HI22,     RELOC_22,                           /* SR 22-bit relocs */
    RELOC_13,       RELOC_LO10,                         /* SR 13&10-bit relocs*/
    RELOC_SFA_BASE, RELOC_SFA_OFF13,                    /* SR S.F.A. relocs */
    RELOC_BASE10,   RELOC_BASE13,    RELOC_BASE22,      /* base_relative pic */
    RELOC_PC10,     RELOC_PC22,                         /* special pc-rel pic */
    RELOC_JMP_TBL,                                      /* jmp_tbl_rel in pic */
    RELOC_SEGOFF16,                                     /* ShLib offset-in-seg*/
    RELOC_GLOB_DAT, RELOC_JMP_SLOT,  RELOC_RELATIVE     /* rtld relocs */
    } RTYPE_SPARC;

/* Some masks */

#define RA_MSK          0x001f0000
#define GPR13_MSK       0x000d0000
#define GPR2_MSK        0x00020000

/* type definitions */

typedef void *          SYM_ADRS;               /* symbol's address */
typedef void **         SYM_ADRS_TBL;           /* table of symbol's addr */
typedef void *          SCN_ADRS;               /* section's address */
typedef void **         SCN_ADRS_TBL;           /* table of section's addr */

/* data structures */

typedef struct
    {
    UINT32 *    pLoadScnHdrIdxs;        /* loadable sections header index tbl */
    UINT32 *    pSymTabScnHdrIdxs;      /* sym table sections header idx tbl */
    UINT32 *    pRelScnHdrIdxs;         /* reloc info sections header idx tbl */
    UINT32 *    pStrTabScnHdrIdxs;      /* str table sections header idx tbl */
    } IDX_TBLS;

typedef struct
    {
    void *      pAddrSdata;     /* address of SDA data segment */
    void *      pAddrSbss;      /* address of SDA bss segment */
    int         sizeSdata;      /* size of SDA data segment */
    int         sizeSbss;       /* size of SDA bss segment */
    int         flagsSdata;     /* SDA data flags for module */
    int         flagsSbss;      /* SDA bss flags for module */
    PART_ID     sdaMemPartId;   /* ID of memory partition dedicated for SDA */
    void *      sdaBaseAddr;    /* Base address of the SDA area */
    int         sdaAreaSize;    /* Size of the SDA area */
    void *      pAddrSdata2;    /* address of SDA2 data segment */
    void *      pAddrSbss2;     /* address of SDA2 bss segment */
    int         sizeSdata2;     /* size of SDA2 data segment */
    int         sizeSbss2;      /* size of SDA2 bss segment */
    int         flagsSdata2;    /* SDA2 data flags for module */
    int         flagsSbss2;     /* SDA2 bss flags for module */
    PART_ID     sda2MemPartId;  /* ID of memory partition dedicated for SDA2 */
    void *      sda2BaseAddr;   /* Base address of the SDA2 area */
    int         sda2AreaSize;   /* Size of the SDA2 area */
    } SDA_INFO;

typedef struct
    {
    SYM_ADRS    pAddr;  /* symbol's address */
    SYM_TYPE    type;   /* symbol's type */
    } SYM_INFO;

typedef Elf32_Sym **    SYMTBL_REFS;    /* table of pointers to symbol tables */
typedef void ***        SYMADDR_REFS;   /* table of ptrs to sym adrs tables */
typedef SYM_INFO *      SYM_INFO_TBL;   /* table of symbol address/type info */
typedef SYM_INFO_TBL *  SYMINFO_REFS;   /* table of ptr to symbol info tables */

/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern STATUS loadElfInit (void);

#else	/* __STDC__ */

extern STATUS loadElfInit ();

#endif	/* __STDC__ */

#ifdef __cplusplus
}
#endif

#endif /* __INCloadElfLibh */
