/* led.h - Mentat Portable STREAMS O.S dependent file */

/* Copyright 1994-1995 Wind River Systems, Inc. */
#include "copyright_wrs.h"

/*   
modification history
--------------------
01o,30nov98,sgv  Removed definition for SIGIO, SIGURG and SIGPOLL in led.h, 
		 Included sigLib.h
01n,26mar97,sgv  Removed extraneous R4000 conditionals. R4000 uses myVxTas as
		 a workaround for the faulty vxTas in R4000.
01m,24mar97,sgv	 Added conditionals for R4000
01l,06sep95,jag  added defines for mi_strcmp,mi_strlen etc. deleted macros
		 for mps_[re]open_xtr_init, mps_close_sth_check. deleted
		 fattachList from STH_XTRA
01k,27aug95,jag  deleted obsoleted fields from STH_XTRA.
01j,24aug95,jag  moved delay, cmpdev and expdev macros to sysmacros.h, 
		 MPS_DEBUG turned off. deleted drv_priv
01i,20aug95,sgv  Included define for lbolt. Added define for ECANCEL
01h,19aug95,sgv  Included SIGPOLL,SIGURG SIGIO defines.
01g,19aug95,sgv  Included DEF_XXX defines.
01f,01aug95,dzb  changed to inclusion of strmLib.h.
01e,06jun95,sgv  Added Define for lint .
01d,06jun95,jag  Added Byte order checking.
01c,22mar95,jag  Added definition for structure STRM_DEFER_JOB
01b,10mar95,sgv  Added defines for mi_freezestr and mi_unfreezstr
01a,07mar95,jag  Added macro for mps_dispose_of_passed_fp used in flushq
*/

#ifndef __INCledh
#define __INCledh

/* Header files we pretty much always need */

#include <vxWorks.h>
#include <errno.h>
#include "strmLib.h"
#include <types/vxTypesOld.h>
#include <selectLib.h>
#include <wdLib.h>
#include <sigLib.h>
#include <vxLib.h>
#include <string.h>
 
/* Definitions required by MPS */

#if     _BYTE_ORDER==_BIG_ENDIAN
#define MI_BIG_ENDIAN  1    
#else
#define MI_LITTLE_ENDIAN 1
#endif

#define SVR4_STYLE     1    /* Well, this is 1994 */
#define MPS_NO_CTTYS   1    /* No Controlling TTY stuff */
/* #define MPS_DEBUG            It isn't working yet! */
/* #define NATIVE_ONDELAY 1     We can do this at the FD level */

#define OTHER_MPS_LOCK_TYPE 1  /* We use VxWorks semaphores for spinlocks */

#define NO_SENDFD      1    /* Sending fd's is pointless in VxWorks */
#define NO_SEEK        1    /* Strange Mentat extension */
#define MPS_NO_UNLOAD  1    /* Don't (currently) support unloading MPS */

/* VxWorks already support ECANCEL as ECANCELED so just define as such */

#define ECANCEL        ECANCELED

/* VxWorks fast lock code */

#define OTHER_MPS_LOCKF_ACQUIRE
#if	(CPU != __R4000__)
#define mps_lockf_acquire(mpslf)        vxTas((void *)(mpslf))
#else
#define mps_lockf_acquire(mpslf)        myVxTas((int *)(mpslf))
#endif
#define mps_lockf_release(mpslf)        (*(mpslf) = 0)
#define mps_lockf_alloc(mpslf)          (*(mpslf) = 0, true)
#define mps_lockf_free(mpslf)           /* No-op */
#define mps_lockf_in_use(mpslf)         (*mpslf)


/* This defined is used by the TLI library and the sthd test */
#define MAX_STACK_BUF	512
#define PIPE_BUF    	5120     /* Traditional value */
#define NOFILE      maxFiles     /* Max number of fd's in a pollfd strucure */
#define MAX_FAST_MBLK	8192	 /* VR maximum message block allowed in strm */

#define int_fd      fd    /* fd's are global pointers to fd structure */

/* Add typedefs for SVR4 style working, but some of  these might be
 * included by VxWorks.  We include <vxTypesOld.h> to avoid some problems
 */


typedef unsigned long     ulong;
typedef unsigned int      uint;


/* Add Mentat specific definitions     */

typedef int               boolean_t;
typedef int               boolean;
typedef unsigned long     u32;          /* N.B. 64 bit systems! */
typedef unsigned short    u16;
typedef unsigned char     u8;

typedef void             *PCELL;
typedef void             *FDCELL;       /* Container for a file descriptor? */

typedef int               pl_t;         /* Used in miecho.c Processor level? */

typedef SEM_ID           MPSL, *MPSLP;


/* Syntactic sugar */

#define globaldef
#define globalref


/* Global Variables */

extern int qwillrun;
extern SEM_ID strmRunSem;
extern BOOL 	myVxTas (int * address);


/* External variable used within mps code */

extern int maxFiles;


/* External functions supplied by VxWorks port specific code */

/* Null functions */

#define mi_qprocsoff(q) (q)  /* These will produce warnings with some */
#define mi_qprocson(q) (q)   /* Compilers about 'null effect' */


#define mps_printf      printf    

void mps_osr_close_continue();

#define mps_osr_pop_continue      mps_osr_close_continue
#define mps_osr_push_continue     mps_osr_close_continue
#define mps_osr_open_continue     mps_osr_close_continue
#define mps_osr_reopen_continue   mps_osr_close_continue

#define mps_qrun_tickle()         semGive(strmRunSem);
#define mps_deliver_sig(a, b, c)           (0)

#define mps_lock_free(p)          semDelete(*p)


#define mps_close_finish          mps_osr_finish
#define mps_open_finish           mps_osr_finish
#define mps_install_finish        mps_osr_finish
#define mps_timer_accelerate      mps_timer_start

#ifndef HZ

#define HZ                        ticksASec
#endif
#define MS_TO_TICKS(ms)           (((ms * HZ)/1000) + 1)

extern int ticksASec;
extern WDOG_ID mpsTimerId;
extern void mps_timeout_callback();

#define mps_timer_start(n)          wdStart(mpsTimerId, n, mps_timeout_callback, 0)


/* Macros to manipulate slow Mutex locks */

#define mps_lock_acquire(p)       semTake(*p, WAIT_FOREVER)
#define mps_lock_release(p)       semGive(*p)
#define mps_lock_in_use(p)        (semTake(*p, NO_WAIT) != OK)

#define OTHER_CANPUTNEXT    1
#define OTHER_BCANPUTNEXT    1

#define canputnext(q)       canput((q)->q_next)
#define bcanputnext(q, pri)      banput((q)->q_next, pri)


#define mps_copyin(osr, usrc, kdest, cnt)     (bcopy(usrc, kdest, cnt), 0)
#define mps_copyout(osr, ksrc, udest, cnt)    (bcopy(ksrc, udest, cnt), 0)

/* Tasks wait on a semaphore for completion of MPS requests */
#define mps_osr_wait(osr)       semTake(osr->vxwSemid, WAIT_FOREVER)

#define mps_dispose_of_file_by_cookie(cookie) (0)

/*
 * This routine is descirbed in the MPS manual and is used to decrement
 * the FP count at the time the STREAMS is close.  It  is deffered until this
 * time since this operation required a process context.  In VxWorks this is
 * not necessary, so we just free the mp.
 */

#define mps_dispose_of_passed_fp(pSth, pMsp)	freemsg(pMsp)

/* Extra fields in the OSR which are not zeroed every time */
#define OSR_NONZERO_XTRA \
SEM_ID         vxwSemid;           /* Sem for waiting request */  \
SEM_ID         osrSleepSem;        /* Sem for sleep in open/close */


/* Extra fields in the Stream Head structure */
#define STH_XTRA \
int                    blockFlags;   /* Set to zero or non-blocking flag */ \
SEL_WAKEUP_LIST        selectList;   /* Select list */ \
int                    openCnt;      /* No of opens on this stream */



/* This flag is set if a request has to run in the context of the caller */
#define OSR_IN_PROCESS            F_OSR_PORTFLAG_1

/* Restart an OSR, switching context if necessary */
#define STH_OSR_RESTART(osrq) \
if ((OSRQ_NEXT((OSRQP)(osrq)))->osrq_osr->osr_flags & OSR_IN_PROCESS) \
    semGive(OSRQ_NEXT(((OSRQP)(osrq)))->osrq_osr->vxwSemid); \
else \
    STH_OSR_LOOP(OSRQ_NEXT(((OSRQP)(osrq)))->osrq_osr)


#define         usage(s)  printf(s)
#define         warn      printf
#define         set_program_name(s)
#define         sleep(n)  taskDelay(n * 100)

#define stream_open(name, mode)     open(name, mode, 0)
#define stream_close    close
#define stream_read     read
#define stream_write    write
#define stream_ioctl    ioctl

/* 
 * This set of defines are provided by WRS to avoid inclusion of duplicate
 * functions.
 */

 #define OTHER_MI_STRCMP
 #define OTHER_MI_STRLEN
 #define OTHER_MI_STRCHR
 #define OTHER_MI_STRTOL
 #define OTHER_MI_BZERO
 #define mi_strcmp     strcmp
 #define mi_strlen     strlen
 #define mi_strchr     strchr
 #define mi_strtol     strtol
 #define mi_bzero      bzero


/* The following defines are NO-OPS in MPS environment. MPS provides
 * mechanisms to single-thread a stream using synchronization levels
 */

#define mi_freezestr(q) 	0
#define mi_unfreezestr(q,old_pl)

/* The following define "lbolt" is used by MPS timer facility */

#define lbolt tickGet()


#define DEF_NSTRPUSH	9
#define DEF_STRCTLSZ	1024
#define DEF_STRMSGSZ	4096
#define DEF_STRTHRESH   0

/*
 * The routines qenable, putq, and freeb use these defines and the structure
 * STRM_DEFER_JOB to schedule them selfs to execute under the STREAMS task
 * context if invoked from an ISR.  These are the only routine in the STREAMS
 * enviroment that can be invoked from interrupt context.
 */

#define PUTQ_DEFERRED		0x01
#define FREEB_DEFERRED		0x02
#define QENABLE_DEFERRED	0x03

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

typedef struct
    {
    unsigned long  jobType;
    int            param1;
    int            param2;
    } STRM_DEFER_JOB;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#define STRM_DEFER_RING_SIZE (50 * sizeof (STRM_DEFER_JOB))

/* This routine is used by putq, qenable and freeb to schedule deferred jobs */

extern void strmJobAdd ( int jobType, int param1, int param2 );


#endif /* __INCledh */
