/* vxCpu.h - VxWorks CPU definitions header */

/* Copyright 1984-1998 Wind River Systems, Inc. */

/*
modification history
--------------------
02e,17aug97,tpr  added PowerPC EC 603 support.
02e,15aug97,cym  added SIMNT support.
02g,09apr98,hdn  added support for Pentium, PentiumPro.
02f,26mar97,cdp  added Thumb (ARM7TDMI_T) support.
02e,28nov96,cdp  added ARM support.
02d,12jul96,kkk  added CW4000 & R4650 support.
02c,08feb96,tpr  added PPC505 and PPC860 support.
02b,23feb96,tpr  undefined the PPC macro defined by the PowerPC Gnu.
02a,26may94,yao  added PPC support.
01k,24jul95,ism  added SIMSOLARIS support.
01j,27dec95,myz  added I960HX stuff.
01i,20mar95,kvk  added I960JX specific stuff.
01h,31oct94,kdl  removed comment-within-comment.
01f,27sep93,cd   added R4000 support.
01g,26oct94,tmk  added new cpu type MC68LC040
01f,21jul94,tpr  added MC68060 cpu.
01f,09jun93,hdn  added support for I80X86
01g,02dec93,tpr  added definition for the AMD 29200 microcontroller
	    pad  added definitions for the AMD 29030 cpu
01g,11aug93,gae  vxsim hppa.
01f,22jun93,gae  vxsim: added SIMSPARCSUNOS.
01e,13nov92,dnw  added test for correct definition of CPU
01d,22sep92,rrr  added support for c++
01c,07sep92,smb  added documentation
01b,23jul92,jwt  restored SPARClite reference omitted in file creation.
01a,11jul92,smb  CPU definitions moved from vxWorks.h.
*/

/*
DESCRIPTION
Depending on the value of CPU passed to the system by the compiler command
line, the CPU_FAMILY is defined.  This must be the first header file
included by vxWorks.h.
*/

#ifndef __INCvxCpuh
#define __INCvxCpuh

#ifdef __cplusplus
extern "C" {
#endif


/* CPU types */

/* The Green Hills compiler pre-defines "MC68000"!! */
#ifdef MC68000
#undef MC68000
#endif

#define MC68000         1       /* CPU */
#define MC68010         2       /* CPU */
#define MC68020         3       /* CPU */
#define MC68030         4       /* CPU */
#define MC68040         5       /* CPU */
#define MC68LC040       6       /* CPU */
#define MC68060         7       /* CPU */
#define CPU32           8       /* CPU */
#define MC680X0         9       /* CPU_FAMILY */

#define SPARC           10      /* CPU and CPU_FAMILY */
#define SPARClite       11	/* CPU */

#ifndef I960
#define I960            20      /* CPU_FAMILY */
#endif
#define I960CA          21      /* CPU */
#define I960KA          22      /* CPU */
#define I960KB          23      /* CPU */
#define I960JX          24      /* CPU */
#define I960HX          25      /* CPU */

#define TRON            30      /* CPU_FAMILY */
#define G100            31      /* CPU */
#define G200            32      /* CPU */

#define MIPS            40      /* CPU_FAMILY */
#define R3000           41      /* CPU */
/* #define R33000       42      ** reserved */
/* #define R33020       43      ** reserved */
#define R4000		44	/* CPU */
#define CW4000		45	/* CPU */
#define R4650		46	/* CPU */

#define AM29XXX         50      /* CPU_FAMILY */
#define AM29030		51      /* CPU */
#define AM29200		52      /* CPU */
#define AM29035		53      /* CPU */

#define SIMSPARCSUNOS	60	/* CPU & CPU_FAMILY */
#define SIMSPARCSOLARIS	61	/* CPU & CPU_FAMILY */

#define SIMHPPA		70	/* CPU & CPU_FAMILY */

#define I80X86          80      /* CPU_FAMILY */
#define I80386          81      /* CPU */
#define I80486          82      /* CPU */
#define PENTIUM         83      /* CPU */
#define PENTIUMPRO      84      /* CPU */

#undef  PPC
#define PPC             90      /* CPU_FAMILY */
#define PPC601          91      /* CPU */
#define PPC602          92      /* CPU */
#define PPC603          93      /* CPU */
#define PPC604          94      /* CPU */
#define PPC403          95      /* CPU */
#define PPC505          96      /* CPU */
#define PPC860          97      /* CPU */
#define PPCEC603	98	/* CPU */

#define SIMNT		100 	/* CPU & CPU_FAMILY */

#define ARM             120     /* CPU_FAMILY */
#define ARM710A         121     /* CPU */
#define ARM7TDMI        122     /* CPU */
#define ARM810          123     /* CPU */
#define ARMSA110        124     /* CPU */
#define ARM7TDMI_T      125     /* CPU: ARM7TDMI in Thumb state */
/* 126..129 reserved for ARM */

/* define the CPU family based on the CPU selection */

#undef CPU_FAMILY

#if	(CPU==MC68000 || CPU==MC68010 || CPU==MC68020 || CPU==MC68030 || \
	 CPU==CPU32   || CPU==MC68040 || CPU==MC68060 || CPU==MC68LC040)
#define	CPU_FAMILY	MC680X0
#endif	/* CPU_FAMILY==MC680X0 */

#if     (CPU==SPARC || CPU==SPARClite)
#define CPU_FAMILY      SPARC
#endif  /* CPU_FAMILY==SPARC */

#if 	(CPU==I960CA || CPU==I960KA || CPU==I960KB || CPU==I960JX || CPU==I960HX)
#define	CPU_FAMILY	I960
#endif	/* CPU_FAMILY==I960 */

#if     (CPU==G100 || CPU==G200)
#define CPU_FAMILY      TRON
#endif	/* CPU_FAMILY==TRON */

#if	(CPU==__R3000__ || CPU==__R4000__ || CPU==CW4000 || CPU==R4650)
#define CPU_FAMILY      MIPS
#endif	/* CPU_FAMILY==MIPS */

#if     (CPU==I80386 || CPU==I80486 || CPU==PENTIUM || CPU==PENTIUMPRO)
#define CPU_FAMILY      I80X86
#endif	/* CPU_FAMILY==I80X86 */

#if	(CPU==AM29030 || CPU==AM29035 || CPU==AM29200)
#define CPU_FAMILY	AM29XXX
#endif /* CPU_FAMILY==AM29XXX */

#if	(CPU==SIMSPARCSUNOS)
#define	CPU_FAMILY	SIMSPARCSUNOS
#endif	/* CPU_FAMILY==SIMSPARCSUNOS */

#if	(CPU==SIMSPARCSOLARIS)
#define	CPU_FAMILY	SIMSPARCSOLARIS
#endif	/* CPU_FAMILY==SIMSPARCSOLARIS */

#if	(CPU==SIMHPPA)
#define	CPU_FAMILY	SIMHPPA
#endif	/* CPU_FAMILY==SIMHPPA */

#if	(CPU==PPC403 || CPU==PPC505 || CPU==PPC601 || CPU==PPC603 || \
	 CPU==PPC604 || CPU==PPC860 || CPU==PPCEC603)
#define CPU_FAMILY      PPC
#endif  /* CPU_FAMILY==PPC */

#if	(CPU==SIMNT)
#define CPU_FAMILY	SIMNT
#endif	/* CPU==SIMNT */

#if     (CPU==ARM710A || CPU==ARM7TDMI || CPU==ARM810 || CPU==ARMSA110 || \
	 CPU==ARM7TDMI_T)
#define CPU_FAMILY      ARM
#endif  /* CPU_FAMILY==ARM */


/*
 * Check that CPU and CPU_FAMILY are now defined correctly.
 * If CPU is defined to be one of the above valid values then
 * the CPU_FAMILY will have been properly selected.
 * This is required in order to select the right headers
 * and definitions for that CPU in subsequent headers.
 * If CPU or CPU_FAMILY is not defined at this point,
 * we generate an error and abort the compilation.
 */

#if !defined(CPU) || !defined(CPU_FAMILY)
#error CPU is not defined correctly
#endif



#ifdef __cplusplus
}
#endif

#endif /* __INCvxCpuh */
