/* mmuPpro36Lib.h - mmuPpro36Lib header for i86. */

/* Copyright 1984-1997 Wind River Systems, Inc. */

/*
modification history
--------------------
01b,13may98,hdn  added _ASMLANGUAGE macro. 
01a,11apr97,hdn  written.
*/

#ifndef __INCmmuPpro36Libh
#define __INCmmuPpro36Libh

#ifdef __cplusplus
extern "C" {
#endif


#define PAGE_SIZE		0x1000
#define PAGE_BLOCK_SIZE		0x200000
#define PAGE_SIZE_4KB		0x1000
#define PAGE_SIZE_2MB		0x200000

#define DIR_BITS		0xffe00000
#define TBL_BITS		0x001ff000
#define OFFSET_BITS_4KB		0x00000fff
#define OFFSET_BITS_2MB		0x001fffff
#define DIR_INDEX		21
#define TBL_INDEX		12
#define PTE_TO_ADDR_4KB		0xfffff000
#define PTE_TO_ADDR_2MB		0xffe00000
#define PDP_TO_ADDR		0xfffff000
#define ADDR_TO_PAGE		12
#define ADDR_TO_PAGEBASE	0xffe00000

#ifndef	_ASMLANGUAGE

typedef struct
    {
    unsigned present:1;
    unsigned rw:1;
    unsigned us:1;
    unsigned pwt:1;
    unsigned pcd:1;
    unsigned access:1;
    unsigned dirty:1;
    unsigned pagesize:1;
    unsigned global:1;
    unsigned avail:3;
    unsigned page:20;
    unsigned page36:4;
    unsigned reserved:28;
    } PTE_FIELD;

typedef union pte
    {
    PTE_FIELD field;
    UINT bits[2];
    } PTE;

typedef struct mmuTransTblStruct
    {
    PTE *pDirectoryTable;
    } MMU_TRANS_TBL;

typedef struct gdt
    {
    unsigned short	limit00;
    unsigned short	base00;
    unsigned char	base01;
    unsigned char	type;
    unsigned char	limit01;
    unsigned char	base02;
    } GDT;


#define MMU_STATE_MASK_VALID		0x001
#define MMU_STATE_MASK_WRITABLE		0x002
#define MMU_STATE_MASK_CACHEABLE	0x018

#define MMU_STATE_VALID			0x001
#define MMU_STATE_VALID_NOT		0x000
#define MMU_STATE_WRITABLE		0x002
#define MMU_STATE_WRITABLE_NOT		0x000
#define MMU_STATE_CACHEABLE		0x008
#define MMU_STATE_CACHEABLE_NOT		0x018

#define MMU_STATE_CACHEABLE_WT		0x008

#define GDT_ENTRIES			5


/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern STATUS	mmuPro36LibInit (int pageSize);
extern STATUS	mmuPro36Enable (BOOL enable);
extern void	mmuPro36On ();
extern void	mmuPro36Off ();
extern void	mmuPro36TLBFlush ();
extern void	mmuPro36PdbrSet (void *transTbl);
extern void	*mmuPro36PdbrGet ();

#else   /* __STDC__ */

extern STATUS	mmuPro36LibInit ();
extern STATUS	mmuPro36Enable ();
extern void	mmuPro36On ();
extern void	mmuPro36Off ();
extern void	mmuPro36TLBFlush ();
extern void	mmuPro36PdbrSet ();
extern void	*mmuPro36PdbrGet ();

#endif  /* __STDC__ */

#endif	/* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCmmuPpro36Libh */
