/* cacheMc68kLib.h - 68k cache library header file */

/* Copyright 1995-1996 Wind River Systems, Inc. */
/*
modification history
--------------------
02e,12jun96,dbt  fixed SPR 6210, Added ")".
		 Update copyright.
02d,26oct94,tmk  added support for MC68LC040
02c,08jun94,tpr  added MC68060 cpu support.
		 added prototype for cacheStoreBufEnable() and
		 cacheStoreBufDisable().
02b,22dec93,jwt  added cacheArchInvalidate() function prototype for '040.
02a,01oct92,jcf  new interface definition. clean up.
01i,22sep92,rrr  added support for c++
01h,23aug92,jcf  fixed prototypes.
01g,31jul92,jwt  renamed cacheMc68kMalloc() to cacheMc68kDmaMalloc().
01f,15jul92,jwt  added definitions for cache modes, cleanup.
01e,14jul92,jwt  added prototype for cacheMc68kFree() - missing from 01d.
01d,13jul92,rdc  added prototype for cacheMc68kMalloc.
01c,03jul92,jwt  moved 68040 stuff from h/cacheLib.h to h/arch/mc68k/.
01b,26may92,rrr  the tree shuffle
01a,20jan92,shl  created.
*/

#ifndef __INCcacheMc68kLibh
#define __INCcacheMc68kLibh

#ifdef __cplusplus
extern "C" {
#endif

#include "vxWorks.h"

#if defined(__STDC__) || defined(__cplusplus)

#if ((CPU == MC68020) || (CPU == MC68040) || (CPU == MC68060) || \
     (CPU == MC68LC040))

extern STATUS cacheArchEnable (CACHE_TYPE cache);
extern STATUS cacheArchDisable (CACHE_TYPE cache);
extern STATUS cacheArchLock (CACHE_TYPE cache, void * address, size_t bytes);
extern STATUS cacheArchUnlock (CACHE_TYPE cache,
				void * address, size_t bytes);
extern STATUS cacheArchClear (CACHE_TYPE cache, void * address, size_t bytes);
extern void * cacheArchDmaMalloc (size_t bytes);
extern STATUS cacheArchDmaFree (void * pBuf);
extern STATUS cacheArchTextUpdate (void * address, size_t bytes);
extern STATUS cacheArchClearEntry (CACHE_TYPE cache, void * address);

extern int    cacheCACRGet (void);
extern void   cacheCACRSet (int cacr);
extern int    cacheCAARGet (void);
extern void   cacheCAARSet (void * address);

#if ((CPU == MC68040) || (CPU == MC68060) || (CPU == MC68LC040))
extern STATUS cacheArchInvalidate (CACHE_TYPE cache, 
				   void * address, size_t bytes);
extern void   cacheCINV (int cache, int scope, int line);
extern void   cacheCPUSH (int cache, int scope, void * address);
extern void   cache040WriteBufferFlush (void);
extern void   cache040DataDisable (void);
extern void   cacheDTTR0ModeSet (UINT mode);
extern void   cacheDTTR0Set (UINT dttr0);
extern UINT   cacheDTTR0Get (void);

#if (CPU == MC68060)
extern void   cacheStoreBufEnable (void);
extern void   cacheStoreBufDisable (void);
#endif /* (CPU == MC68060) */

#endif /* ((CPU==MC68040 || (CPU==MC68060) || (CPU==MC68LC040)) */

#endif /* ((CPU == MC68020) || (CPU == MC68040) || (CPU == MC68060) || \
	*  (CPU == MC68LC040)) */

#else

#if ((CPU==MC68020) || (CPU==MC68040) || (CPU==MC68060) || (CPU==MC68LC040))

extern STATUS cacheArchEnable ();
extern STATUS cacheArchDisable ();
extern STATUS cacheArchLock ();
extern STATUS cacheArchUnlock ();
extern STATUS cacheArchClear ();
extern void * cacheArchDmaMalloc ();
extern STATUS cacheArchDmaFree ();
extern STATUS cacheArchTextUpdate ();
extern STATUS cacheArchClearEntry ();

extern int    cacheCACRGet ();
extern void   cacheCACRSet ();
extern int    cacheCAARGet ();
extern void   cacheCAARSet ();

#if ((CPU == MC68040) || (CPU == MC68060) || (CPU == MC68LC040))
extern STATUS cacheArchInvalidate ();
extern void   cacheCINV ();
extern void   cacheCPUSH ();
extern void   cache040WriteBufferFlush ();
extern void   cache040DataDisable ();
extern void   cacheDTTR0ModeSet ();
extern void   cacheDTTR0Set ();
extern UINT   cacheDTTR0Get ();

#if (CPU == MC68060)
extern void   cacheStoreBufEnable();
extern void   cacheStoreBufDisable();
#endif /* (CPU == MC68060) */

#endif /* ((CPU == MC68040 || (CPU == MC68060) || (CPU == MC68LC040)) */

#endif /* ((CPU == MC68020) || (CPU == MC68040) || (CPU == MC68060) || \
	*  (CPU == MC68LC040)) */
#endif /* __STDC__ */

#if (CPU == MC68020)
#define C_ENABLE        	0x1	/* enable cache */
#define C_FREEZE        	0x2	/* freeze cache */
#define C_CLR_ENTRY    		0x4	/* remove entry from cache */
#define C_CLR           	0x8	/* remove all cache entries */
#define C_BURST         	0x10	/* enable cache burst fill */
#define C_ALLOCATE      	0x20	/* write allocate */
#define C_CACR_SHIFT    	8	/* bits shifted left to data fields */
#define	C_INDEX_MASK		0xfc
#endif	/* (CPU == MC68020) */

#if ((CPU == MC68040) || (CPU == MC68060) || (CPU == MC68LC040))
#define	CACHE_INH_SERIAL	0x100	/* cache inhibited, serial accesses */
#define	CACHE_INH_NONSERIAL	0x200	/* cache inhibited, defered writes */
#define	CACHE_INH_PRECISE	0x100	/* cache inhibited, precise mode */
#define	CACHE_INH_IMPRECISE	0x200	/* cache inhibited, imprecise mode */

#define C_ENABLE        	0x8000	/* enable cache */
#define C_FREEZE        	0x4000	/* freeze cache */
#define C_CACR_SHIFT    	16      /* bits shifted left to data fields */
#define C_CACR_BRANCH_SHIFT	8	/* bits shifted left to branch fields */

/* MC68060 Cache Control Register bit define */
#define C_CACR_FIC	0x00002000	/* 1/2 inst. cache operation mode */
#define C_CACR_NAI	0x00004000	/* Inst. cache no allocate mode */
#define C_CACR_EIC	0x00008000	/* enable instruction cache */
#define C_CACR_CUBC	0x00200000	/* clear all user entries in B-cache */
#define C_CACR_CABC	0x00400000	/* clear all entries in branch cache */
#define C_CACR_EBC	0x00800000	/* enable branch cache */
#define C_CACR_FOC	0x08000000	/* 1/2 data cache operation mode */
#define C_CACR_DPI	0x10000000	/* disable CPUSH invalidation */
#define C_CACR_ESB	0x20000000	/* enable store buffer */
#define C_CACR_NAD	0x40000000	/* data cache no allocate mode */
#define C_CACR_EDC	0x80000000	/* enable data cache */

#define CACHE_LINE              0x1	/* CPUSH granularity */
#define CACHE_PAGE              0x2
#define CACHE_ALL               0x3

#define	C_TTR_CACHE_MODE	0x0060	/* transparent translation */
#define	C_TTR_WRITETHROUGH	0x0000
#define	C_TTR_COPYBACK		0x0020
#define	C_TTR_SERIALIZED	0x0040
#define	C_TTR_NOT_SERIAL	0x0060
#define	C_TTR_PRECISE		0x0040
#define	C_TTR_NOT_PRECISE	0x0060
#define	C_TTR_ENABLE		0x8000	/* enable TTR */

#endif	/* ((CPU == MC68040) || (CPU == MC68060) || (CPU == MC68LC040)) */

#ifdef __cplusplus
}
#endif

#endif /* __INCcacheMc68kLibh */
