/* dbgMc68kLib.h - header file for arch dependent portion of debugger */

/* Copyright 1984-1993 Wind River Systems, Inc. */

/*
modification history
--------------------
01g,26oct94,tmk  added support for MC68LC040
01f,21jul94,tpr  added MC68060 cpu support.
01e,19aug93,dvs  removed PC and included reg.h (SPR #2264)
01d,05aug93,jwt  removed DBG_SAVE structure - not used; copyright 1993.
01c,22sep92,rrr  added support for c++
01b,22sep92,kdl  added D0...D7, A0...A7, PC, SR symbols; added c++ support.
01a,11Feb92,yao  written based on tron/dbgTRONLib.h 01c version.
*/

#ifndef __INCMc68kdbgh
#define __INCMc68kdbgh

#ifdef __cplusplus
extern "C" {
#endif

#include "esf.h"
#include "reg.h"

#define D0	0	/* data registers 0 to 7 */
#define D1	1
#define D2	2
#define D3	3
#define D4	4
#define D5	5
#define D6	6
#define D7	7

#define A0	8	/* address registers 0 to 6 */
#define A1	9
#define A2	10
#define A3	11
#define A4	12
#define A5	13
#define A6	14
#define A7	15	/* a7 is the stack pointer */

#define SR	16	/* status register */

#define LINK            0x4e50
#define LINK_MASK       0xfff8
#define RTS             0x4e75
#define RTS_MASK        0xffff
#define JSR             0x4e80
#define JSR_MASK        0xffc0
#define BSR             0x6100
#define BSR_MASK        0xff00

#define TRAP0_INST      0x4e40  		/* opcode for trap 0 */
#define TRACE_BIT       0x8000  		/* trace bit in 68K SR */
#define	DBG_TRAP_NUM	2			/* debug trap number */
#define DBG_BREAK_INST	(TRAP0_INST + DBG_TRAP_NUM)	
						/* breakpoint instruction */

#if	(CPU == MC68000 || CPU == MC68010 || CPU == CPU32)
#define DBG_INST_ALIGN	2
#else	/* (CPU == MC68000 || CPU == MC68010 || CPU == CPU32) */
#define DBG_INST_ALIGN	1
#endif	/* (CPU == MC68000 || CPU == MC68010 || CPU == CPU32) */

#if (CPU==MC68000)
#define TRACE_ESF ESF68K
#endif

#if (CPU==MC68010)
#define TRACE_ESF ESF0
#endif

#if (CPU==MC68020 || CPU==MC68040 || CPU==MC68060 || CPU==CPU32 || \
     CPU==MC68LC040)

#define TRACE_ESF ESF2
#endif

#if (CPU==MC68000)
#define BREAK_ESF ESF68K
#else
#define BREAK_ESF ESF0
#endif

#ifdef __cplusplus
}
#endif

#endif /* __INCMc68kdbgh */
