/* fpp68kLib.h - MC680X0 floating-point coprocessor support library header */

/* Copyright 1984-1995 Wind River Systems, Inc. */
/*
modification history
--------------------
01n,06jan95,jcf  added NULLFRAME definition.
01m,22sep92,rrr  added support for c++
01l,28jul92,jcf  added include taskLib.h.
01k,04jul92,jcf  added variable declarations; changed fp*RegIndex to fp*RegName
01j,26may92,rrr  the tree shuffle
01i,20feb92,yao  added FPREG_SET.  removed ANSI function propotype declaration.
		 added FPX_OFFSET macro, FPSR, FPIAR.  made FPCR, FPX,
		 STATEFRAME available for c too. added ANSI definition for
		 fppProbeSup(), fppDtoDx().  changed FP_NUM_REGS to
		 FP_NUM_DREGS.
01h,04oct91,rrr  passed through the ansification filter
		  -fixed #else and #endif
		  -changed TINY and UTINY to INT8 and UINT8
		  -changed VOID to void
		  -changed ASMLANGUAGE to _ASMLANGUAGE
		  -changed copyright notice
01g,05oct90,dnw  moved function prototypes within non-_ASMLANGUAGE part
01f,05oct90,shl  added ANSI function prototypes.
                 made #endif ANSI style.
                 added copyright notice.
01e,01aug90,jcf  cleanup.
01d,18mar90,jcf  added type definition to FP_CONTEXT.
01c,09aug89,gae  now in 68k.
01b,18mar88,gae  boosted FP_STATE_FRAME_SIZE by 32 for MC68882.
01a,12aug87,gae  written.
*/

#ifndef __INCfppMc68kLibh
#define __INCfppMc68kLibh

#ifdef __cplusplus
extern "C" {
#endif

/* FP_CONTEXT structure offsets */

#define	FPCR		0x00	/* OFFSET(FP_CONTEXT, fpcr)		*/
#define	FPSR		0x04	/* OFFSET(FP_CONTEXT, fpsr)		*/
#define	FPIAR		0x08	/* OFFSET(FP_CONTEXT, fpiar)		*/
#define	FPX		0x0c	/* OFFSET(FP_CONTEXT, fpx[0])		*/
#define	STATEFRAME	0x6c	/* OFFSET(FP_CONTEXT, stateFrame[0])	*/

#if (CPU==MC68060)
#define	NULLFRAME	0x6e	/* MC68060 changed NULLFRAME field location! */
#else 
#define	NULLFRAME	0x6c	/* MC68881/MC68882/MC68040 NULLFRAME location */
#endif


#ifndef	_ASMLANGUAGE

#include "taskLib.h"

/* number of fp registers on coprocessor */

#define	FP_NUM_DREGS	8

/* maximum size of floating-point coprocessor state frame */

#define FP_STATE_FRAME_SIZE	216

typedef struct	/* DOUBLEX - double extended precision */
    {
    UINT8 f[12];
    } DOUBLEX;

typedef struct fpregSet			/* FPREG_SET */
    {
    int		fpcr;				/*			:   4 */
    int		fpsr;				/*			:   4 */
    int		fpiar;				/*			:   4 */
    DOUBLEX	fpx[FP_NUM_DREGS];		/* 8 extended doubles	:  96 */
    } FPREG_SET;

typedef struct fpContext	/* FP_CONTEXT */
    {
    FPREG_SET   fpRegSet;	/* floating-point register set */
    char	stateFrame[FP_STATE_FRAME_SIZE];/* coprocessor specific : 216 */
    } FP_CONTEXT;				/*	     	  TOTAL	: 326 */

#define FPX_OFFSET(n)	(FPX + (n)*sizeof(DOUBLEX))

/* variable declarations */

extern REG_INDEX fpRegName[];		/* f-point data register table */
extern REG_INDEX fpCtlRegName[];	/* f-point control register table */
extern WIND_TCB *pFppTaskIdPrevious;	/* task id for deferred exceptions */
extern FUNCPTR	 fppCreateHookRtn;	/* arch dependent create hook routine */
extern FUNCPTR	 fppDisplayHookRtn;	/* arch dependent display routine */


/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern void	fppArchInit (void);
extern void	fppArchTaskCreateInit (FP_CONTEXT *pFpContext);
extern STATUS 	fppProbeSup (void);
extern void	fppProbeTrap (void);
extern void 	fppDtoDx (DOUBLEX *pDx, double *pDouble);
extern void 	fppDxtoD (double *pDouble, DOUBLEX *pDx);

#else	/* __STDC__ */

extern void	fppArchInit ();
extern void	fppArchTaskCreateInit ();
extern STATUS	fppProbeSup ();
extern void	fppProbeTrap ();
extern void 	fppDtoDx ();
extern void 	fppDxToD ();

#endif	/* __STDC__ */

#endif	/* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCfppMc68kLibh */



