/* dbgPpcLib.h - header file for arch dependent portion of debugger */

/* Copyright 1984-1995 Wind River Systems, Inc. */

/*
modification history
--------------------
01f,09nov98,elg  added hardware breakpoints for PPC403
01e,14oct98,elg  added hardware breakpoints for PPC603 and PPC604
01d,27jul98,elg  added hardware breakpoints
01c,24dec97,dbt  modified for new breakpoint scheme.
01b,24oct95,kdl	 added DBG_TRACE=FALSE for PPC403; added mod hist.
01a,??may95,yao	 created.
*/

#ifndef __INCdbgPpcLibh
#define __INCdbgPpcLibh

#ifdef __cplusplus
extern "C" {
#endif

#include "esf.h"
#include "reg.h"
#ifndef _ASMLANGUAGE
#include "dsmLib.h"
#endif	/* _ASMLANGUAGE */
#include "iv.h"

#define	BREAK_ESF	ESFPPC		/* XXX */
#define	TRACE_ESF	ESFPPC		/* XXX */

#define DBG_BREAK_INST	0x7fe00008	/* trap 31, 0, 0 */

#if	(CPU == PPC403) 
#define DBG_NO_SINGLE_STEP	1	/* no trace support */
#endif 	/* CPU == PPC403 */

/* definition for HID1 register for 601 */
#define HID1_RUN_MODE(x)	(((x)&0x70000000)>>28)
#define HID1_RUN_NORM
#define HID1_RUN_UNDEF
#define HID1_RUN_UNDEF

#if 	(CPU == PPC603) || (CPU == PPCEC603) || (CPU == PPC604) || \
        (CPU == PPC860)
#define DBG_HARDWARE_BP	1

#define BRK_INST	0x0	/* hardware instruction breakpoint */
#define BRK_RW		0x1	/* hardware data breakpoint for read or write */
#define BRK_READ	0x2	/* hardware data breakpoint for read */
#define BRK_WRITE	0x3	/* hardware data breakpoint for write */

#define DEFAULT_HW_BP	BRK_RW	/* default hardware breakpoint */

#define BRK_HARDWARE	0x10	/* hardware breakpoint bit */
#define BRK_HARDMASK	0x0f	/* hardware breakpoint mask */

#elif	(CPU == PPC403)

#define DBG_HARDWARE_BP	1

#define BRK_INST	0x0	/* hardware instruction breakpoint */
#define BRK_DATAW1	0x1	/* data breakpoint for write one byte */
#define BRK_DATAR1	0x2	/* data breakpoint for read one byte */
#define BRK_DATARW1	0x3	/* data breakpoint for read/write one byte */
#define BRK_DATAW2	0x5	/* data breakpoint for write 2 bytes */
#define BRK_DATAR2	0x6	/* data breakpoint for read 2 bytes */
#define BRK_DATARW2	0x7	/* data breakpoint for read/write 2 bytes */
#define BRK_DATAW4	0x9	/* data breakpoint for write 4 bytes */
#define BRK_DATAR4	0xA	/* data breakpoint for read 4 bytes */
#define BRK_DATARW4	0xB	/* data breakpoint for read/write 4 bytes */
#define BRK_DATAW16	0xD	/* data breakpoint for write 16 bytes */
#define BRK_DATAR16	0xE	/* data breakpoint for read 16 bytes */
#define BRK_DATARW16	0xF	/* data breakpoint for read/write 16 bytes */

#define DEFAULT_HW_BP	BRK_DATAW1	/* default hardware breakpoint */

#define BRK_HARDWARE	0x10	/* hardware breakpoint bit */
#define BRK_HARDMASK	0x0f	/* hardware breakpoint mask */

#endif	/* (CPU == PPC403) */

#if	DBG_HARDWARE_BP

#ifndef _ASMLANGUAGE
typedef struct
    {
#if	(CPU == PPC860)
    UINT32	cmpa;		/* comparator A value register */
    UINT32	cmpb;		/* comparator B value register */
    UINT32 	cmpc;		/* comparator C value register */
    UINT32	cmpd;		/* comparator D value register */
    UINT32	counta;		/* breakpoint counter value register A */
    UINT32	countb;		/* breakpoint counter value register B */
    UINT32	cmpe;		/* comparator E value register */
    UINT32	cmpf;		/* comparator F value register */
    UINT32	cmpg;		/* comparator G value register */
    UINT32	cmph;		/* comparator H value register */
    UINT32	lctrl1;		/* load/store support comparators control reg */
    UINT32	lctrl2;		/* load/store support AND-OR control register */
    UINT32	ictrl;		/* instruction support control register */
    UINT32	bar;		/* breakpoint address register */

#elif	(CPU == PPC603) || (CPU == PPCEC603) || (CPU == PPC604)
    UINT32	iabr;		/* instruction address breakpoint register */
#if	(CPU == PPC604)
    UINT32	dabr;		/* data address breakpoint register */
    UINT32	dar;		/* data address register */
#endif	/* (CPU == PPC604) */

#elif	(CPU == PPC403)
    UINT32	dbcr;		/* debug control register */
    UINT32	dbsr;		/* debug status register */
    UINT32	dac1;		/* data address compare register 1 */
    UINT32	dac2;		/* data address compare register 2 */
    UINT32	iac1;		/* instruction address compare register 1 */
    UINT32	iac2;		/* instruction address compare register 2 */
    UINT32	msr;		/* machine state register */
#endif	/* (CPU == PPC403) */
    } DBG_REGS;

#if 	defined(__STDC__) || defined(__cplusplus)

#if	(CPU == PPC860)
IMPORT	void	dbgCmpaSet (int value);
IMPORT	void	dbgCmpbSet (int value);
IMPORT	void	dbgCmpcSet (int value);
IMPORT	void	dbgCmpdSet (int value);
IMPORT	void	dbgCmpeSet (int value);
IMPORT	void	dbgCmpfSet (int value);
IMPORT	void	dbgLctrl1Set (int value);
IMPORT	void	dbgLctrl2Set (int value);
IMPORT	void	dbgIctrlSet (int value);
IMPORT	int	dbgCmpaGet (void) ;
IMPORT	int	dbgCmpbGet (void) ;
IMPORT	int	dbgCmpcGet (void) ;
IMPORT	int	dbgCmpdGet (void) ;
IMPORT	int	dbgCmpeGet (void) ;
IMPORT	int	dbgCmpfGet (void) ;
IMPORT	int	dbgLctrl1Get (void) ;
IMPORT	int	dbgLctrl2Get (void) ;
IMPORT	int	dbgIctrlGet (void) ;

#elif	(CPU == PPC603) || (CPU == PPCEC603) || (CPU == PPC604)
IMPORT	void	wdbDbgIabrSet (int value);
IMPORT	int	wdbDbgIabrGet (void);
#if	(CPU == PPC604)
IMPORT	void	wdbDbgDabrSet (int value);
IMPORT	int	wdbDbgDabrGet (void);
IMPORT	int	wdbDbgDarGet (void);
#endif	/* (CPU == PPC604) */

#elif	(CPU == PPC403)
IMPORT	void	wdbDbgDbcrSet (int value);
IMPORT	int	wdbDbgDbcrGet (void);
IMPORT	void	wdbDbgDbsrSet (int value);
IMPORT	int	wdbDbgDbsrGet (void);
IMPORT	void	wdbDbgDac1Set (int value);
IMPORT	int	wdbDbgDac1Get (void);
IMPORT	void	wdbDbgDac2Set (int value);
IMPORT	int	wdbDbgDac2Get (void);
IMPORT	void	wdbDbgIac1Set (int value);
IMPORT	int	wdbDbgIac1Get (void);
IMPORT	void	wdbDbgIac2Set (int value);
IMPORT	int	wdbDbgIac2Get (void);
#endif	/* (CPU == PPC403) */
#else 	/* __STDC__ */
#if	(CPU == PPC860)
IMPORT	void	dbgCmpaSet ();
IMPORT	void	dbgCmpbSet ();
IMPORT	void	dbgCmpcSet ();
IMPORT	void	dbgCmpdSet ();
IMPORT	void	dbgCmpeSet ();
IMPORT	void	dbgCmpfSet ();
IMPORT	void	dbgLctrl1Set ();
IMPORT	void	dbgLctrl2Set ();
IMPORT	void	dbgIctrlSet ();
IMPORT	int	dbgCmpaGet () ;
IMPORT	int	dbgCmpbGet () ;
IMPORT	int	dbgCmpcGet () ;
IMPORT	int	dbgCmpdGet () ;
IMPORT	int	dbgCmpeGet () ;
IMPORT	int	dbgCmpfGet () ;
IMPORT	int	dbgLctrl1Get () ;
IMPORT	int	dbgLctrl2Get () ;
IMPORT	int	dbgIctrlGet () ;

#elif	(CPU == PPC603) || (CPU == PPCEC603) || (CPU == PPC604)
IMPORT	void	wdbDbgIabrSet ();
IMPORT	int	wdbDbgIabrGet ();
#if	(CPU == PPC604)
IMPORT	void	wdbDbgDabrSet ();
IMPORT	int	wdbDbgDabrGet ();
IMPORT	int	wdbDbgDarGet ();
#endif	/* (CPU == PPC604) */

#elif	(CPU == PPC403)
IMPORT	void	wdbDbgDbcrSet ();
IMPORT	int	wdbDbgDbcrGet ();
IMPORT	void	wdbDbgDbsrSet ();
IMPORT	int	wdbDbgDbsrGet ();
IMPORT	void	wdbDbgDac1Set ();
IMPORT	int	wdbDbgDac1Get ();
IMPORT	void	wdbDbgDac2Set ();
IMPORT	int	wdbDbgDac2Get ();
IMPORT	void	wdbDbgIac1Set ();
IMPORT	int	wdbDbgIac1Get ();
IMPORT	void	wdbDbgIac2Set ();
IMPORT	int	wdbDbgIac2Get ();
#endif	/* (CPU == PPC403) */
#endif 	/* __STDC__ */
#endif 	/* _ASMLANGUAGE */
#endif 	/* DBG_HARDWARE_BP */

#ifdef __cplusplus
}
#endif

#endif /* __INCdbgPpcLibh */
