/* cd1400.h - Cirrus Logic CL-CD1400 UXART header */

/* Copyright 1984-1996 Wind River Systems, Inc. */

/*
modification history
--------------------
01a,08aug94,caf  created.
*/

#ifndef __INCcd1400h
#define __INCcd1400h

#ifdef __cplusplus
extern "C" {
#endif

/*
This file contains constants for the Cirrus Logic CL-CD1400 Serial/Parallel
Controller (UXART).  The macros _UX_BASE_ADRS and _UX_REG_INTERVAL
must be defined when including this header.
*/

#ifndef _ASMLANGUAGE

#include "tyLib.h"

#define _UX_CAST (volatile unsigned char *)

/* device descriptors */

typedef struct                  /* TY_CO_DEV */
    {
    TY_DEV      tyDev;
    BOOL        created;        /* true if device has already been created */
    int         chan_num;       /* save channel number here also */
    int         int_vec;        /* channel interrupt vector base */
    int         numChannels;    /* number of channels on device */
    } TY_CO_DEV;

#else

#define _UX_CAST

#endif  /* _ASMLANGUAGE */

#ifndef _UX_ADRS        /* to permit alternative board addressing */
#define _UX_ADRS(reg)   (_UX_CAST (_UX_BASE_ADRS + (reg * _UX_REG_INTERVAL)))
#endif  /* _UX_ADRS */

/* global registers */

#define _UX_GFRCR       _UX_ADRS(0x40)  /* firmware revision code reg    R/W */
#define _UX_CAR         _UX_ADRS(0x68)  /* channel address reg           R/W */
#define _UX_GCR         _UX_ADRS(0x4b)  /* global configuration reg      R/W */
#define _UX_SVRR        _UX_ADRS(0x67)  /* service request reg            R  */
#define _UX_RICR        _UX_ADRS(0x44)  /* receive interrupting chan reg R/W */
#define _UX_TICR        _UX_ADRS(0x45)  /* xmit interrupting chan reg    R/W */
#define _UX_MICR        _UX_ADRS(0x46)  /* modem interrupting chan reg   R/W */
#define _UX_RIR         _UX_ADRS(0x6b)  /* receive interrupt reg         R/W */
#define _UX_TIR         _UX_ADRS(0x6a)  /* transmit interrupt reg        R/W */
#define _UX_MIR         _UX_ADRS(0x69)  /* modem interrupt reg           R/W */
#define _UX_PPR         _UX_ADRS(0x7e)  /* prescaler period reg          R/W */

/* virtual registers */

#define _UX_RIVR        _UX_ADRS(0x43)  /* receive interrupt vector reg   R  */
#define _UX_TIVR        _UX_ADRS(0x42)  /* transmit interrupt vector reg  R  */
#define _UX_MIVR        _UX_ADRS(0x41)  /* modem interrupt vector reg     R  */
#define _UX_TDR         _UX_ADRS(0x63)  /* transmit data reg              W  */
#define _UX_RDSR        _UX_ADRS(0x62)  /* receive data/status reg        R  */
#define _UX_MISR        _UX_ADRS(0x4c)  /* modem interrupt status reg     R  */
#define _UX_EOSRR       _UX_ADRS(0x60)  /* end of service request reg     W  */

/* channel registers */

#define _UX_LIVR        _UX_ADRS(0x18)  /* local interrupt vector reg    R/W */
#define _UX_CCR         _UX_ADRS(0x05)  /* channel command reg           R/W */
#define _UX_SRER        _UX_ADRS(0x06)  /* service request enable reg    R/W */
#define _UX_COR1        _UX_ADRS(0x08)  /* channel option reg 1          R/W */
#define _UX_COR2        _UX_ADRS(0x09)  /* channel option reg 2          R/W */
#define _UX_COR3        _UX_ADRS(0x0a)  /* channel option reg 3          R/W */
#define _UX_COR4        _UX_ADRS(0x1e)  /* channel option reg 4          R/W */
#define _UX_COR5        _UX_ADRS(0x1f)  /* channel option reg 5          R/W */
#define _UX_CCSR        _UX_ADRS(0x0b)  /* channel control status reg     R  */
#define _UX_RDCR        _UX_ADRS(0x0e)  /* received data count reg        R  */
#define _UX_SCHR1       _UX_ADRS(0x1a)  /* special character reg 1       R/W */
#define _UX_SCHR2       _UX_ADRS(0x1b)  /* special character reg 2       R/W */
#define _UX_SCHR3       _UX_ADRS(0x1c)  /* special character reg 3       R/W */
#define _UX_SCHR4       _UX_ADRS(0x1d)  /* special character reg 4       R/W */
#define _UX_SCRL        _UX_ADRS(0x22)  /* special character range, low  R/W */
#define _UX_SCRH        _UX_ADRS(0x23)  /* special character range, high R/W */
#define _UX_LNC         _UX_ADRS(0x24)  /* lnext character               R/W */
#define _UX_MCOR1       _UX_ADRS(0x15)  /* modem change option reg 1     R/W */
#define _UX_MCOR2       _UX_ADRS(0x16)  /* modem change option reg 2     R/W */
#define _UX_RTPR        _UX_ADRS(0x21)  /* receive time-out period reg   R/W */
#define _UX_MSVR1       _UX_ADRS(0x6c)  /* modem signal value reg 1      R/W */
#define _UX_MSVR2       _UX_ADRS(0x6d)  /* modem signal value reg 2      R/W */
#define _UX_PSVR        _UX_ADRS(0x6f)  /* printer signal value reg      R/W */
#define _UX_RBPR        _UX_ADRS(0x78)  /* receive baud rate period reg  R/W */
#define _UX_RCOR        _UX_ADRS(0x7c)  /* receive clock option reg      R/W */
#define _UX_TBPR        _UX_ADRS(0x72)  /* transmit baud rate period reg R/W */
#define _UX_TCOR        _UX_ADRS(0x76)  /* transmit clock option reg     R/W */

/* bit definitions */

/*****************************************************************************
* _UX_GCR                   global configuration reg      R/W                *
******************************************************************************/

#define _UX_GCR_PS          0x80

/*****************************************************************************
* _UX_SVRR                  service request reg            R                 *
******************************************************************************/

#define _UX_SVRR_SRM        0x04
#define _UX_SVRR_SRT        0x02
#define _UX_SVRR_SRR        0x01

/*****************************************************************************
* _UX_RIR                   receive interrupt reg         R/W                *
******************************************************************************/

#define _UX_RIR_RXIREQ      0x80
#define _UX_RIR_RBUSY       0x40
#define _UX_RIR_RUNFAIR     0x20
#define _UX_RIR_CH          0x03

/*****************************************************************************
* _UX_TIR                   transmit interrupt reg        R/W                *
******************************************************************************/

#define _UX_TIR_TXIREQ      0x80
#define _UX_TIR_TBUSY       0x40
#define _UX_TIR_TUNFAIR     0x20
#define _UX_TIR_CH          0x03

/*****************************************************************************
* _UX_MIR                   modem interrupt reg           R/W                *
******************************************************************************/

#define _UX_MIR_MDIREQ      0x80
#define _UX_MIR_MBUSY       0x40
#define _UX_MIR_MUNFAIR     0x20
#define _UX_MIR_CH          0x03

/*****************************************************************************
* _UX_RDSR                  receive data/status reg        R                 *
******************************************************************************/

#define _UX_RDSR_TIMEOUT    0x80
#define _UX_RDSR_SCDET2     0x40
#define _UX_RDSR_SCDET1     0x20
#define _UX_RDSR_SCDET0     0x10
#define _UX_RDSR_BREAK      0x08
#define _UX_RDSR_PE         0x04
#define _UX_RDSR_FE         0x02
#define _UX_RDSR_OE         0x01

/*****************************************************************************
* _UX_MISR                  modem interrupt status reg     R                 *
******************************************************************************/

#define _UX_MISR_DSRCH      0x80
#define _UX_MISR_CTSCH      0x40
#define _UX_MISR_RICH       0x20
#define _UX_MISR_CDCH       0x10

/*****************************************************************************
* _UX_CCR                   channel command reg           R/W                *
******************************************************************************/

/* format 1: reset channel command */

#define _UX_CCR_RESCHAN     0x80
#define _UX_CCR_FTF         0x02
#define _UX_CCR_TYPE        0x01

/* format 2: channel option register change command */

#define _UX_CCR_CORCHG      0x40
#define _UX_CCR_COR3        0x08
#define _UX_CCR_COR2        0x04
#define _UX_CCR_COR1        0x02

/* format 3: send special character command */

#define _UX_CCR_SENDSC      0x20
#define _UX_CCR_SSPC2       0x04
#define _UX_CCR_SSPC1       0x02
#define _UX_CCR_SSPC0       0x01

/* format 4: channel control command */

#define _UX_CCR_CHANCTL     0x10
#define _UX_CCR_XMTEN       0x08
#define _UX_CCR_XMTDIS      0x04
#define _UX_CCR_RCVEN       0x02
#define _UX_CCR_RCVDIS      0x01

/*****************************************************************************
* _UX_SRER                  service request enable reg    R/W                *
******************************************************************************/

#define _UX_SRER_MDMCH      0x80
#define _UX_SRER_RXDATA     0x10
#define _UX_SRER_TXRDY      0x04
#define _UX_SRER_TXMPTY     0x02
#define _UX_SRER_NNDT       0x01

/*****************************************************************************
* _UX_COR1                  channel option reg 1          R/W                *
******************************************************************************/

#define _UX_COR1_PARITY     0x80
#define _UX_COR1_PARM1      0x40
#define _UX_COR1_PARM0      0x20
#define _UX_COR1_IGNORE     0x10
#define _UX_COR1_1STOP      0x00
#define _UX_COR1_15STOP     0x04
#define _UX_COR1_2STOP      0x08
#define _UX_COR1_5DATA      0x00
#define _UX_COR1_6DATA      0x01
#define _UX_COR1_7DATA      0x02
#define _UX_COR1_8DATA      0x03

/*****************************************************************************
* _UX_COR2                  channel option reg 2          R/W                *
******************************************************************************/

#define _UX_COR2_IXM        0x80
#define _UX_COR2_TXIBE      0x40
#define _UX_COR2_ETC        0x20
#define _UX_COR2_LLM        0x10
#define _UX_COR2_RLM        0x08
#define _UX_COR2_RTSAO      0x04
#define _UX_COR2_CTSAE      0x02
#define _UX_COR2_DSRAE      0x01

/*****************************************************************************
* _UX_COR3                  channel option reg 3          R/W                *
******************************************************************************/

/* serial only */

#define _UX_COR3_SCDRNG     0x80
#define _UX_COR3_SCD34      0x40
#define _UX_COR3_FCT        0x20
#define _UX_COR3_SCD12      0x10

/*****************************************************************************
* _UX_COR4                  channel option reg 4          R/W                *
******************************************************************************/

#define _UX_COR4_IGNCR      0x80
#define _UX_COR4_ICRNL      0x40
#define _UX_COR4_INLCR      0x20
#define _UX_COR4_IGNBRK     0x10
#define _UX_COR4_BRKINT     0x08
#define _UX_COR4_PEH2       0x04
#define _UX_COR4_PEH1       0x02
#define _UX_COR4_PEH0       0x01

/*****************************************************************************
* _UX_COR5                  channel option reg 5          R/W                *
******************************************************************************/

#define _UX_COR5_ISTRIP     0x80
#define _UX_COR5_LNE        0x40
#define _UX_COR5_CMOE       0x20
#define _UX_COR5_EBD        0x04
#define _UX_COR5_ONLCR      0x02
#define _UX_COR5_OCRNL      0x01

/*****************************************************************************
* _UX_CCSR                  channel control status reg     R                 *
******************************************************************************/

/* serial only */

#define _UX_CCSR_RXFLOFF    0x40
#define _UX_CCSR_RXFLON     0x20
#define _UX_CCSR_TXFLOFF    0x04
#define _UX_CCSR_TXFLON     0x02

/* serial and parallel */

#define _UX_CCSR_RXEN       0x80
#define _UX_CCSR_TXEN       0x08

/*****************************************************************************
* _UX_MCOR1                 modem change option reg 1     R/W                *
******************************************************************************/

/* serial only */

#define _UX_MCOR1_DSRZD     0x80
#define _UX_MCOR1_CTSZD     0x40
#define _UX_MCOR1_RIZD      0x20
#define _UX_MCOR1_CDZD      0x10

/* parallel only */

#define _UX_MCOR1_PBUSYZD   0x80
#define _UX_MCOR1_PSLCTZD   0x40
#define _UX_MCOR1_PPEZD     0x20
#define _UX_MCOR1_PERRORZD  0x10

/*****************************************************************************
* _UX_MCOR2                 modem change option reg 2     R/W                *
******************************************************************************/

/* serial only */

#define _UX_MCOR2_DSROD     0x80
#define _UX_MCOR2_CTSOD     0x40
#define _UX_MCOR2_RIOD      0x20
#define _UX_MCOR2_CDOD      0x10

/* parallel only */

#define _UX_MCOR2_PBUSYOD   0x80
#define _UX_MCOR2_PSLCTOD   0x40
#define _UX_MCOR2_PPEOD     0x20
#define _UX_MCOR2_PERROROD  0x10

/*****************************************************************************
* _UX_MSVR1                 modem signal value reg 1      R/W                *
******************************************************************************/

#define _UX_MSVR1_DSR       0x80
#define _UX_MSVR1_CTS       0x40
#define _UX_MSVR1_RI        0x20
#define _UX_MSVR1_CD        0x10
#define _UX_MSVR1_PSTROBE   0x08
#define _UX_MSVR1_RTS       0x01

/*****************************************************************************
* _UX_MSVR2                 modem signal value reg 2      R/W                *
******************************************************************************/

#define _UX_MSVR2_DSR       0x80
#define _UX_MSVR2_CTS       0x40
#define _UX_MSVR2_RI        0x20
#define _UX_MSVR2_CD        0x10
#define _UX_MSVR2_PSTROBE   0x08
#define _UX_MSVR2_DTR       0x02

/*****************************************************************************
* _UX_PSVR                  printer signal value reg      R/W                *
******************************************************************************/

#define _UX_PSVR_PBUSY      0x80
#define _UX_PSVR_PSLCT      0x40
#define _UX_PSVR_PPE        0x20
#define _UX_PSVR_PERROR     0x10
#define _UX_PSVR_PACK       0x08
#define _UX_PSVR_PAUTOFD    0x04
#define _UX_PSVR_PINIT      0x02
#define _UX_PSVR_PSLIN      0x01

/*****************************************************************************
* _UX_RCOR                  receive clock option reg      R/W                *
******************************************************************************/

#define _UX_RCOR_CLK0       0x00
#define _UX_RCOR_CLK1       0x01
#define _UX_RCOR_CLK2       0x02
#define _UX_RCOR_CLK3       0x03
#define _UX_RCOR_CLK4       0x04

/*****************************************************************************
*  _UX_TCOR                 transmit clock option reg     R/W                *
******************************************************************************/

#define _UX_TCOR_CLK0       0x00
#define _UX_TCOR_CLK1       0x01
#define _UX_TCOR_CLK2       0x02
#define _UX_TCOR_CLK3       0x03
#define _UX_TCOR_CLK4       0x04

#ifdef __cplusplus
}
#endif

#endif /* __INCcd1400h */
