/* z8030.h - Zilog 8530 Serial Communications Controller header file */

/* Copyright 1984-1993 Wind River Systems, Inc. */
/*
modification history
--------------------
01a,24feb93,eve  started from version 01j of z8530.h.
*/

#ifndef __INCz8030h
#define __INCz8030h

#ifdef __cplusplus
extern "C" {
#endif

#ifndef	_ASMLANGUAGE

#include "tyLib.h"

/* device descriptors */

#ifndef	OLD_TY_CO_DRV
typedef struct		/* TY_CO_DEV */
    {
    TY_DEV tyDev;
    BOOL   created;		/* true if device has already been created */
    volatile char  *cr;		/* control register I/O address */
    volatile char  *dr;		/* data port I/O address */
    volatile char   intVec;	/* interrupt vector address */
    int    baudFreq;		/* baud clock frequency */
    char   numChannels;		/* number of channels to support */
    char   intType;		/* type of vector to supply from 8530 */
    char   clockModeWR11; 	/* write register 11 value to write */
    char   clockModeWR14; 	/* write register 14 value to write */
    } TY_CO_DEV;
#endif	/* OLD_TY_CO_DRV */

/* bit values for write register 0 */
/* command register */

#define	SCC_WR0_NULL_CODE	0x00
#define SCC_WR0_SHIFT_LEFT	0x02
#define SCC_WR0_SHIFT_RIGHT	0x03
#define	SCC_WR0_RST_INT		0x10
#define	SCC_WR0_SEND_ABORT	0x18
#define	SCC_WR0_EN_INT_RX	0x20
#define	SCC_WR0_RST_TX_INT	0x28
#define	SCC_WR0_ERR_RST		0x30
#define	SCC_WR0_RST_HI_IUS	0x38
#define	SCC_WR0_RST_RX_CRC	0x40
#define	SCC_WR0_RST_TX_CRC	0x80
#define	SCC_WR0_RST_TX_UND	0xc0

/* Registers mapping */

#define Z8030_WR0(base)    (( char *) (base) + 0x00) /* Command reg */
#define Z8030_WR1(base)    (( char *) (base) + 0x02) /* Int cond */
#define Z8030_WR2(base)    (( char *) (base) + 0x04) /* Int vector */
#define Z8030_WR3(base)    (( char *) (base) + 0x06) /* Rx params */
#define Z8030_WR4(base)    (( char *) (base) + 0x08) /* Rx/Tx misc params */
#define Z8030_WR5(base)    (( char *) (base) + 0x0a) /* Tx params */
#define Z8030_WR6(base)    (( char *) (base) + 0x0c) /* 1st sync char */
#define Z8030_WR7(base)    (( char *) (base) + 0x0e) /* 2nd sync char */
#define Z8030_WR8(base)    (( char *) (base) + 0x10) /* Tx buffer */
#define Z8030_WR9(base)    (( char *) (base) + 0x12) /* Master ctrl reg */
#define Z8030_WR10(base)   (( char *) (base) + 0x14) /* More misc params */
#define Z8030_WR11(base)   (( char *) (base) + 0x16) /* Clock mode reg */
#define Z8030_WR12(base)   (( char *) (base) + 0x18) /* Baud rate low */
#define Z8030_WR13(base)   (( char *) (base) + 0x1a) /* Baud rate high */ 
#define Z8030_WR14(base)   (( char *) (base) + 0x1c) /* Misc ctrl reg */ 
#define Z8030_WR15(base)   (( char *) (base) + 0x1e) /* Int status reg */ 


/* write register 2 */
/* interrupt vector */

/* bit values for write register 1 */
/* tx/rx interrupt and data transfer mode definition */

#define	SCC_WR1_EXT_INT_EN	0x01
#define	SCC_WR1_TX_INT_EN	0x02
#define	SCC_WR1_PARITY		0x04
#define	SCC_WR1_RX_INT_DIS	0x00
#define	SCC_WR1_RX_INT_FIR	0x08
#define	SCC_WR1_INT_ALL_RX	0x10
#define	SCC_WR1_RX_INT_SPE	0x18
#define	SCC_WR1_RDMA_RECTR	0x20
#define	SCC_WR1_RDMA_FUNC	0x40
#define	SCC_WR1_RDMA_EN		0x80

/* bit values for write register 3 */
/* receive parameters and control */

#define	SCC_WR3_RX_EN		0x01
#define	SCC_WR3_SYNC_CHAR	0x02
#define	SCC_WR3_ADR_SEARCH	0x04
#define	SCC_WR3_RX_CRC_EN	0x08
#define	SCC_WR3_ENTER_HUNT	0x10
#define	SCC_WR3_AUTO_EN		0x20
#define	SCC_WR3_RX_5_BITS	0x00
#define	SCC_WR3_RX_7_BITS	0x40
#define	SCC_WR3_RX_6_BITS	0x80
#define	SCC_WR3_RX_8_BITS	0xc0

/* bit values for write register 4 */
/* tx/rx misc parameters and modes */

#define	SCC_WR4_PAR_EN		0x01
#define	SCC_WR4_PAR_EVEN	0x02
#define	SCC_WR4_SYNC_EN		0x00
#define	SCC_WR4_1_STOP		0x04
#define	SCC_WR4_2_STOP		0x0c
#define	SCC_WR4_8_SYNC		0x00
#define	SCC_WR4_16_SYNC		0x10
#define	SCC_WR4_SDLC		0x20
#define	SCC_WR4_EXT_SYNC	0x30
#define	SCC_WR4_1_CLOCK		0x00
#define	SCC_WR4_16_CLOCK	0x40
#define	SCC_WR4_32_CLOCK	0x80
#define	SCC_WR4_64_CLOCK	0xc0

/* bit values for write register 5 */
/* transmit parameter and controls */

#define	SCC_WR5_TX_CRC_EN	0x01
#define	SCC_WR5_RTS		0x02
#define	SCC_WR5_SDLC		0x04
#define	SCC_WR5_TX_EN		0x08
#define	SCC_WR5_SEND_BRK	0x10

#define	SCC_WR5_TX_5_BITS	0x00
#define	SCC_WR5_TX_7_BITS	0x20
#define	SCC_WR5_TX_6_BITS	0x40
#define	SCC_WR5_TX_8_BITS	0x60
#define	SCC_WR5_DTR		0x80

/* write register 6 */
/* sync chars or sdlc address field */

/* write register 7 */
/* sync char or sdlc flag */

/* write register 8 */
/* transmit buffer */

/* bit values for write register 9 */
/* master interrupt control */

#define	SCC_WR9_VIS		0x01
#define	SCC_WR9_NV		0x02
#define	SCC_WR9_DLC		0x04
#define	SCC_WR9_MIE		0x08
#define	SCC_WR9_STATUS_HI	0x10
#define	SCC_WR9_NO_RST		0x00
#define	SCC_WR9_CH_B_RST	0x40
#define	SCC_WR9_CH_A_RST	0x80
#define	SCC_WR9_HDWR_RST	0xc0

/* bit values for write register 10 */
/* misc tx/rx control bits */

#define	SCC_WR10_6_BIT_SYNC	0x01
#define	SCC_WR10_LOOP_MODE	0x02
#define	SCC_WR10_ABORT_UND	0x04
#define	SCC_WR10_MARK_IDLE	0x08
#define	SCC_WR10_ACT_POLL	0x10
#define	SCC_WR10_NRZ		0x00
#define	SCC_WR10_NRZI		0x20
#define	SCC_WR10_FM1		0x40
#define	SCC_WR10_FM0		0x60
#define	SCC_WR10_CRC_PRESET	0x80

/* bit values for write register 11 */
/* clock mode control */

#define	SCC_WR11_OUT_XTAL	0x00
#define	SCC_WR11_OUT_TX_CLK	0x01
#define	SCC_WR11_OUT_BR_GEN	0x02
#define	SCC_WR11_OUT_DPLL	0x03
#define	SCC_WR11_TRXC_OI	0x04
#define	SCC_WR11_TX_RTXC	0x00
#define	SCC_WR11_TX_TRXC	0x08
#define	SCC_WR11_TX_BR_GEN	0x10
#define	SCC_WR11_TX_DPLL	0x18
#define	SCC_WR11_RX_RTXC	0x00
#define	SCC_WR11_RX_TRXC	0x20
#define	SCC_WR11_RX_BR_GEN	0x40
#define	SCC_WR11_RX_DPLL	0x60
#define	SCC_WR11_RTXC_XTAL	0x80

/* write register 12 */
/* lower byte of baud rate generator time constant */

/* write register 13 */
/* upper byte of baud rate generator time constant */

/* bit values for write register 14 */
/* misc control bits */

#define	SCC_WR14_BR_EN		0x01
#define	SCC_WR14_BR_SRC		0x02
#define	SCC_WR14_DTR_FUNC	0x04
#define	SCC_WR14_AUTO_ECHO 	0x08
#define	SCC_WR14_LCL_LOOP	0x10
#define	SCC_WR14_NULL		0x00
#define	SCC_WR14_SEARCH		0x20
#define	SCC_WR14_RST_CLK	0x40
#define	SCC_WR14_DIS_DPLL	0x60
#define	SCC_WR14_SRC_BR		0x80
#define	SCC_WR14_SRC_RTXC	0xa0
#define	SCC_WR14_FM_MODE	0xc0
#define	SCC_WR14_NRZI		0xe0

/* bit values for write register 15 */
/* external/status interrupt control */

#define	SCC_WR15_ZERO_CNT	0x02
#define	SCC_WR15_CD_IE		0x08
#define	SCC_WR15_SYNC_IE	0x10
#define	SCC_WR15_CTS_IE		0x20
#define	SCC_WR15_TX_UND_IE	0x40
#define	SCC_WR15_BREAK_IE	0x80

/* bit values for read register 0 */
/* tx/rx buffer status and external status  */

#define	SCC_RR0_RX_AVAIL	0x01
#define	SCC_RR0_ZERO_CNT	0x02
#define	SCC_RR0_TX_EMPTY	0x04
#define	SCC_RR0_CD		0x08
#define	SCC_RR0_SYNC		0x10
#define	SCC_RR0_CTS		0x20
#define	SCC_RR0_TX_UND		0x40
#define	SCC_RR0_BREAK		0x80

/* bit values for read register 1 */

#define	SCC_RR1_ALL_SENT	0x01
#define	SCC_RR1_RES_CD_2	0x02
#define	SCC_RR1_RES_CD_1	0x01
#define	SCC_RR1_RES_CD_0	0x08
#define	SCC_RR1_PAR_ERR		0x10
#define	SCC_RR1_RX_OV_ERR	0x20
#define	SCC_RR1_CRC_ERR		0x40
#define	SCC_RR1_END_FRAME	0x80

/* read register 2 */
/* interrupt vector */

/* bit values for read register 3 */
/* interrupt pending register */

#define	SCC_RR3_B_EXT_IP	0x01
#define	SCC_RR3_B_TX_IP		0x02
#define	SCC_RR3_B_RX_IP		0x04
#define	SCC_RR3_A_EXT_IP	0x08
#define	SCC_RR3_A_TX_IP		0x10
#define	SCC_RR3_A_RX_IP		0x20

/* read register 8 */
/* receive data register */

/* bit values for read register 10 */
/* misc status bits */

#define	SCC_RR10_ON_LOOP	0x02
#define	SCC_RR10_LOOP_SEND	0x10
#define	SCC_RR10_2_CLK_MIS	0x40
#define	SCC_RR10_1_CLK_MIS	0x80

/* read register 12 */
/* lower byte of time constant */

/* read register 13 */
/* upper byte of time constant */

/* bit values for read register 15 */
/* external/status ie bits */

#define	SCC_RR15_ZERO_CNT	0x02
#define	SCC_RR15_CD_IE		0x08
#define	SCC_RR15_SYNC_IE	0x10
#define	SCC_RR15_CTS_IE		0x20
#define	SCC_RR15_TX_UND_IE	0x40
#define	SCC_RR15_BREAK_IE	0x80

/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

IMPORT	void	tyCoIntWr (int channel);
IMPORT	void	tyCoIntRd (int channel);
IMPORT	void	tyCoIntEx (int channel);
IMPORT	void	tyCoInt (int channel);

#else

IMPORT	void	tyCoIntWr ();
IMPORT	void	tyCoIntRd ();
IMPORT	void	tyCoIntEx ();
IMPORT	void	tyCoInt ();

#endif	/* __STDC__ */

#endif	/* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCz8030h */
