/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCos_lsdh
#define __INCos_lsdh

/****************************************
os_lsd.h:

link state pdu strcutures 

copyright phase2 networks 1994
all rights reserved


SID: 1.7
Revision History:


    1.7	96/02/06 22:29:58 root
	extern api mods

    1.6	96/01/10 08:40:06 root
	add tag field to ase

    1.5	95/11/27 13:37:11 root
	multiple incarnation support

    1.4	95/11/09 09:45:06 root
	add mospf

    1.3	95/05/02 14:19:25 root
	add tos

    1.2	95/03/13 16:18:39 root
	change i_delete to i_flags

    1.1	94/12/04 09:38:22 root
	date and time created 94/12/04 09:38:22 by root


****************************************/

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

/**************************************

a raw link state advertisement header

**************************************/
#define LSA_HLEN 20
typedef struct lsa_hdr {
    byte		ls_age[2];
    byte		ls_opt;
    byte		ls_type;
    byte		ls_id[4];
    byte		ls_artr[4];
    byte		ls_seq[4];
    byte		ls_csum[2];
    byte		ls_len[2];
}LSA, *lsa_pt;

/* lsa types */
#define LST_RTR	1		/* router links */
#define LST_NET	2		/* network links */
#define LST_SUMNET	3		/* summary network */
#define LST_SUMASB	4		/* summary as bdr */
#define LST_ASEXT	5		/* as external */
#define LST_MCG		6		/* multicast group */

/* router links types */
#define RLT_P2P	1		/* point 2 point */
#define RLT_TRNET	2		/* transit net */
#define RLT_STUB	3		/* stub net */
#define RLT_VLNK	4		/* virtual link */

/* router links lsa flags */
#define AFLAG_V	4		/* endpoint active vlink */
#define AFLAG_E	2		/* is as border router */
#define AFLAG_B	1		/* is area border router */
#define AFLAG_W	8		/* mospf wild card */

/* router links header */
#define RTR_LINKS_HLEN (LSA_HLEN+4)
typedef struct rtr_link_hdr{
	byte		unused[LSA_HLEN];
	byte		flags;
	byte		zero;
	byte		cnt[2];
}RTR_LINKS_HDR,*rlinks_hdr_pt;

/* router links entry */
#define RLINK_SIZE 12
typedef struct rtr_link{
	byte		lid[4];		/* link ID */
	byte		ldata[4];		/* link data */
	byte		type;
	byte		numtos;
	byte		met[2];
}RTR_LINK, *rlink_pt;
#define RLINK_FWD(x)  \
   (rlink_pt)(((byte *)(x)) + 12 + ((x)->numtos << 2))

/* network links entry */
#define NET_LINKS_HLEN (LSA_HLEN +4)
typedef struct net_link{
	byte		unused[LSA_HLEN];
	byte 	mask[4];
}NET_LINK, *nlink_pt;
#define NLCNT(xlsa) ((n2u16(xlsa->ls_len)-NET_LINKS_HLEN) >>2)

/* sumary links entry */
#define SUM_LINK_HLEN (LSA_HLEN + 8)
typedef struct sum_link{
	byte 	unused[LSA_HLEN];
	byte		mask[4];
	byte		tos;
	byte		met[3];
}SUM_LINK, *slink_pt;

/* as external link entry */
#define EXT_LINK_HLEN (LSA_HLEN + 16)
typedef struct ext_link{
	byte		unused[LSA_HLEN];
	byte		mask[4];
	byte		tos;
	byte		met[3];
	byte		fwd[4];
	byte		tag[4];
}EXT_LINK, *elink_pt;

#define ASE_EXTTYPE	0x80		/* in tos */

/* lsa ack types from spec table 19 */
#define LSACK_IGNORE -1
#define LSACK_BAD	-2
#define LSACK1		1
#define LSACK2		2
#define LSACK3		3
#define LSACK4		4
#define LSACK5		5
/************************************************

		structures for received lsas 

************************************************/

/* a summary of information about a received lsa,
   these are stored in a hashed linked list  */

typedef struct lsa_info{

	struct	lsa_info	*i_fwd;  /* hash links */
	struct	lsa_info	*i_bwd;
	struct 	lsa_info	*i_sfwd; /*sorted links*/
	struct	lsa_info	*i_sbwd;
	struct	lsa_hdr		*i_lsa;  /* lsa itself */
	struct	area		*i_area;
	boolean			i_flags;	/* del flg  */
	int			i_ref_count;    /* reference count, for deletion */
	struct ospf_timer	*i_tid;	/* timeout/refresh tid*/
	int				i_mlen;		/* max len allowed*/
	word				i_life;
	dword			i_id;
	dword			i_rtr;
	sdword			i_seq;
	word				i_csum;
	dword			i_rxtime;		/* arrival time */
	word				i_orgage;		/* age at arrival */
}LSAI, *lsai_pt;

/* compute current age of lsa, this is done because
   we dont increment the age of each individual lsa
   each tic since doing so would entail too much
   processing.
*/

#define LS_CURR_AGE(xlsai,xage) {\
	if( ospfNode->n_tics >= xlsai->i_rxtime ){		\
		xage = (word)(ospfNode->n_tics - xlsai->i_rxtime);	\
	}										\
	else{	/* wrap */						\
		xage = (word)(ospfNode->n_tics - xlsai->i_rxtime);	\
	}										\
	xage += xlsai->i_orgage;						\
	if(xage > LS_MAXAGE) xage = LS_MAXAGE;			\
}

/* flags */
#define LSA_DELETE		1
#define LSA_WRAP		2
#define LSA_DELMSK		3
#define LSA_MOD		4	/* changed, for incr spf */

/******************************************************

same as above, but also contains a path entry. Used for
router links lsa only. This is because paths to border
routers need to be stored independent of SPF run. The
reason we only do this for router links is because to
do this for all lsas would be too much overhead.

Also holds links for storage of AS border router list.
******************************************************/
typedef struct rl_lsa_info{
	LSAI				rl_info;
	PATHENT			rl_pe;
	struct rl_lsa_info	*rl_asbr_fwd;
	struct rl_lsa_info	*rl_asbr_bwd;
}RL_LSAI, *rl_lsai_pt;

#define RL_VALID 1
#define RL_INVALID 0

/**************************************************

a header for locally generated summary lsas.

header contains
info about the router summary. this info is the
same independent of what areas the lsa is injected into.
the lsa themselves are injected into areas depending
on filters, eg. whether the origin is the area,etc.

**************************************************/
typedef struct lsa_summ_hdr{
	struct lsa_summ_hdr	*s_fwd;	/* links */
	struct lsa_summ_hdr	*s_bwd;	/* links */
	struct area		*s_area;  /* src */
	struct area		*s_nharea; /* next hop */
	struct area		*s_oldnharea; /* next hop */
	int				 s_flag;	/* for updates */
	IPNA			 s_net;	/* dest net/rtr */
	int				 s_type;	/* 3 or 4 */
	int				 s_intra;	/* intra/inter */
	dword			 s_cost;
	dword			 s_oldcost;
#if ALL_METRICS
	dword			 s_tcost[NUM_OSNH-1];	/* tos */
	dword			 s_oldtcost[NUM_OSNH-1];	/* tos */
#endif
} SUMM_HDR, *summ_hdr_pt;

#define SH_INTRA	1
#define SH_INTER	2
#define SHF_UNSEEN	0
#define SHF_SEEN	1		/* not modified */
#define SHF_MOD	2		/* modified */
#define SHF_NEW	3

/* results of lsa comparison */
#define LSA_NEWER	1
#define LSA_SAME	0
#define LSA_OLDER	-1

/***********************************************
a header for routes imported from another
domain (eg AS EXTERNALs).
***********************************************/

typedef struct as_ext_hdr{
	struct as_ext_hdr		*e_fwd;	/* links */
	struct as_ext_hdr		*e_bwd;
	IPNA					e_net;	/* addr/mask */
	int					 e_cost;	/* metric */
	int					 e_type;  /* ext type 1/2 */
	int					 e_state;
	ipa					 e_nh;	/* next hop */
	ipa					 e_tag;	/* route tag */
} ASE_HDR, *ase_hdr_pt;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#define ASE_TYPE1		1	/* use ospf metric space */
#define ASE_TYPE2		2	/* use extern metric space */
#define ASE_STATE_OFF	1
#define ASE_STATE_ON	2

#endif /* __INCos_lsdh */
