/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCos_struch
#define __INCos_struch

/************************************************
os_struc.h

primary OSPF structures: main node, area,etc 


copyright phase2 networks inc, 1994
all rights reserved

SID: 1.9
Revision History:


    1.9	96/03/29 09:56:29 root
	midnight tests

    1.8	96/02/22 22:10:05 root
	move externally visible constants from here

    1.7	96/02/06 22:30:37 root
	extern api mods

    1.6	95/11/27 13:37:18 root
	multiple incarnation support

    1.5	95/11/09 09:45:35 root
	add mospf

    1.4	95/10/03 14:33:22 root
	move authfail cntr to intf

    1.3	95/05/02 14:19:48 root
	add tos

    1.2	95/01/02 17:43:03 root
	final test

    1.1	94/12/04 09:38:40 root
	date and time created 94/12/04 09:38:40 by root

************************************************/



/* max lsa sizes (that we build) */
#define MAX_LSA_SIZE	1500 - 20 - 28
#define MAX_SUMLSA_SIZE	24 + 64
#define MAX_ASELSA_SIZE  24 + (12 * 16)

#if P2_MOSPF
#define LSA_MAX_TYPE 6
#else
#define LSA_MAX_TYPE 5
#endif

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

typedef struct lsa_hash{
	DLL				lh_bin[LSD_HASHES];
}LSA_HASH;

/* the area struct */
typedef struct area {
	struct area			*a_fwd;
	struct area			*a_bwd;
    ipa					a_id;
	dword				a_flags;
	LSA_HASH			a_lsa[LSA_MAX_TYPE+1];
	lsai_pt				a_mylsd;
	int					a_transit;
	int					a_cnctd;		/* vc to all bdr */
	struct circuit		*a_circ_fwd;	/* phys links */
	struct circuit		*a_circ_bwd;	/* phys links */
	struct circuit		*a_vc_fwd;	/* virtual links*/
	struct circuit		*a_vc_bwd;	/* virtual links*/
	int					a_stub;		/* stub area? */
	unsigned int			a_stub_cost;	/* stub area cost */
	int					a_auth_type;	/* authorize type */
	struct cfg_range	*a_cfgr_fwd;	/* configd ranges */
	struct cfg_range	*a_cfgr_bwd;	/* configd ranges */
	struct lsa_info		*a_lsort_fwd;	/* sorted lsas */
	struct lsa_info		*a_lsort_bwd;
	int					a_spf_runs;	/* counter */
	int					a_num_abdr;	/* counter */
	int				 	a_num_asbdr;	/* counter */
	int				 	a_mospf_runs;
}AREA, *area_pt;

/* the main ospf data structure */
typedef struct ospf_node{
	dword				n_tics;		/* global timer*/
	int					n_state;		/* ospf on/off */
	int					n_initdone;	/* completed init */
	struct ospf_timer	*n_timer_fwd;	/* system timers */
	struct ospf_timer	*n_timer_bwd;	/* system timers */
	ipa					n_rtid;		/* router ID */
	int					n_msplit;		/* path splits */
	struct pathent_blk	*n_pe_base;	/* first peb */
	struct pathent_blk	*n_pe_curr;	/* curr peb */
	int					n_pe_max;
	int					n_next_pent;
	int					n_runspf;		/* pend run type*/
	LSA_HASH			*n_elsa;		/* extern lsas */
	struct lsa_info		*n_asesort_fwd; /* sort externlsa */
	struct lsa_info		*n_asesort_bwd; /* sort externlsa */
	struct rl_lsa_info	*n_asbr_fwd;	/* AS bdr list */
	struct rl_lsa_info	*n_asbr_bwd;	/* AS bdr list */
	struct area			*n_area_fwd;	/* area list */
	struct area			*n_area_bwd;
	int					n_im_abdr;	/* ? area border */
	int					n_im_asbdr;	/* AS border ?*/
	int					n_num_act_area;
	struct area			*n_bbarea;	/* backbone */
	struct lsa_summ_hdr	*n_summ_fwd;	/* local summs */
	struct lsa_summ_hdr	*n_summ_bwd;	/* local summs */
	struct as_ext_hdr	*n_ase_fwd;	/* extern routes */
	struct as_ext_hdr	*n_ase_bwd;	/* extern routes */
	int					n_auto_vlnk;	/* auto make virt*/
	int					n_tos;		/* does TOS?*/
	dword				n_txnewlsa;
	dword				n_rxnewlsa;
	int					n_cmove;		/* circ change */
	int                 n_need_dr;      /* need to elect DR */
	int					n_chk_delack;	/* delayed ack */
	int					n_trnbr;		/* trace flag */
	int					n_trlsa;		/* trace flag */
	int					n_trdr;		/* trace dr */
	int					n_af_nbr;		/* alloc fails */
	int					n_af_lsa;		/* alloc fails */
	int					n_af_lsd;		/* alloc fails */
	int					n_af_dbr;		/* alloc fails */
	int					n_af_rtx;		/* alloc fails */
	int					n_af_ack;		/* alloc fails */
	int					n_af_dbp;		/* alloc fails */
	struct host_rt		*n_host_fwd;	/* host routes */
	struct host_rt		*n_host_bwd;	/* host routes */
	int					n_mospfenl;
	int					n_mospfiafwd;	/*interareafwd*/
	int					n_spfhold;		/* min time between spf */
	int					n_spftime;		/* min time to next spf */
	int					n_spfcnt;		/* suspend count */
	int					n_spfccnt;

	/* ONLY EMBEDDED STUCTS BEYOND HERE */
	LSA_HASH			n_elsa_area;	/* extern lsas */
	struct area			n_bbarea_area;	/* backbone */
	struct circuit			*n_circ_hash[256];
}OSPF_NODE;
#define MY_RTID ospfNode->n_rtid
#define OSPF_OFF	1
#define OSPF_ON	2
#define OSPF_ONREQ	3

/* configured address range for an area */
typedef struct cfg_range{
	struct cfg_range	*r_fwd;		/* links */
	struct cfg_range	*r_bwd;
	IPNA				 r_ipaddr;	/* net/mask */
	int				 r_adv;
}CFG_RANGE, *cfg_range_pt;

#define IS_BACKBONE(a) ( (a) == ospfNode->n_bbarea)

#define T_OPT	1
#define E_OPT	2
#define MC_OPT	4

/* timer struct:
   we make an order linked list with expiration time
   to first entry kept separate. each entry then
   contains a delta time relative to previous.
*/
typedef struct ospf_timer{
	struct ospf_timer	*t_fwd; 	/* link */
	struct ospf_timer	*t_bwd; 	/* link */

					/* pointer to callback fnc to
					   call on expiration */
	void				*(*t_callback)();

					/* a pointer to a generic struct,
					   passed as param to callback */
	void				*t_param;
	int				 t_delta;	/* delta ttl */

					/* original time, used for cyclic
					   timers. */
	int				 t_time;
	int				 t_type;		/* cycle or 1shot */
}OTIMER, *otimer_pt;

#define TTYPE_ONESHOT	1
#define TTYPE_CYCLIC	2


/* host route structure */
typedef struct host_rt{
	struct host_rt		*h_fwd;
	struct host_rt		*h_bwd;
	ipa				h_host;
	unsigned int		h_cost;
	area_pt			h_area;
}HOST_RT;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#endif /* __INCos_struch */
