/* ospfLib.h - ospf library header */

/* Copyright 1990-1997 Wind River Systems, Inc. */

/*
modification history
-------------------------
01e,29dec97,rjc added prototype for ospfTerminate
01f,10dec97,rjc added some missing prototypes
01e,12aug97,rjc cleanup after code review
01d,30jun97,rjc removed unused define values.
01c,30apr97,rjc added error values.
01b,14apr97,rjc added m2 defines and updated prototypes.
01a,05dec96,rjc written
*/

/*
 * This file contains the structure definitions used for configuring
 * ospf, along with prototypes used for manipulating these structures,
 * and other entry points into the ospf module.
 */

#ifndef _INCospfLibh
#define _INCospfLibh

#ifdef __cplusplus
extern "C" {
#endif

#define S_ospfLib_MCAST_GROUP_FAILED        (M_ospfLib | 1)
#define S_ospfLib_LOOPBACK_DISABLE_FAILED   (M_ospfLib | 2)
#define S_ospfLib_MCAST_IF_SELECT_FAILED    (M_ospfLib | 3)
#define S_ospfLib_CIRC_CREATE_FAILED        (M_ospfLib | 4)
#define S_ospfLib_NBMA_DST_ADD_FAILED       (M_ospfLib | 5)
#define S_ospfLib_NBMA_DST_DELETE_FAILED    (M_ospfLib | 6)
#define S_ospfLib_EXT_ROUTE_ADD_FAILED      (M_ospfLib | 7)
#define S_ospfLib_EXT_ROUTE_DELETE_FAILED   (M_ospfLib | 8)


/* Defined values for ospfAdminStat */
#define M2_ospfAdminStat_enabled        1
#define M2_ospfAdminStat_disabled       2

/* Defined values for ospfVersionNumber */
#define M2_ospfVersionNumber_version2   2

/* Defined values for ospfAreaBdrRtrStatus */
#define M2_ospfAreaBdrRtrStatus_true    1
#define M2_ospfAreaBdrRtrStatus_false   2

/* Defined values for ospfASBdrRtrStatus */
#define M2_ospfASBdrRtrStatus_true      1
#define M2_ospfASBdrRtrStatus_false     2

/* Defined values for ospfTOSSupport */
#define M2_ospfTOSSupport_true          1
#define M2_ospfTOSSupport_false         2

/* Defined values for ospfImportASExtern */
#define M2_ospfImportASExtern_true      1
#define M2_ospfImportASExtern_false     2

/* Defined values of ospfAuthType */
#define M2_ospfAuthType_none            0
#define M2_ospfAuthType_simplePassword  1

/* Defined values for ospfStubStatus */
#define M2_ospfStubStatus_valid         1
#define M2_ospfStubStatus_invalid       2

/* Defined values for ospfLsdbType */
#define M2_ospfLsdbType_routerLink      1
#define M2_ospfLsdbType_networkLink     2
#define M2_ospfLsdbType_summaryLink     3
#define M2_ospfLsdbType_asSummaryLink   4
#define M2_ospfLsdbType_asExternalLink  5

/* Defined values for ospfAreaRangeStatus */
#define M2_ospfAreaRangeStatus_valid    1
#define M2_ospfAreaRangeStatus_invalid  2

/* Defined values for ospfHostStatus */
#define M2_ospfHostStatus_valid         1
#define M2_ospfHostStatus_invalid       2

/* Defined values for ospfIfType */
#define M2_ospfIfType_broadcast         1
#define M2_ospfIfType_nbma              2
#define M2_ospfIfType_pointToPoint      3

/* Defined values for ospfIfAdminStat */
#define M2_ospfIfAdminStat_enabled      1
#define M2_ospfIfAdminStat_disabled     2

/* Defined values for ospfIfState */
#define M2_ospfIfState_down             1
#define M2_ospfIfState_loopback         2
#define M2_ospfIfState_waiting          3
#define M2_ospfIfState_pointToPoint     4
#define M2_ospfIfState_designatedRouter 5
#define M2_ospfIfState_backupDesignatedRouter 6
#define M2_ospfIfState_otherDesignatedRouter 7

/* Defined values for ospfIfMetricStatus */
#define M2_ospfIfMetricStatus_valid     1
#define M2_ospfIfMetricStatus_invalid   2

/* Defined values for ospfVirtIfState */
#define M2_ospfVirtIfState_down         1
#define M2_ospfVirtIfState_pointToPoint 4

/* Defined values for ospfVirtIfStatus */
#define M2_ospfVirtIfStatus_valid       1
#define M2_ospfVirtIfStatus_invalid     2

/* Defined values for ospfNbrState */
#define M2_ospfNbrState_down            1
#define M2_ospfNbrState_attempt         2
#define M2_ospfNbrState_init            3
#define M2_ospfNbrState_twoWay          4
#define M2_ospfNbrState_exchangeStart   5
#define M2_ospfNbrState_exchange        6
#define M2_ospfNbrState_loading         7
#define M2_ospfNbrState_full            8

/* Defined values for ospfNBMANbrStatus */
#define M2_ospfNBMANbrStatus_valid      1
#define M2_ospfNBMANbrStatus_invalid    2

/* Defined values for ospfVirtNbrState */
#define M2_ospfVirtNbrState_down        1
#define M2_ospfVirtNbrState_attempt     2
#define M2_ospfVirtNbrState_init        3
#define M2_ospfVirtNbrState_twoWay      4
#define M2_ospfVirtNbrState_exchangeStart 5
#define M2_ospfVirtNbrState_exchange    6
#define M2_ospfVirtNbrState_loading     7
#define M2_ospfVirtNbrState_full        8

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

/*
 * The ospfGeneralGroup family. 
 */


typedef struct {
        unsigned long   ospfRouterId;
        long            ospfAdminStat;
        long            ospfVersionNumber;
        long            ospfAreaBdrRtrStatus;
        long            ospfASBdrRtrStatus;
        unsigned long   ospfExternLSACount;
        long            ospfExternLSACksumSum;
        long            ospfTOSSupport;
        unsigned long   ospfOriginateNewLSAs;
        unsigned long   ospfRxNewLSAs;
} M2_OSPF_GENERAL_GROUP;

/* bit fields for ospf general group */
#define M2_OSPF_ROUTER_ID                 0x1
#define M2_OSPF_ADMIN_STAT                0x2
#define M2_OSPF_AS_BDR_RTR_STATUS        0x4
#define M2_OSPF_TOS_SUPPORT             0x8


/*
 * The ospfAreaEntry family. 
 */

typedef struct  {
        unsigned long   ospfAreaId;
        long            ospfAuthType;
        long            ospfImportASExtern;
        unsigned long   ospfSpfRuns;
        unsigned long   ospfAreaBdrRtrCount;
        unsigned long   ospfASBdrRtrCount;
        unsigned long   ospfAreaLSACount;
        long            ospfAreaLSACksumSum;
} M2_OSPF_AREA_ENTRY;


/* bit fields for area entry */

#define M2_OSPF_AREA_ID               0x1
#define M2_OSPF_AUTH_TYPE             0x2
#define M2_OSPF_IMPORT_AS_EXTERN      0x4 

/*
 * The ospfStubAreaEntry family. 
 */


typedef struct {
        unsigned long   ospfStubAreaID;
        long            ospfStubTOS;
        long            ospfStubMetric;
        long            ospfStubStatus;
} M2_OSPF_STUB_AREA_ENTRY;

#define M2_OSPF_STUB_AREA_ID        0x1
#define M2_OSPF_STUB_TOS          0x2
#define M2_OSPF_STUB_METRIC         0x4
#define M2_OSPF_STUB_STATUS         0x8

/*
 * The ospfLsdbEntry family. 
 */


typedef struct  {
        unsigned long   ospfLsdbAreaId;
        long            ospfLsdbType;
        unsigned long   ospfLsdbLSID;
        unsigned long   ospfLsdbRouterId;
        long            ospfLsdbSequence;
        long            ospfLsdbAge;
        long            ospfLsdbChecksum;
        unsigned char   ospfLsdbAdvertisement [M2DISPLAYSTRSIZE];
	int             adLen;    /* length of ospfLsdbAdvertisement */
} M2_OSPF_LSDB_ENTRY;



/*
 * The ospfAreaRangeEntry family. 
 */


typedef struct {
        unsigned long   ospfAreaRangeAreaID;
        unsigned long   ospfAreaRangeNet;
        unsigned long   ospfAreaRangeMask;
        long            ospfAreaRangeStatus;
} M2_OSPF_AREA_RANGE_ENTRY;

#define M2_OSPF_AREA_RANGE_AREA_ID     0x1
#define M2_OSPF_AREA_RANGE_NET         0x2
#define M2_OSPF_AREA_RANGE_MASK        0x4
#define M2_OSPF_AREA_RANGE_STATUS      0x8


/*
 * The ospfHostEntry family. 
 */


typedef
struct {
        unsigned long   ospfHostIpAddress;
        long            ospfHostTOS;
        long            ospfHostMetric;
        long            ospfHostStatus;

} M2_OSPF_HOST_ENTRY;

#define M2_OSPF_HOST_IP_ADDRESS     0x1
#define M2_OSPF_HOST_TOS            0x2
#define M2_OSPF_HOST_METRIC         0x4
#define M2_OSPF_HOST_STATUS         0x8


/*
 * The ospfIfEntry family. 
 */


typedef struct {
        unsigned long   ospfIfIpAddress;
        long            ospfAddressLessIf;
        unsigned long   ospfIfAreaId;
        long            ospfIfType;
        long            ospfIfAdminStat;
        long            ospfIfRtrPriority;
        long            ospfIfTransitDelay;
        long            ospfIfRetransInterval;
        long            ospfIfHelloInterval;
        long            ospfIfRtrDeadInterval;
        long            ospfIfPollInterval;
        long            ospfIfState;
        unsigned long   ospfIfDesignatedRouter;
        unsigned long   ospfIfBackupDesignatedRouter;
        unsigned long   ospfIfEvents;
        unsigned char   ospfIfAuthKey [M2DISPLAYSTRSIZE];
	int             keyLen;  /* length of ospfIfAuthKey*/
   
} M2_OSPF_IF_ENTRY;

#define M2_OSPF_IF_AREA_ID                      0x1
#define M2_OSPF_IF_ADMIN_STAT                   0x2
#define M2_OSPF_IF_RTR_PRIORITY                 0x4
#define M2_OSPF_IF_TRANSIT_DELAY                0x8
#define M2_OSPF_IF_RETRANS_INTERVAL             0x10
#define M2_OSPF_IF_HELLO_INTERVAL               0x20
#define M2_OSPF_IF_RTR_DEAD_INTERVAL            0x40
#define M2_OSPF_IF_POLL_INTERVAL                0x80
#define M2_OSPF_IF_AUTH_KEY                     0x100


/*
 * The ospfIfMetricEntry family. 
 */


typedef struct {
        unsigned long   ospfIfMetricIpAddress;
        long            ospfIfMetricAddressLessIf;
        long            ospfIfMetricTOS;
        long            ospfIfMetricMetric;
        long            ospfIfMetricStatus;
} M2_OSPF_IF_METRIC_ENTRY;

#define M2_OSPF_IF_METRIC_METRIC             0x1
#define M2_OSPF_IF_METRIC_STATUS             0x2


/*
 * The ospfVirtIfEntry family. 
 */


typedef struct {
        unsigned long   ospfVirtIfAreaID;
        unsigned long   ospfVirtIfNeighbor;
        long            ospfVirtIfTransitDelay;
        long            ospfVirtIfRetransInterval;
        long            ospfVirtIfHelloInterval;
        long            ospfVirtIfRtrDeadInterval;
        long            ospfVirtIfState;
        unsigned long   ospfVirtIfEvents;
        unsigned char   ospfVirtIfAuthKey [M2DISPLAYSTRSIZE];
        long            ospfVirtIfStatus;
	int             keyLen; /* length of ospfVirtIfAuthKey */

} M2_OSPF_VIRT_IF_ENTRY;

#define M2_OSPF_VIRT_IF_AREA_ID               0x1        
#define M2_OSPF_VIRT_IF_NEIGHBOR              0x2
#define M2_OSPF_VIRT_IF_TRANSIT_DELAY         0x4
#define M2_OSPF_VIRT_IF_RETRANS_INTERVAL      0x8
#define M2_OSPF_VIRT_IF_HELLO_INTERVAL        0x10
#define M2_OSPF_VIRT_IF_RTR_DEAD_INTERVAL     0x20
#define M2_OSPF_VIRT_IF_AUTH_KEY              0x40
#define M2_OSPF_VIRT_IF_STATUS                0x80

/*
 * The ospfNbrEntry family. 
 */



typedef struct {
        unsigned long   ospfNbrIpAddr;
        long            ospfNbrAddressLessIndex;
        unsigned long   ospfNbrRtrId;
        long            ospfNbrOptions;
        long            ospfNbrPriority;
        long            ospfNbrState;
        unsigned long   ospfNbrEvents;
        unsigned long   ospfNbrLSRetransQLen;
        long            ospfNBMANbrStatus; 
} M2_OSPF_NBR_ENTRY;

#define M2_OSPF_NBMA_NBR_STATUS            0x1



#
/*
 * The ospfVirtNbrEntry family. 
 */


typedef struct {
        unsigned long   ospfVirtNbrArea;
        unsigned long   ospfVirtNbrRtrId;
        unsigned long   ospfVirtNbrIpAddr;
        long            ospfVirtNbrOptions;
        long            ospfVirtNbrState;
        unsigned long   ospfVirtNbrEvents;
        unsigned long   ospfVirtNbrLSRetransQLen;
} M2_OSPF_VIRT_NBR_ENTRY;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

STATUS        m2OspfGeneralGroupGet (M2_OSPF_GENERAL_GROUP * pInfo);
STATUS        m2OspfGeneralGroupSet (int varsToSet, M2_OSPF_GENERAL_GROUP * pInfo);
STATUS        m2OspfAreaEntryGet (int searchType, M2_OSPF_AREA_ENTRY * pInfo);
STATUS        m2OspfAreaEntrySet (int varsToSet, M2_OSPF_AREA_ENTRY * pInfo);
STATUS        m2OspfStubAreaEntryGet (int searchType, M2_OSPF_STUB_AREA_ENTRY * pInfo);
STATUS        m2OspfStubAreaEntrySet (int varsToSet, M2_OSPF_STUB_AREA_ENTRY * pInfo);
STATUS        m2OspfLsdbEntryGet (int searchType, M2_OSPF_LSDB_ENTRY * pInfo);
STATUS        m2OspfAreaRangeEntryGet (int searchType, M2_OSPF_AREA_RANGE_ENTRY * pInfo);
STATUS        m2OspfAreaRangeEntrySet (int varsToSet, M2_OSPF_AREA_RANGE_ENTRY * pInfo);
STATUS        m2OspfHostEntryGet (int searchType, M2_OSPF_HOST_ENTRY * pInfo);
STATUS        m2OspfHostEntrySet (int varsToSet, M2_OSPF_HOST_ENTRY * pInfo);
STATUS        m2OspfIfEntryGet (int searchType, M2_OSPF_IF_ENTRY * pInfo);
STATUS        m2OspfIfEntrySet (int varsToSet, M2_OSPF_IF_ENTRY * pInfo);
STATUS        m2OspfIfMetricEntryGet (int searchType, M2_OSPF_IF_METRIC_ENTRY * pInfo);
STATUS        m2OspfIfMetricEntrySet (int varsToSet, M2_OSPF_IF_METRIC_ENTRY * pInfo);
STATUS        m2OspfVirtIfEntryGet (int searchType, M2_OSPF_VIRT_IF_ENTRY * pInfo);
STATUS        m2OspfVirtIfEntrySet (int varsToSet, M2_OSPF_VIRT_IF_ENTRY * pInfo);
STATUS        m2OspfNbrEntryGet (int searchType, M2_OSPF_NBR_ENTRY * pInfo);
STATUS        m2OspfNbrEntrySet (int varsToSet, M2_OSPF_NBR_ENTRY * pInfo);
STATUS        m2OspfVirtNbrEntryGet (int searchType, M2_OSPF_VIRT_NBR_ENTRY * pInfo);
STATUS        ospfInit (int priority, int options, int stackSize, int routerId, FUNCPTR
			pAuthHook);
STATUS        ospfLibInit (void);
STATUS        ospfNbmaDstAdd (uint32_t ipAddress, uint32_t ifIpAddress, BOOL eligible); 
STATUS        ospfNbmaDstDelete (uint32_t ipAddress, uint32_t ifIpAddress);
STATUS        ospfExtRouteAdd (uint32_t destIp, uint32_t destMask, uint32_t nextHopIp,
	                       int cost, int extRouteType, int tos);
STATUS        ospfExtRouteDelete (uint32_t destIp, uint32_t destMask, int extRouteType, 
				  int tos);
void          ospfTerminate (void);
#else


STATUS        m2OspfGeneralGroupGet ();
STATUS        m2OspfGeneralGroupSet ();
STATUS        m2OspfAreaEntryGet ();
STATUS        m2OspfAreaEntrySet ();
STATUS        m2OspfStubAreaEntryGet ();
STATUS        m2OspfStubAreaEntrySet ();
STATUS        m2OspfLsdbEntryGet ();
STATUS        m2OspfAreaRangeEntryGet ();
STATUS        m2OspfAreaRangeEntrySet ();
STATUS        m2OspfHostEntryGet ();
STATUS        m2OspfHostEntrySet ();
STATUS        m2OspfIfEntryGet ();
STATUS        m2OspfIfEntrySet ();
STATUS        m2OspfIfMetricEntryGet ();
STATUS        m2OspfIfMetricEntrySet	();
STATUS        m2OspfVirtIfEntryGet ();
STATUS        m2OspfVirtIfEntrySet ();
STATUS        m2OspfNbrEntryGet ();
STATUS        m2OspfNbrEntrySet ();
STATUS        m2OspfVirtNbrEntryGet ();
STATUS        ospfInit ();
STATUS        ospfLibInit ();
STATUS        ospfNbmaDstAdd (); 
STATUS        ospfNbmaDstDelete ();
STATUS        ospfExtRouteAdd ();
STATUS        ospfExtRouteDelete ();
void          ospfTerminate ();
#endif


#ifdef        __cplusplus
}
#endif
        
#endif /* _INCospfLibh */
