/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCp2snaddh
#define __INCp2snaddh

/********************************************
snadd.h

copyright phase2 networks 1990
all rights reserved

subnetwork address and llc definitions


SID: 1.7
Revision History:


    1.9	96/06/12 11:40:37 root
	add NUM_ENCAP

    1.8	96/05/06 10:27:06 root
	renumber encap types

    1.7	96/05/03 23:26:55 root
	add encap defs

    1.6	95/06/25 21:51:29 root
	make cmn

    1.5	95/06/23 15:10:57 root
	make cmn

    1.4	95/04/18 10:40:33 root
	added gre support

    1.3	94/02/25 16:29:16 root
	ifndef file for decnet coexistence

    1.2	93/04/15 16:53:24 root
	multi-prot enhancements

    1.1	92/09/15 14:52:01 root
	date and time created 92/09/15 14:52:01 by root

***********************************************/

#ifndef _snadd_h
#define _snadd_h

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

/* llc stuff */
struct lan_addr{
    byte	addr[6];
};

#define MAX_SNPA_LEN  12

typedef struct sn_addr{
    byte  s_type;
    byte  s_len;
    union {
		struct 	lan_addr	ea;
		byte	x121[8];
		byte	e164[9];
		byte ipa[4];			/* IP addr */
		byte	gen[MAX_SNPA_LEN];
    }s_addr;
}SNAD, *snad_pt;

/* types */
#define SN_UNKNOWN	0
#define SN_LAN		1
#define SN_PTPT		2 
#define SN_X121		3
#define SN_E164		4
#define SN_GENERIC	5
#define SN_MC		6
#define SN_GREIP	7		/* encap in IP */

/* generic router encapsulation header */
#define IP_PROT_GRE	 47
#define GRE_PROT_OSI 0x00fe
#define GRE_HDR_LEN 4
typedef struct gre_header{
	byte		flver1;		/* flags/version */
	byte		flver0;
	byte		ptype1;		/* protocol type */
	byte		ptype0;
}GRE_HDR, *gre_hdr_pt;

#define GRE_CP		0x80		/* csum present */
#define GRE_RP		0x40		/* routing present */
#define GRE_KP		0x20		/* key present */
#define GRE_SP		0x10		/* seq # present */
#define GRE_SRT	0x80		/* source routed */	

/* used to locate incoming GRE circuit 
   from source IP address. */
typedef struct ipdest_search{
	struct ipdest_search	*ipd_fwd;		/* links */
	struct ipdest_search	*ipd_bwd;		/* links */
	byte					 ipd_ipa[4];	/* ip source */
	int					 ipd_cid;		/* neigh circ*/
}IPDSRCH, *ipdsrch_pt;


typedef struct eth_llc_hdr{
    byte		llc_da[6];
    byte		llc_sa[6];
    word		llc_len;
    byte		llc_dsap;
    byte		llc_ssap;
    byte		llc_cntl;
}ETHLLC,*eth_llc_pt;

typedef struct llc_hdr{
    byte		llc_da[6];
    byte		llc_sa[6];
    byte		llc_dsap;
    byte		llc_ssap;
    byte		llc_cntl;
}LLC,*llc_pt;

typedef struct eth_hdr{
    byte		eth_da[6];
    byte		eth_sa[6];
    word		eth_type;
}ETH,*eth_pt;

typedef struct eth_snap_hdr{
    byte		llc_da[6];
    byte		llc_sa[6];
    word		llc_len;
    byte		llc_dsap;
    byte		llc_ssap;
    byte		llc_cntl;
    byte		llc_snap[5];
}ETHSNAP,*eth_snap_pt;

typedef struct snap_hdr{
    byte		llc_da[6];
    byte		llc_sa[6];
    byte		llc_dsap;
    byte		llc_ssap;
    byte		llc_cntl;
    byte		llc_snap[5];
}SNAP,*snap_pt;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

/* whether or not to delete output frame after tx */
#define NODELETE 0
#define DELETE	 1

/* mac encapsulation type */
#define ENCAP_DIX	0		/* type */
#define ENCAP_RAW	1		/* len only */
#define ENCAP_LLC	2		/* len,llc */
#define ENCAP_SNAP	3		/* snap hdr */
#define NUM_ENCAP	4

#endif

#endif /* __INCp2snaddh */
