/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCp2snmph
#define __INCp2snmph

/*****************************************************
p2snmp.h:

common snmp definitions for routing

copyright phase2 networks 1991
all rights reserved


SID: 1.19
Revision History:


    1.19	96/02/08 11:14:37 root
	change all "byte" to unsigned char

    1.18	96/02/05 10:49:15 dse
	changed OID to P2OID to avoid conficts with cust code

    1.17	95/08/01 16:17:44 root
	rm dual #define

    1.16	95/07/10 11:05:54 root
	put protos in p2snmp.h

    1.15	95/07/10 10:54:35 root
	add ifdef p2snmp_h

    1.14	95/07/10 10:49:44 root
	ospf common mib entry

    1.13	95/07/10 10:07:23 root
	common snmp.c

    1.12	95/07/10 07:47:33 root
	add T_METRIC

    1.11	95/07/09 19:26:54 root
	add F_COSNT

    1.10	95/06/23 17:38:01 root
	fix typo

    1.9	95/06/23 15:15:27 root
	cmn typo

    1.8	95/06/23 15:10:50 root
	make cmn

    1.7	95/06/22 09:18:39 root
	add settest

    1.6	94/03/07 21:27:52 root
	add T_LONG

    1.5	93/07/07 21:41:49 root
	increase oid size

    1.4	93/04/15 16:50:07 root
	multi-prot enhancements

    1.3	92/12/02 15:48:23 jpp
	fix MOFF 

    1.2	92/09/15 16:33:35 root
	IP additions

    1.1	92/05/29 12:34:24 jpp
	date and time created 92/05/29 12:34:24 by jpp

*****************************************************/

#ifndef _p2snmp_h
#define _p2snmp_h

#define IR_SNMP_PREFIX	1
#define O_SNMP_PREFIX	1
#define MAX_DESC_STR	32
#define MAX_P2OID_LEN		64	/* max len oid after prefix */
#define MAX_BASE_P2OID_LEN	48	/* without instance ID */
#define MAX_STRINGS		512

/* object type definitions */
#define T_BYTE		0xff
#define T_BOOLEAN	0xfe
#define T_WORD		0xfd
#define T_LONG		0xfc
#define T_METRIC	0xfb
#define T_INTEGER	2
#define T_OCTSTR	4
#define T_OID		6
#define T_IPADDRESS 0x40
#define T_COUNTER	0x41
#define T_GAUGE		0x42
#define T_TICS		0x43
#define T_OSINADDR	0x80
#define T_LANADDR	0x81
#define T_SNPAADDR	0x82
#define T_OSIAREA	0x83
#define T_STRIDLEN	0x84		/* octet string, IDLEN */
#define T_STRIDLEN1	0x85		/* octet string, IDLEN +1 */
#define T_STROID	0x86		/* object ID octet string */
#define T_PREFIXAREA 0x87
#define T_IPXSERVTYPEVALUE	0x88
#define T_IPXSERVNAME		0X89
#define T_NICADDR			0x8a
#define T_IPXNETNUM			0x8b		/* octet sting, 4 bytes ipx networ*/
#define T_SIPXNETNUM		0x8c		/* swapped octet string */
#define T_SYSID				0X8d		/* octet string, IDLEN +2 */
#define T_NLSPID			0X8e		/* SYSID + 1 */

/* access definitions */
#define A_GET	1
#define A_SET	2

/* flag definitions */
#define F_INST		1	/* class has multiple instances */
#define F_CREATE	2	/* no modify after create */
#define F_CUST		4	/* no custom  processing */
#define F_SETPROC	8	/* special set processing */
#define F_PS		0x10 /* protocol specific */
#define F_CONST		0x20	/* constant int value */

/* macro to determine structure member offset */
/* 'x' is declared in ir_mib.c to be ptr to void
   with value 0.
*/

#define MOFF(type, mem) ((void *)( &((type)0)->mem) )

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

/* object id is stored in len/ array atruct */
typedef struct p2object_id{
	unsigned short	o_len;
	unsigned short	o_id[MAX_P2OID_LEN];
}P2OID;

typedef struct object_id_base{
	unsigned short	o_len;
	unsigned short	o_id[MAX_BASE_P2OID_LEN];
}P2OID_BASE;

/* a type/len/value tuple */
typedef struct type_len_value{
	unsigned char t_type;
	unsigned char t_len;
	unsigned char *t_val;
}TLV; 

/* a counted byte string  */
typedef struct cnt_byte_str{
	unsigned char		c_len;
	unsigned char		c_dat[255];
}CBS, *cbs_pt;	

/* one per object class */
typedef struct ir_mib{

   unsigned short 		m_acc;				/* access */
   unsigned short 		m_type;				/* object type */
   unsigned long		m_min;				/* min legal */
   unsigned long		m_max;				/* max legal */
   unsigned short		m_flags;			/* misc flags */
   void				*(*m_fndobj)();			/* obj finder */
   void				   *m_offset;			/* obj ptr or offset */
   P2OID_BASE			m_oid;				/* oid string */
}IRMIB,IPXMIB,OMIB;


#define SnmpOff			1
#define SnmpOn			2
#define SnmpValid		1
#define SnmpInvalid 	2
#define SnmpTrue		1
#define SnmpFalse		2
#define SnmpEnabled		1
#define SnmpDisabled	2

/* an snmp command block used to pass a command to the engine */
typedef struct snmp_cmd_blk{
	struct snmp_cmd_blk	*sc_fwd;
	int				sc_type;		/* get/set/getnxt */
	int				sc_res;		/* result */
	P2OID			sc_oid;		/* ob id */
	TLV				sc_tlv;		/* tlv struct */
}SNMP_CB;

#define GetReq		1
#define GetNextReq	2
#define GetResp		3
#define SetReq		4
#define SetTest		5

#define noError		0
#define tooBig		1
#define noSuchName	2
#define badValue	3
#define readOnly	4
#define genErr		5
#define endChain	10


/* for building tree of object classes */
/* note that t_kids index is value of kid oid */
#define MAX_KIDS 32
typedef struct p2mib_tree{
	int 	t_parent;		/* index in array of parent */
	int		t_val;			/* value of this sub-oid */
	int	t_kids[MAX_KIDS];	/* index of children */
}P2MIB_TREE;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

/* indices defining which MIB we are talking about */
#define IRMIB_OSI		0
#define IRMIB_DECNET		1
#define IRMIB_IP		2	/* mib2 */
#define IRMIB_IPEXT		3    /* private extensions */
#define IRMIB_ATALK		4
#define IPXMIB_IPX		5	/* main mib, default */
#define IPXMIB_RS		6	/* RipSap mib */

#if PROTO
long p2SnmpDecode(TLV *);
void p2SnmpStr(SNMP_CB *, unsigned char *,int);
void p2SnmpInt(SNMP_CB *,int, int*,int);
int  p2SnmpValid(SNMP_CB *, IRMIB *);
void p2SnmpCmdErr(SNMP_CB *,int);
#else
long p2SnmpDecode();
void p2SnmpStr();
void p2SnmpInt();
int  p2SnmpValid();
void p2SnmpCmdErr();
#endif

#endif

#endif /* __INCp2snmph */
