/* libtli.h - tli port file */

/* Copyright 1984-1995 Wind River Systems, Inc. */

/*
modification history
01c,26mar97,sgv  modified TLS_LOCK to call myVxTas for R4000.
01b,24mar97,sgv  Added conditionals for R4000
01a,22sep95,jag  Added mod history, provided locks and define TLI_HIDE_EXTRAS
*/

#ifndef __INClibtlih
#define __INClibtlih

/** Copyright (c) 1993  Mentat Inc.
 ** libtli.h 4.4, last change 4/25/94
 **/

#ifndef	_LIBTLI_
#define	_LIBTLI_

#ifndef WRS
#ifndef lint
static char	libtli_h_sccsid[] = "@(#)libtli.h	4.4";
#endif
#endif

#ifdef WRS
#include <led.h>
#endif

/*
 * TLI symbols defined in port-specific led.h to alter standard XTI/TLI
 * library build.
 *
 * Define TLI_NO_OPEN_FLAG_CHECK to disable strict checking of flags argument 
 * in t_open.
 * Default: TLI_NO_OPEN_FLAG_CHECK is not defined and t_open performs flag checks.
 *
 * Define TLI_ERRLIST_INIT to initialize t_errlist[] at run time; omit for
 * compile time initialization.
 * Default: TLI_ERRLIST_INIT is not defined.
 *
 * Define TLI_XPG4_TINFO to include the "flags" field in t_info structures.
 * NOTE: This *must* be defined for XTI.  xti.h defines this symbol.
 * Default: TLI_XPG4_TINFO is defined only in xti.h
 *
 * Define TLI_HIDE_EXTRAS to redfine TLI/XTI extensions to have a leading
 * underscore in their name.
 * Default: TLI_HIDE_EXTRAS is not defined; functions have no leading "_"
 *
 * Define TLI_DEBUG for additional debug output from library when debug
 * mode is set.  This is normally defined whenever TIMOD_DEBUG is defined.
 * Default: TLI_DEBUG is not defined; extra debug output is not compiled.
 *
 * Define TLI_TLI_ONLY to compile the library for TLI semantics only.
 * Default: TLI_TLI_ONLY is not defined; library assumes XTI semantics and
 * can support TLI semantics via the tli_open() function.
 */

#ifdef WRS
#define TLI_HIDE_EXTRAS
#endif /* WRS */

#ifdef TLI_HIDE_EXTRAS
#define	t_blocking		_t_blocking
#define	t_nonblocking		_t_nonblocking
#define	t_getprotaddr		_t_getprotaddr
#define	t_is_nonblocking	_t_is_nonblocking
#define	t_rcv_with_type		_t_rcv_with_type
#define	t_snd_with_type		_t_snd_with_type
#define	t_strerror		_t_strerror
#define	xti_open		_xti_open
#define	tli_open		_tli_open
#endif

/* The functions for xti_open tli_open are needed by WRS */
#ifdef WRS
#undef xti_open
#undef tli_open
#endif /* WRS */

/* 
 * Define TI2 to be same as TI1 for additional output in some "time critical" 
 * segments for tracing nasty errors.
 */
#define	DBG_ARG		stderr,		/* 1st part of "a" to make macros work */
#define	TI0DBG(a)	fprintf a
#ifdef TLI_DEBUG
#define	TI1DBG(a)	if (_mitli_g_debug) fprintf a; else
#define TIEDBG(text)	if (_mitli_g_debug) \
				fprintf(DBG_ARG "%s, errno = %d, t_errno = %d\n" \
					, text, errno, t_errno); else
#define	TI2DBG(a)	{;}
#else
#define	TI1DBG(a)	{;}
#define	TIEDBG(a)	{;}
#define	TI2DBG(a)	{;}
#endif
/*
 * Options must fit in a single M_PROTO message block (max size STRCTLSZ)
 * For systems which don't make symbol visible to user applications, use
 * 1024.  If a provider violates this assumption, e.g., OPT_size > STRCTLSZ,
 * then it is out of spec with TPI and this code (and timod) will break.
 */
#if defined(STRCTLSZ) && (STRCTLSZ > 0)
#define MAX_OPTBUF	STRCTLSZ
#else
#define MAX_OPTBUF	1024
#endif
/*
 * Include xti.h for XTI library, tiuser.h for TLI library.
 */
#ifdef TLI_TLI_ONLY
#include <tiuser.h>
#else
#include <xti.h>
#endif

/*
 * Header file for SVR4 timod ioctl's
 */
#include <timod.h>
/* 
 * Our own additions to the list 
 */
#define	TI_GETPROTOBUF		MIOC_CMD(MIOC_TLI,5)	/* retrieve proto_buf from timod (t_sync() call) */
#define	TI_SETPROTOBUF		MIOC_CMD(MIOC_TLI,6)	/* copy library proto_buf to timod */
#define	TI_GETSTATE		MIOC_CMD(MIOC_TLI,7)	/* get state (less proto_buf) from timod */
#define	TI_SETSTATE		MIOC_CMD(MIOC_TLI,8)	/* copy lib state to timod, clear timod's protobuf */
#define	TI_CLEAR_EVENT		MIOC_CMD(MIOC_TLI,9)	/* SETSTATE + clear XTI discon/ordrel/uderr event */
#define TI_EVENT_ON		MIOC_CMD(MIOC_TLI,10)	/* cross min/maxpsz */
#define TI_EVENT_OFF		MIOC_CMD(MIOC_TLI,11)	/* cross min/maxpsz */
/*
 * Following neeeded for streams buffers.  DEFxxx defined in led.h
 */
#ifdef STRMSGSZ
#if STRMSGSZ == 0
  #define TI_MAXPSZ	MAX_FAST_MBLK
#else
  #define TI_MAXPSZ	STRMSGSZ
#endif
#else
  #define TI_MAXPSZ	MAX_FAST_MBLK
#endif

/*
 * at least as big as max T_ok_ack, T_error_ack 
 */
#define ACK_BUFSIZE	32
/*
 * Expedited data is sent/received as a band>0 msg.
 */
#define T_EXDATA_BAND	1
/*
 * How long to wait for poll() after EINTR error in t_accept()
 */
#define	EINTR_WAIT_TIME	5L
/*
 * I_STR timeout value when sending T_INFO_REQ to a provider during
 * TLS initialization.  We assume a timeout means this is not a TPI
 * provider.
 */
#define ISTR_WAIT_TIME	5

#if T_INFO_REQ == 1 || T_INFO_REQ == 2
#define XTI_MODE	3
#else
#define XTI_MODE	1
#endif
#define TLI_MODE	(XTI_MODE+1)

#define IS_XTI(tls)		((tls)->tls_mode == XTI_MODE)

/*
 * Not all TLI functions return TOUTSTATE when called out-of-state.  For these
 * cases, SETBADSTATE is used.  The choice of TSYSERR/EIO is based on SVR4 tests.
 */
#define SETBADSTATE(tls)	if(IS_XTI(tls)) t_errno = TOUTSTATE;	\
				else {t_errno = TSYSERR; errno = EIO;}

/*
 * For multi-thread applications, define following to synchronize access to
 * hash table
 */
#ifdef WRS
extern SEM_ID	strmTliSem;
#define	LOCK_TLS_TABLE		semTake(strmTliSem, WAIT_FOREVER)
#define	UNLOCK_TLS_TABLE	semGive(strmTliSem)
#else
#define	LOCK_TLS_TABLE
#define	UNLOCK_TLS_TABLE
#endif /* WRS */

/*
 * Follow used to insure single thread access to current TLS structure
 * _mitli_tls_acquire(fd) "locks" the returned TLS structure by
 * setting the TLS_CHANGING bit.  These two macros are used prior
 * to all returns from library functions to release the structure.
 * NOTE: TLS_LOCK needs suitable atomic test and set.
 */

#define TLS_BUSY(tls)	(tls->tls_lock)

#if 	(CPU==R4000)
#define TLS_LOCK(tls, lockset)	(lockset = (myVxTas((int *)(&tls->tls_lock))))
#else
#define TLS_LOCK(tls, lockset)	(lockset = (vxTas((void *)(&tls->tls_lock))))
#endif /* CPU==R4000 */

#define TLS_UNLOCK(tls)			tls->tls_lock = 0


#define CHANGE_STATE_BEGIN(tls)		tls->tls_flags |= TLS_CHANGING
#define CHANGE_STATE_END(tls)		tls->tls_flags &= ~TLS_CHANGING
#define NEW_STATE(tls, newstate)	(tls->tls_state = newstate	\
					, CHANGE_STATE_END(tls))
/*
 * Used for option and connect data size checks in t_accept() and t_connect().
 */

#define DATA_LEN_OK(len,lim,frag)	( (len) == 0			\
					|| ( (len) > 0			\
					     && ((lim) == -1 || (len) <= (lim)) \
					     && (len) <= (frag) )	\
					)

/*
 * It is convenient for testing to distinguish various "TSYSERR" errors.
 * Library therefore uses the following error codes, which may be redefined
 * as needed on any given system.  Setting all to EPROTO will conform to TLI.
 */
#define TX_INUSE	EBUSY		/* resource not available	*/
#define TX_BADARG	EINVAL		/* non-specific bad arguments	*/
#define TX_MALLOC	ENOMEM		/* malloc() or calloc() failure	*/
#define TX_BADMSG	EBADMSG		/* unexpected getmsg/putmsg failure	*/
#define TX_UNINIT	ENXIO		/* tls table not initialized	*/
#define TX_CONNRESET	ECONNRESET	/* T_DISCON_IND has arrived	*/

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

/*
 * Library State Structures
 */
#define MAX_TADDR	64
typedef struct taddr_s {		/* statically allocated to simplify ioctl's */
	long	ta_len;
	char	ta_buf[MAX_TADDR];
} TADDR, *TADDRP;

typedef struct t_libstate_s {
	struct t_libstate_s	* tls_next;		/* for library hash list */
	long			tls_debug;		/* timod_g_debug from timod */
	int			tls_flags;
	int			tls_lock;		/* lock access to this TLS */
	int			tls_fd;			/* fd for this TLS */
	int			tls_mode;		/* TLI_MODE or XTI_MODE */
	int			tls_state;		/* library (not provider) state */
	int			tls_qlen;		/* CONIND_number from t_bind() */
	int			tls_ocnt;		/* # of outstanding connection requests */
	int			tls_fragsize;		/* "optimal" frag size for t_snd() */
	int			tls_dataflags;		/* flags for t_rcv() from T_DATA_IND */
	int			tls_exdataflags;	/* flags for t_rcv() from T_EXDATA_IND */
	struct T_info_ack	tls_infoack;		/* from t_open or last successful t_getinfo() */
	TADDR			tls_boundaddr;		/* this is us */
	TADDR			tls_peeraddr;		/* and this is them */
	union pbuf_s {
		long		primtype;
		char		tpimsg[MAX_OPTBUF]; 	/* Save area for M_PROTO portions */
	} tls_pbuf;
} TLS, *TLSP;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#define tls_primtype	tls_pbuf.primtype
#define tls_proto_buf	tls_pbuf.tpimsg
#define TLS_PROTO_SIZE	sizeof(union pbuf_s)
#define TLS_STATE_SIZE	(sizeof(TLS) - TLS_PROTO_SIZE)

/* tls_flags values */
#define	TLS_DATA_STOPPED	0x0001
#define	TLS_EXDATA_STOPPED	0x0002
#define	TLS_NONDATA_PROTO	0x0004
#define	TLS_DATA_PROTO		0x0008
#define	TLS_EXDATA_PROTO	0x0010
#define TLS_SAVED_PROTO		(TLS_DATA_PROTO | TLS_EXDATA_PROTO | TLS_NONDATA_PROTO)

#define TLS_CLTS		0x0020
#define TLS_COTS_ORD		0x0040
#define TLS_COTS		0x0080
#define TLS_BOTH_COTS		(TLS_COTS_ORD | TLS_COTS)		
#define TLS_ANY_CTS		(TLS_COTS_ORD | TLS_COTS | TLS_CLTS)

#define TLS_CHANGING		0x0800

#ifndef KERNEL

extern	long	_mitli_g_debug;

extern	int	t_blocking(   int fd   );
extern	boolean_t	t_is_nonblocking(   int fd   );
extern	int	t_nonblocking(   int fd   );
extern	int	_mitli_bind(   TLSP tls, struct t_bind * req, struct t_bind * ret   );
extern	int	_mitli_chk_ack(   int fd, TLSP tls, long expected_prim   );
extern	int	_mitli_get_netbuf(   struct netbuf * np, char  * primbuf, long  buflen   );
extern	int	_mitli_get_primitive(   int fd, TLSP tls, long expected_primitive, int expected_len, struct netbuf * netbufp   );
extern	int	_mitli_ioctl(   int fd, int cmd, char * dp, int len   );
extern	int	_mitli_look(   TLSP tls, boolean_t godata   );
extern	TLSP	_mitli_tls_acquire(   int fd, int service   );
extern	int	_mitli_tls_free(   int fd   );
extern	TLSP	_mitli_tls_init(   int fd, int mode   );
extern	int	_mitli_tls_sync(   TLSP tls, int setbuf   );
extern	int	_mitli_tpicall(   int fd, int cmd, char * dp, int len, int maxlen   );
extern	int	_mitli_u2t_errno(   int new_errno   );

#endif	/* KERNEL */

#endif	/*_LIBTLI_*/

#endif /* __INClibtlih */
