/* excLib.h - exception library header */

/* Copyright 1984-1994 Wind River Systems, Inc. */

/*
modification history
--------------------
01g,26oct94,tmk  added support for MC68LC040
01f,01jun94,tpr  added fslw in EXC_INFO and define EXC_FSLW for MC68060.
01e,22sep92,rrr  added support for c++
01d,02aug92,jcf  cleaned up function declarations.
01c,26may92,rrr  the tree shuffle
01b,04oct91,rrr  passed through the ansification filter
		  -changed copyright notice
01a,29nov90,jwt  written from "h/excLib.h" to "h/CPU/excLib.h".
*/

#ifndef __INCexcMc68kLibh
#define __INCexcMc68kLibh

#ifdef __cplusplus
extern "C" {
#endif

typedef struct
    {
    UINT16  valid;	/* indicators that following fields are valid */
    UINT16  vecNum;	/* vector number */
    INSTR * pc;		/* program counter */
    ULONG   accessAddr;	/* access address */
    UINT16  statusReg;	/* status register */
#if (CPU != MC68060)
    UINT16  funcCode;	/* func code (or ESF type if EXC_INVALID_TYPE) */
    UINT16  instrReg;	/* instruction register */
#else /* (CPU != MC68060) */
    ULONG   funcCode;	/* fault status long word */
#endif /* (CPU != MC68060) */
    UINT16  pad;	/* pad to four byte boundary */
    } EXC_INFO;

/* exception info valid bits */

#define EXC_VEC_NUM		0x01	/* vector number valid */
#define EXC_PC			0x02	/* pc valid */
#define EXC_STATUS_REG		0x04	/* status register valid */
#define EXC_ACCESS_ADDR		0x08	/* access address valid */
#define EXC_FUNC_CODE		0x10	/* function code valid */
#define EXC_INSTR_REG		0x20	/* instruction register valid */
#define EXC_FSLW		0x40	/* fault status long word valid */
#define EXC_INVALID_TYPE	0x80	/* special indicator: ESF type was bad;
					 * type is in funcCode field */


/* vector numbers of specific exceptions */

#define LOW_VEC		2	/* lowest vector initialized */
#define BUS_ERROR_VEC	2	/* bus error vector */
#define ADRS_ERROR_VEC	3	/* address error vector */
#define FORMAT_ERROR	14	/* last program error vector */
#define TRAP_0_VEC	32	/* start of trap vectors */
#define USER_VEC_START	64	/* start of user interrupt vectors */
#define HIGH_VEC	255	/* highest vector initialized */


/* variable declarations */

extern FUNCPTR  excExcepHook;   /* add'l rtn to call when exceptions occur */

#if (CPU==MC68000)
extern int	excBsrTbl [];	/* table of BSRs in excALib.s */
#endif	/* CPU==MC68000 */


/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

#if (CPU==MC68010 || CPU==MC68020 || CPU==MC68040 || CPU==MC68060 || \
     CPU==MC68LC040 || CPU==CPU32)
extern void	excStub (void);
extern void	excIntStub (void);
#endif	/* (CPU==MC680[124]0 || CPU==CPU32) */

#else	/* __STDC__ */

#if (CPU==MC68010 || CPU==MC68020 || CPU==MC68040 || CPU==MC68060 || \
     CPU==MC68LC040 || CPU==CPU32)
extern void	excStub ();
extern void	excIntStub ();
#endif	/* (CPU==MC680[124]0 || CPU==CPU32) */

#endif	/* __STDC__ */

#ifdef __cplusplus
}
#endif

#endif /* __INCexcMc68kLibh */
