/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCos_helloh
#define __INCos_helloh

/***********************************************
os_hello.h

OSPF Hello PDU related definitions

copyright phase2 networks inc, 1994
all rights reserved

SID: 1.3
Revision History:


    1.3	95/11/09 09:44:57 root
	add mospf

    1.2	95/01/02 17:42:13 root
	final test

    1.1	94/12/04 09:38:11 root
	date and time created 94/12/04 09:38:11 by root

***********************************************/
#define HELLO_TYPE      1
#define ROUTER_OPTIONS  0
#define OSPF_VERSION 2

/* how often to retry sending hello packets,
   in the event we fail to allocate a buffer for the packet */ 
#define HELLO_FAST_INTERVAL 1

#define my_area_id( cir ) \
        ( (cir)->c_area->a_id )

#define my_auth_type( cir ) \
        ( (cir)->c_area->a_auth_type )


#define nbr_fwd_list(cir) \
        ( (cir)->c_nbr_fwd )

#define nbr_bwd_list(cir) \
        ( (cir)->c_nbr_bwd )

#define next_nbr( nbr ) \
        ( (nbr)->nb_fwd )

#define prev_nbr( nbr ) \
        ( (nbr)->nb_bwd )

#define c_network( cir ) \
        ( (cir)->???? )

#define c_hinterval( cir ) \
        ((cir)->c_ht )

#define c_netmask( cir ) \
        ((cir)->c_ipaddr.ip_mask )


#define c_options( cir ) \
        ( (byte) (CIRC_E_OPTION(cir) | CIRC_T_OPTION(circ)) )

#define c_dead_interval( cir ) \
        ( (dword)(cir)->c_deadint)

#define c_dr( cir ) \
        ( (cir)->c_dripa )

#define c_backupdr( cir ) \
        ( (cir)->c_bdr )

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

typedef struct hello_packet
{
  byte net_mask[4];                /* network mask                        */
  byte interval[2];                /* hello interval in seconds           */
  byte options;                    /* Options, see appendix A of rfc 1583 */
  byte priority;                   /* Priority of sender                  */
  byte dead_interval[4];           /* num secs before declaring rtr dead  */
  byte dr[4];                      /* designated router                   */
  byte bdr[4];                     /* backup designated router            */
#if 1
  byte neighbors[4];               /* list of neighbors                   */
#endif
} hello_packet;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#define HELLO_HEADER_SIZE 20

#define HELLO_NETMASK(packet) \
n2ipa ( ( ((hello_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->net_mask ) )

#define HELLO_DR(packet) \
n2ipa ( ( ((hello_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dr ) )

#define HELLO_BDR(packet) \
n2ipa( ( ((hello_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->bdr ) )

#define HELLO_PRIORITY(packet)   \
 (( ((hello_packet *)((byte *)(packet) + OSPF_HEADER_SIZE))->priority ) )

#define HELLO_INTERVAL(packet) \
 ( n2u16( ((hello_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->interval ) )

#define HELLO_DEADROUTER(packet) \
 ( n2u32( ((hello_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dead_interval ) )

#define HELLO_FIRST_NEIGHBOR(packet) \
 ( (ipa*) ((byte*)packet+OSPF_HEADER_SIZE+HELLO_HEADER_SIZE) )

#if 0
#define HELLO_NEXT_NEIGHBOR(pchNeighbor) \
 ( ((byte*)(packet) + HELLO_NEIGHBOR_SIZE ) )
#endif

#define HELLO_OPTIONS(packet) \
 ( ( ((hello_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->options ) )

#define HELLO_OPTIONS_T(packet) \
 (HELLO_OPTIONS(packet) & 0x01 )

#define HELLO_OPTIONS_E(packet) \
 ((HELLO_OPTIONS(packet) & 0x02) >>1)

#define HELLO_OPTIONS_MC(packet) \
 ((HELLO_OPTIONS(packet) & MC_OPT)?1:0 )

#endif /* __INCos_helloh */
