/* mmuPpro32Lib.h - mmuPpro32Lib header for i86. */

/* Copyright 1984-1997 Wind River Systems, Inc. */

/*
modification history
--------------------
01b,13may98,hdn  added _ASMLANGUAGE macro. 
01a,11apr97,hdn  written.
*/

#ifndef __INCmmuPpro32Libh
#define __INCmmuPpro32Libh

#ifdef __cplusplus
extern "C" {
#endif


#define PAGE_SIZE		0x1000
#define PAGE_BLOCK_SIZE		0x400000
#define PAGE_SIZE_4KB		0x1000
#define PAGE_SIZE_4MB		0x400000

#define DIR_BITS		0xffc00000
#define TBL_BITS		0x003ff000
#define OFFSET_BITS_4KB		0x00000fff
#define OFFSET_BITS_4MB		0x003fffff
#define DIR_INDEX		22
#define TBL_INDEX		12
#define PTE_TO_ADDR_4KB		0xfffff000
#define PTE_TO_ADDR_4MB		0xffc00000
#define ADDR_TO_PAGE		12
#define ADDR_TO_PAGEBASE	0xffc00000

#ifndef	_ASMLANGUAGE

typedef struct
    {
    unsigned present:1;
    unsigned rw:1;
    unsigned us:1;
    unsigned pwt:1;
    unsigned pcd:1;
    unsigned access:1;
    unsigned dirty:1;
    unsigned pagesize:1;
    unsigned global:1;
    unsigned avail:3;
    unsigned page:20;
    } PTE_FIELD;

typedef union pte
    {
    PTE_FIELD field;
    unsigned int bits;
    } PTE;

typedef struct mmuTransTblStruct
    {
    PTE *pDirectoryTable;
    } MMU_TRANS_TBL;

typedef struct gdt
    {
    unsigned short	limit00;
    unsigned short	base00;
    unsigned char	base01;
    unsigned char	type;
    unsigned char	limit01;
    unsigned char	base02;
    } GDT;


#define MMU_STATE_MASK_VALID		0x001
#define MMU_STATE_MASK_WRITABLE		0x002
#define MMU_STATE_MASK_CACHEABLE	0x010
#define MMU_STATE_MASK_WBACK		0x008
#define MMU_STATE_MASK_GLOBAL		0x100

#define MMU_STATE_VALID			0x001
#define MMU_STATE_VALID_NOT		0x000
#define MMU_STATE_WRITABLE		0x002
#define MMU_STATE_WRITABLE_NOT		0x000
#define MMU_STATE_CACHEABLE		0x000
#define MMU_STATE_CACHEABLE_NOT		0x010
#define MMU_STATE_WBACK			0x000
#define MMU_STATE_WBACK_NOT		0x008
#define MMU_STATE_GLOBAL		0x100
#define MMU_STATE_GLOBAL_NOT		0x000

#define MMU_STATE_CACHEABLE_WT		0x008

#define GDT_ENTRIES			5


/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern STATUS	mmuPro32LibInit (int pageSize);
extern STATUS	mmuPro32Enable (BOOL enable);
extern void	mmuPro32On ();
extern void	mmuPro32Off ();
extern void	mmuPro32TLBFlush ();
extern void	mmuPro32PdbrSet (MMU_TRANS_TBL *transTbl);
extern MMU_TRANS_TBL *mmuPro32PdbrGet ();

#else   /* __STDC__ */

extern STATUS	mmuPro32LibInit ();
extern STATUS	mmuPro32Enable ();
extern void	mmuPro32On ();
extern void	mmuPro32Off ();
extern void	mmuPro32TLBFlush ();
extern void	mmuPro32PdbrSet ();
extern MMU_TRANS_TBL *mmuPro32PdbrGet ();

#endif  /* __STDC__ */

#endif	/* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCmmuPpro32Libh */
