/* dsmLib.h - 68k disassembler header */

/* Copyright 1984-1994 Wind River Systems, Inc. */
/*
modification history
--------------------
01t,31oct94,kdl  merge cleanup.
01s,26oct94,tmk  added support for MC68LC040
01r,21jul94,tpr  added MC68060 cpu support.
01q,22sep92,rrr  added support for c++
01p,26may92,rrr  the tree shuffle
01o,04oct91,rrr  passed through the ansification filter
		  -fixed #else and #endif
		  -changed copyright notice
01n,27aug91,shl  added MC68040 instruction types, and registers.
01m,25oct90,yao  added MMU registers, instruction types, and function codes.
01l,05oct90,shl  added ANSI function prototypes.
                 made #endif ANSI style.
                 added copyright notice.
01k,30may90,yao	 deleted INSTTWO structure; structure INST now
		 contains two operation words and mask,
		 and modemask and regmask.
01j,26oct87,hin  added fpp instructions.
01i,14sep87,llk  change itShift to itRegShift.  Added itMemShift.
01h,05dec86,gae  changed stsLib.h to vwModNum.h.
01g,03apr86,llk	 added 68020 instructions, INSTTWO [] structure,
		 more control registers.
01f,12jun85,rdc  added 68010 instructions.
01e,08nov84,jlf  added itExt
01d,21sep84,jlf  added itCmpm
01c,17sep84,jlf  added itAdda
01b,16aug84,jlf  added itDb and itScc.
01a,07aug84,ecs  peeled from dsmLib.c
*/

#ifndef __INCdsmMc68kLibh
#define __INCdsmMc68kLibh

#ifdef __cplusplus
extern "C" {
#endif

#include "vwModNum.h"


/* dsmLib status codes */

#define S_dsmLib_UNKNOWN_INSTRUCTION	(M_dsmLib | 1)


/* instruction types */

#define	itBra		0
#define	itChk		1
#define	itComplete	2
#define	itDynBit	3
#define	itExg		4
#define	itImm		5
#define	itMoveB		6
#define	itMovep		7
#define	itMovem		8
#define	itMoveq		9
#define	itNbcd		10
#define	itNegx		11
#define	itOr		12
#define	itQuick		13
#define	itBcd		14
#define	itRegShift	15
#define	itStop		16
#define	itSwap		17
#define	itTrap		18
#define	itX		19
#define	itMoveW		20
#define	itMoveL		21
#define	itMoveFSR	22
#define	itMoveTSR	23
#define	itMoveCCR	24
#define	itMoveUSP	25
#define itStatBit	26
#define itLea		27
#define itLink		28
#define itUnlk		29
#define itDb		30
#define itScc		31
#define itAdda		32
#define itCmpm		33
#define itExt		34
#define itRTD		35
#define itMoves		36
#define itMoveFCCR	37
#define itMovec		38
#define itChk2		39
#define itBfchg		40
#define itBfext		41
#define itBfins		42
#define itCallm		43
#define itLinkL		44
#define itBkpt		45
#define itTrapcc	46
#define itPack		47
/* #define itTwoWord	48   XXX unused */
#define itImmCCR	49
#define itImmTSR	50
#define itCas		51
#define itCas2		52
#define itRtm		53
#define itDivW		54
#define itDivL		55
#define itMoveA		56
#define itCpBcc		57
#define itCpDbcc	58
#define itCpTrapcc	59
#define itCpGen		60
#define itCpScc		61
#define itCpSave	62
#define itMemShift	63
#define itCinv          64
#define itCinva         65
#define itCpush         66
#define itCpusha        67
#define itMove16        68
#define itMove16L       69

/* fpp instructions */
#define itFpp		99
#define itFb		100
#define itFrestore	101
#define itFsave		102
#define itFabs		103
#define itFacos		104
#define itFadd		105
#define itFasin		106
#define itFatan		107
#define itFatanh	108
#define itFcmp		109
#define itFcos		110
#define itFcosh		111
#define itFdb		112
#define itFdiv		113
#define itFetox		114
#define itFetoxm1	115
#define itFgetexp	116
#define itFgetman	117
#define itFint		118
#define itFintrz	119
#define itFlog10	120
#define itFlog2		121
#define itFlogn		122
#define itFlognp1	123
#define itFmod		124
#define itFmove		125
#define itFmovek	126
#define itFmovel	127
#define itFmovecr	128
#define itFmovem	129
#define itFmovemc	130
#define itFmul		131
#define itFneg		132
#define itFnop		133
#define itFrem		134
#define itFscale	135
#define itFs		136
#define itFsgldiv	137
#define itFsglmul	138
#define itFsin		139
#define itFsincos	140
#define itFsinh		141
#define itFsqrt		142
#define itFsub		143
#define itFtan		144
#define itFtanh		145
#define itFtentox	146
#define itFtrap		147
#define itFtst		148
#define itFtwotox	149

#if (CPU==MC68020 || CPU==MC68030 || CPU==MC68040 || CPU==MC68060 || \
     CPU==MC68LC040)
/* MMU instructions */

#define itPflush	150
#define itPload		151
#define itPmove		152
#define itPtest		153
#endif	/* CPU==MC68020 || CPU==MC68030 || CPU==MC68040 || CPU==MC68060 || \
	 * CPU==MC68LC040 */

typedef struct
    {
    /* The variabls are in discreasing order for storage optimization */
    char *name;
    int type;
    unsigned short op1;
    unsigned short op2;
    unsigned short mask1;
    unsigned short mask2;
    UINT8 modemask;
    UINT8 regmask;
    } INST;

/* Control registers */

#define SFC     0x000   /* Source Function Code register */
#define DFC     0x001   /* Destination Function Code register */
#define USP     0x800   /* User Stack Pointer */
#define VBR     0x801   /* Vector Base Register */

#if (CPU==MC68020 || CPU==MC68030 || CPU==MC68040 || CPU==MC68060 || \
     CPU==MC68LC040)
#define CACR    0x002   /* Cache Control Register */
#define TC      0x003   /* Translation Control Register */
#define BUSCR	0x008	/* Bus Control Register */
#define MSP     0x803   /* Master Stack Pointer */
#define ISP     0x804   /* Interrupt Stack Pointer */
#define MMUSR   0x805   /* MMU Status Register */
#define SRP     0x807   /* Supervisor Root Pointer */
#define PCR     0x808   /* Processor Configuration Register */

/* function code  */
#define FCREG   0x008   /* Function Code in data register */
#define FCDATA  0x010   /* Immediate Function Code */
#endif	/* CPU==MC68020 || CPU==MC68030 || CPU==MC68040  || CPU==MC68060 || \
	 * CPU==MC68LC040 */

#if     (CPU == MC68020 || CPU == MC68030)
#define TT0     0x080   /* Transparent Translation Register 0 */
#define TT1     0x0C0   /* Transparent Translation Register 1 */
#define CRP     0x4C0   /* CPU Root Pointer */
#define CAAR    0x802   /* Cache Address Register */
#endif	/* (CPU == MC68020 || CPU == MC68030) */

#if (CPU == MC68040 || CPU == MC68060 || CPU==MC68LC040)
#define ITT0    0x004   /* Instruction Transparent Translation Register 0 */
#define ITT1    0x005   /* Instruction Transparent Translation Register 1 */
#define DTT0    0x006   /* Data Transparent Translation Register 0 */
#define DTT1    0x007   /* Data Transparent Translation Register 1 */
#define URP     0x806   /* User Root Pointer */
#endif	/* (CPU == MC68040 || CPU == MC68060 || CPU==MC68LC040) */

/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

IMPORT	  int	       dsmData (USHORT *binInst, int address);
IMPORT	  int	       dsmInst (USHORT *binInst, int address, VOIDFUNCPTR prtAddress);
IMPORT	  int	       dsmNbytes (USHORT *binInst);

#else

IMPORT	  int	       dsmData ();
IMPORT	  int	       dsmInst ();
IMPORT	  int	       dsmNbytes ();

#endif	/* __STDC__ */

#ifdef __cplusplus
}
#endif

#endif /* __INCdsmMc68kLibh */
