/* esf.h - 68k exception stack frames */

/* Copyright 1984-1994 Wind River Systems, Inc. */
/*
modification history
--------------------
01j,01nov94,kdl  fixed def of "fn" field in ESF68K_BA.
01i,30may94,tpr  added ESF4 for 68060.
01h,22sep92,rrr  added support for c++
01g,26may92,rrr  the tree shuffle
01f,04oct91,rrr  passed through the ansification filter
		  -changed ASMLANGUAGE to _ASMLANGUAGE
		  -changed copyright notice
01e,01oct91,yao  added ESFC for CPU32.
01d,27aug91,shl  added format 3 and 7 ESF of MC68040, updated copyright.
01c,05oct90,shl  added copyright notice.
                 made #endif ANSI style.
01b,16dec89,jcf  ESFB defined incorrectly.
01a,03apr86,dnw  extracted from dbgLib.c
*/

#ifndef __INCesfMc68kh
#define __INCesfMc68kh

#ifdef __cplusplus
extern "C" {
#endif

#ifndef	_ASMLANGUAGE

/*
 * Exception stack frames.  Most of these can happen only for one
 * CPU or another, but they are all defined for all CPU's
 */

/* ESF68K_BA - bus and address error for 68K only */

typedef struct
    {
    unsigned short 	fn;			/* function code */
    unsigned long	aa;			/* access address */
    unsigned short	ir;			/* instruction register */
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    } ESF68K_BA;

/* ESF68K - all other exceptions for 68K only */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    } ESF68K;

/*
 * ESF0: format 0 stack frame.  Generated by interrupts, format errors, TRAP #n
 * instructions, and illegal instructions.  68010, 68020, 68060 and CPU32.
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    } ESF0;

/*
 * ESF2: format 2 stack frame. Generated by instruction-related exceptions,
 * including coprecessor post-instruction exceptions, CHK, CHK2, cpTRAPcc,
 * TRAPcc, TRAPV, trace, and zero divide.  68020, 68060 and CPU32
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned long	aa;			/* fault address */
    } ESF2;

/*
 * ESF3: format 3 exception stack frame. Generated Floating-Point
 * Post-Instruction exception on 68040 and 68060 
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned long	effectiveAddr;		/* effective address */
    } ESF3;

/*
 * ESF4 : format 4 exception stack frame. Data and instruction access errors
 * Floating point disabled exception on 68060 only
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned long	effectiveAddr;		/* effective address */
    unsigned long	fslw;			/* Fault Status LongWord */
    } ESF4;

/*
 * ESF7: format 7 exception stack frame. Generated by bus
 * error on 68040 only
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned long	effectiveAddr;		/* effective address */
    unsigned short	fn;			/* special status word */
    unsigned short	wb3stat;		/* writeback 3 status */
    unsigned short	wb2stat;		/* writeback 2 status */
    unsigned short	wb1stat;		/* writeback 1 status */
    unsigned long	aa;			/* fault address */
    unsigned long	wb3addr;		/* writeback 3 address */
    unsigned long	wb3data;		/* writeback 3 data */
    unsigned long	wb2addr;		/* writeback 2 address */
    unsigned long	wb2data;		/* writeback 2 data */
    unsigned long	wb1addr;		/* writeback 1 address */
    unsigned long	wb1data;		/* writeback 1 data */
    unsigned long	pushd1;			/* push data long word 1 */
    unsigned long	pushd2;			/* push data long word 2 */
    unsigned long	pushd3;			/* push data long word 3 */
    } ESF7;

/*
 * ESF8: format 8 exception stack frame. Generated by bus or address
 * error on 68010 only
 */

typedef struct
    {
    unsigned short	sr;		/* status register */
    INSTR *		pc;		/* program counter */
    unsigned short	vectorOffset;	/* vector offset */
    unsigned short	fn;		/* special status word */
    unsigned long	aa;		/* fault address */
    short		unused1;
    unsigned short	dataOutBuf;	/* data output buffer */
    short		unused2;
    unsigned short	dataInBuf;	/* data input buffer */
    short		unused3;
    unsigned short	ir;		/* instruction input buffer */
    short		intInfo[16];	/* internal information, 16 words */
    } ESF8;

/*
 * ESF9: format 9 stack frame.  Generated by coprocessor mid-instruction
 * exception.  68020 only
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned long	aa;			/* fault address */
    short		InternalRegs [4];	/* internal registers */
    } ESF9;

/*
 * ESFA: format A exception stack frame.  Generated
 * by a 'short' bus cycle fault. 68020 only.
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned short	internalReg1;		/* internal register */
    unsigned short	fn;			/* special status word */
    unsigned short	instPipeC;		/* instruction pipe stage C */
    unsigned short	instPipeB;		/* instruction pipe stage B */
    unsigned long	aa;			/* fault address */
    unsigned short	internalReg2;		/* internal register */
    unsigned short	internalReg3;		/* internal register */
    unsigned long	dataOutBuf;		/* data output buffer */
    unsigned short	internalReg4;		/* internal register */
    unsigned short	internalReg5;		/* internal register */
    } ESFA;

/*
 * ESFB: format B exception stack frame.  Generated
 * by a 'long' bus cycle fault. 68020 only.
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned short	internalReg1;		/* internal register */
    unsigned short	fn;			/* special status word */
    unsigned short	instPipeC;		/* instruction pipe stage C */
    unsigned short	instPipeB;		/* instruction pipe stage B */
    unsigned long	aa;			/* fault address */
    unsigned short	internalReg2;		/* internal register */
    unsigned short	internalReg3;		/* internal register */
    unsigned long	dataOutBuf;		/* data output buffer */
    unsigned short	internalReg4;		/* internal register */
    unsigned short	internalReg5;		/* internal register */
    unsigned short	internalReg6;		/* internal register */
    unsigned short	internalReg7;		/* internal register */
    unsigned long	addrStageB;		/* stage B address */
    unsigned short	internalReg8;		/* internal register */
    unsigned short	internalReg9;		/* internal register */
    unsigned long	dataInBuf;		/* data input buffer */
    unsigned short	internalRegs [22];	/* more internal registers */
    } ESFB;

/*
 * ESFC: format C exception stack frame.  Generated by a bus cycle
 * fault. CPU32 only.
 */

typedef struct
    {
    unsigned short	sr;			/* status register */
    INSTR *		pc;			/* return program counter */
    unsigned short	vectorOffset;		/* vector offset */
    unsigned long	aa;			/* fault address */
    unsigned long	dataOutBuf;		/* data output buffer */
    INSTR *		currentPC;		/* current PC */
    unsigned short	internalReg1;		/* internal register */
    unsigned short	fn;			/* special status word */
    } ESFC;

#endif	/* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCesfMc68kh */
