/* mmu30Lib.h - mmuLib header for 68030. */

/* Copyright 1984-1992 Wind River Systems, Inc. */

/*
modification history
--------------------
01d,12oct92,kdl  removed prototype for mmuPtest().
01c,22sep92,rrr  added support for c++
01b,28jul92,jmm  added function prototypes
01a,08jul92,rdc  written.
*/

#ifndef __INCmmu30Libh
#define __INCmmu30Libh

#ifdef __cplusplus
extern "C" {
#endif


#define PAGE_SIZE 8192
#define PAGE_BLOCK_SIZE 16777216

typedef struct {
    unsigned lu:1;
    unsigned limit:15;
    unsigned zero:14;
    unsigned dt:2;
    unsigned ta:28;
    unsigned :4;
} CRP_REG;

typedef struct {
    unsigned enable:1;
    unsigned zero:5;
    unsigned sre:1;
    unsigned fcl:1;
    unsigned pageSize:4;
    unsigned initialShift:4;
    unsigned tia:4;
    unsigned tib:4;
    unsigned tic:4;
    unsigned tid:4;
} TC_REG;

/* short format table descriptor */
typedef struct {
    unsigned addr:28;
    unsigned u:1;
    unsigned wp:1;
    unsigned dt:2;
} SFT_DESC;

/* short format page descriptor */
typedef union sfpd
    {
    struct
	{
	unsigned addr:24;
	unsigned :1;
	unsigned ci:1;
	unsigned :1;
	unsigned m:1;
	unsigned u:1;
	unsigned wp:1;
	unsigned dt:2;
	} fields;
    unsigned int bits;
    } SFP_DESC;

typedef struct {
    union {
	SFT_DESC sftd;
	SFP_DESC sfpd;
    } pte;
} PTE;

typedef struct
    {
    unsigned b:1;
    unsigned l:1;
    unsigned s:1;
    unsigned :1;
    unsigned w:1;
    unsigned i:1;
    unsigned m:1;
    unsigned :2;
    unsigned t:1;
    unsigned :3;
    unsigned n:3;
    } MMU_SR;

#define MMU_BLOCKS_USED_SIZE 64

typedef struct mmuTransTblStruct
    {
    PTE *pUpperLevelTable;
    LIST memFreePageList;
    void **memBlocksUsedArray;
    int memBlocksUsedIndex;
    int memBlocksUsedSize;
    } MMU_TRANS_TBL;

#define DT_INVALID 0
#define DT_PAGE_DESCRIPTOR 1
#define DT_VALID_4_BYTE 2
#define DT_VALID_8_BYTE 3

#define MMU_STATE_MASK_VALID		0x03
#define MMU_STATE_MASK_WRITABLE		0x04
#define MMU_STATE_MASK_CACHEABLE	0x40

#define MMU_STATE_VALID			DT_PAGE_DESCRIPTOR
#define MMU_STATE_VALID_NOT		DT_INVALID
#define MMU_STATE_WRITABLE		0x00
#define MMU_STATE_WRITABLE_NOT		0x04
#define MMU_STATE_CACHEABLE		0x00
#define MMU_STATE_CACHEABLE_NOT		0x40

/* the virtual address is divided into fields of the following lengths */

#define NUM_TIA_BITS 8
#define NUM_TIB_BITS 11
#define NUM_PAGE_OFFSET_BITS 13

/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern STATUS mmu30LibInit (int pageSize);

#else   /* __STDC__ */

extern STATUS mmu30LibInit ();

#endif  /* __STDC__ */

#ifdef __cplusplus
}
#endif

#endif /* __INCmmu30Libh */
