/* regs68k.h - 68k registers */

/* Copyright 1984-1995 Wind River Systems, Inc. */
/*
modification history
--------------------
01j,30dec97,dbt  added common names for registers
01i,08jun95,p_m  added reg_set structure name for manual generation
01h,22sep92,rrr  added support for c++
01g,26may92,rrr  the tree shuffle
01f,20feb92,yao  added D_REG_BASE, D_REG_OFFSET, A_REG_BASE, A_REG_OFFSET,
		 SR_OFFSET, PC_OFFSET, DREG_NUM, AREG_NUM.  changed copyright
		 notice.
01e,04oct91,rrr  passed through the ansification filter
		  -changed ASMLANGUAGE to _ASMLANGUAGE
		  -changed copyright notice
01d,05oct90,shl  added copyright notice.
                 made #endif ANSI style.
01c,15apr90,jcf  cleaned.
01b,20aug89,gae  extracted from wind.h.
*/

#ifndef __INCregsMc68kh
#define __INCregsMc68kh

#ifdef __cplusplus
extern "C" {
#endif

#ifndef	_ASMLANGUAGE

#define DREG_NUM	8	/* has 8 32-bit data registers */
#define AREG_NUM	8	/* has 8 32-bit address registers */

typedef struct reg_set		/* REG_SET - 680x0 register set */
    {
    ULONG dataReg[8];	/* data registers */
    ULONG addrReg[8];	/* address registers */
    USHORT pad;		/* pad SR to a long */
    USHORT sr;		/* status register (must be second to last) */
    INSTR *pc;		/* program counter (must be last) */
    } REG_SET;

/* some common names for registers */

#define fpReg		addrReg[6]	/* frame pointer */
#define spReg		addrReg[7]	/* stack pointer */
#define reg_pc		pc		/* program counter */
#define reg_sp		addrReg[7]	/* stack pointer */
#define reg_fp		addrReg[6]	/* frame pointer */

#define  D_REG_BASE	0x00		/* data reg's base offset to REG_SET */
#define  D_REG_OFFSET(n)	(D_REG_BASE + (n)*sizeof(ULONG))
#define  A_REG_OFFSET(n)	D_REG_OFFSET(DREG_NUM + n)
#define  SR_OFFSET		A_REG_OFFSET(AREG_NUM)
#define  PC_OFFSET		(SR_OFFSET + 2*sizeof(USHORT))
#endif	/* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCregsMc68kh */
