/* vxPpcLib.h - header for board dependent library routines for the PowerPC */

/*
modification history
--------------------
01i,14jul97,mas  prototypes for accessing DAR, DSISR, SRR0, SRR1 (SPR 8918).
01h,31mar97,tam  added prototypes for DMA register access routines. 
01g,10feb97,tam  added prototypes for vxFpscrGet/Set()
01f,29oct96,tam  added prototypes for vxPowerDown() , vxPowerModeSet() and
		 vxPowerModeGet(); added power management mode macros.
01e,18jun96,tam  added prototypes for PPC403 debug register access routines.
01d,17jun96,tpr  added vxDerGet(), vxDerSet(), vxImmrGet() and
		 vxImmrSet() prototypes.
01c,29may96,tam  added prototypes for vxTimeBaseSet/Get (spr #6604).
01b,28feb96,tam  added some PPC403 declarations.
01a,23feb96,tpr  written.
*/

#ifndef __INCvxPpcLibh
#define __INCvxPpcLibh

#ifdef __cplusplus
extern "C" {
#endif

/* power management mode definitions - used by vxPowerModeSet/Get */

#define VX_POWER_MODE_DISABLE      0x1     /* power mgt disable: MSR(POW) = 0 */
#define VX_POWER_MODE_FULL         0x2     /* All CPU units are active */
#define VX_POWER_MODE_DOZE         0x4     /* doze power management mode */
#define VX_POWER_MODE_NAP          0x8     /* nap power management mode */
#define VX_POWER_MODE_SLEEP        0x10    /* sleep power management mode */
#define VX_POWER_MODE_DEEP_SLEEP   0x20    /* deep sleep power mgt mode */
#define VX_POWER_MODE_DPM          0x40    /* dynamic power management mode */
#define VX_POWER_MODE_DOWN         0x80    /* all units down */

/* DMA channel definition for the vxDmaXXGet/Set() routines */

#define	DMA_CHANNEL_0		0
#define	DMA_CHANNEL_1		1
#define	DMA_CHANNEL_2		2
#define	DMA_CHANNEL_3		3

/* function declarations */

#ifndef	_ASMLANGUAGE
#if defined(__STDC__) || defined(__cplusplus)

IMPORT void	vxMsrSet (UINT32);
IMPORT UINT32	vxMsrGet (void);
IMPORT void	vxDarSet (UINT32);
IMPORT UINT32	vxDarGet (void);
IMPORT void	vxDsisrSet (UINT32);
IMPORT UINT32	vxDsisrGet (void);
IMPORT void	vxSrr0Set (UINT32);
IMPORT UINT32	vxSrr0Get (void);
IMPORT void	vxSrr1Set (UINT32);
IMPORT UINT32	vxSrr1Get (void);
IMPORT UINT32	vxFirstBit (UINT32);
IMPORT UINT32	vxPvrGet (void);
IMPORT void	vxDecSet (UINT32);
IMPORT UINT32	vxDecGet (void);
IMPORT void	vxHid0Set (UINT32);
IMPORT UINT32	vxHid0Get (void);
IMPORT STATUS	vxPowerDown (void);
IMPORT STATUS	vxPowerModeSet (UINT32);
IMPORT UINT32	vxPowerModeGet (void);
IMPORT void	vxTimeBaseSet (UINT32 tbu, UINT32 tbl);
IMPORT void	vxTimeBaseGet (UINT32 * pTbu, UINT32 * pTbl);
IMPORT void	vxFpscrSet (UINT32);
IMPORT UINT32	vxFpscrGet (void);
#if 	(CPU == PPC403)
IMPORT UINT32	vxExierEnable (UINT32);
IMPORT UINT32	vxExierDisable (UINT32);
IMPORT void     vxPitSet (UINT32);
IMPORT UINT32   vxPitGet (void);
IMPORT void     vxPitIntEnable (void);
IMPORT void     vxPitIntAck (void);
IMPORT void     vxFitIntEnable (void);
IMPORT void     vxFitIntDisable (void);
IMPORT void     vxFitIntAck (void);
IMPORT UINT32   vxExisrGet (void);
IMPORT void     vxExisrClear (UINT32);
IMPORT UINT32   vxExierGet (void);
IMPORT void     vxExierSet (UINT32);
IMPORT UINT32   vxDccrGet (void);
IMPORT void     vxDccrSet (UINT32);
IMPORT UINT32   vxIccrGet (void);
IMPORT void     vxIccrSet (UINT32);
IMPORT UINT32   vxEvprGet (void);
IMPORT void     vxEvprSet (UINT32);
IMPORT UINT32   vxIocrGet (void);
IMPORT void     vxIocrSet (UINT32);
IMPORT UINT32   vxTcrGet (void);
IMPORT void     vxTcrSet (UINT32);
IMPORT UINT32   vxTsrGet (void);
IMPORT void     vxTsrSet (UINT32);
IMPORT void     vxBesrSet (UINT32);
IMPORT UINT32   vxDbcrGet (void);
IMPORT void     vxDbcrSet (UINT32);
IMPORT UINT32   vxDbsrGet (void);
IMPORT void     vxDbsrClear (UINT32);
IMPORT UINT32   vxDac1Get (void);
IMPORT void     vxDac1Set (UINT32);
IMPORT UINT32   vxDac2Get (void);
IMPORT void     vxDac2Set (UINT32);
IMPORT UINT32   vxIac1Get (void);
IMPORT void     vxIac1Set (UINT32);
IMPORT UINT32   vxIac2Get (void);
IMPORT void     vxIac2Set (UINT32);
IMPORT void	vxDmacrSet (UINT32 regVal, UINT32 dmaRegNo);
IMPORT UINT32	vxDmacrGet (UINT32 dmaRegNo);
IMPORT void	vxDmasrSet (UINT32 regVal);
IMPORT UINT32	vxDmasrGet (void);
IMPORT void	vxDmaccSet (UINT32 regVal, UINT32 dmaRegNo);
IMPORT UINT32	vxDmaccGet (UINT32 dmaRegNo);
IMPORT void	vxDmactSet (UINT32 regVal, UINT32 dmaRegNo);
IMPORT UINT32	vxDmactGet (UINT32 dmaRegNo);
IMPORT void	vxDmadaSet (UINT32 regVal, UINT32 dmaRegNo);
IMPORT UINT32	vxDmadaGet (UINT32 dmaRegNo);
IMPORT void	vxDmasaSet (UINT32 regVal, UINT32 dmaRegNo);
IMPORT UINT32	vxDmasaGet (UINT32 dmaRegNo);
#endif /* (CPU == PPC403) */

#if	(CPU == PPC860)
IMPORT	void	vxImmrSet (UINT32);
IMPORT	UINT32	vxImmrGet (void);
IMPORT	void	vxDerSet (UINT32);
IMPORT	UINT32	vxDerGet (void);
#endif  /* (CPU == PPC860) */

#else  	/* __STDC__ */

IMPORT void	vxMsrSet ();
IMPORT UINT32	vxMsrGet();
IMPORT void	vxDarSet ();
IMPORT UINT32	vxDarGet ();
IMPORT void	vxDsisrSet ();
IMPORT UINT32	vxDsisrGet ();
IMPORT void	vxSrr0Set ();
IMPORT UINT32	vxSrr0Get ();
IMPORT void	vxSrr1Set ();
IMPORT UINT32	vxSrr1Get ();
IMPORT UINT32	vxFirstBit ();
IMPORT UINT32	vxPvrGet ();
IMPORT void	vxDecSet ();
IMPORT UINT32	vxDecGet();
IMPORT void	vxHid0Set ();
IMPORT UINT32	vxHid0Get ();
IMPORT STATUS	vxPowerDown ();
IMPORT STATUS	vxPowerModeSet ();
IMPORT UINT32	vxPowerModeGet ();
IMPORT void	vxTimeBaseSet ();
IMPORT void	vxTimeBaseGet ();
IMPORT void	vxFpscrSet ();
IMPORT UINT32	vxFpscrGet ();
#if 	(CPU == PPC403)
IMPORT UINT32	vxExierEnable ();
IMPORT UINT32	vxExierDisable ();
IMPORT void     vxPitSet ();
IMPORT UINT32   vxPitGet ();
IMPORT void     vxPitIntEnable ();
IMPORT void     vxPitIntAck ();
IMPORT void     vxFitIntEnable ();
IMPORT void     vxFitIntDisable ();
IMPORT void     vxFitIntAck ();
IMPORT UINT32   vxExisrGet ();
IMPORT void     vxExisrClear ();
IMPORT UINT32   vxExierGet ();
IMPORT void     vxExierSet ();
IMPORT UINT32   vxDccrGet ();
IMPORT void     vxDccrSet ();
IMPORT UINT32   vxIccrGet ();
IMPORT void     vxIccrSet ();
IMPORT UINT32   vxEvprGet ();
IMPORT void     vxEvprSet ();
IMPORT UINT32   vxIocrGet ();
IMPORT void     vxIocrSet ();
IMPORT UINT32   vxTcrGet ();
IMPORT void     vxTcrSet ();
IMPORT UINT32   vxTsrGet ();
IMPORT void     vxTsrSet ();
IMPORT void     vxBesrSet ();
IMPORT UINT32   vxDbcrGet ();
IMPORT void     vxDbcrSet ();
IMPORT UINT32   vxDbsrGet ();
IMPORT void     vxDbsrClear ();
IMPORT UINT32   vxDac1Get ();
IMPORT void     vxDac1Set ();
IMPORT UINT32   vxDac2Get ();
IMPORT void     vxDac2Set ();
IMPORT UINT32   vxIac1Get ();
IMPORT void     vxIac1Set ();
IMPORT UINT32   vxIac2Get ();
IMPORT void     vxIac2Set ();
IMPORT void	vxDmacrSet ();
IMPORT UINT32	vxDmacrGet ();
IMPORT void	vxDmasrSet ();
IMPORT UINT32	vxDmasrGet ();
IMPORT void	vxDmaccSet ();
IMPORT UINT32	vxDmaccGet ();
IMPORT void	vxDmactSet ();
IMPORT UINT32	vxDmactGet ();
IMPORT void	vxDmadaSet ();
IMPORT UINT32	vxDmadaGet ();
IMPORT void	vxDmasaSet ();
IMPORT UINT32	vxDmasaGet ();
#endif /* (CPU == PPC403) */

#if	(CPU == PPC860)
IMPORT	void	vxImmrSet ();
IMPORT	UINT32	vxImmrGet ();
IMPORT	void	vxDerSet ();
IMPORT	UINT32	vxDerGet ();
#endif  /* (CPU == PPC860) */

#endif 	/* __STDC__ */
#endif  /* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCvxPpcLibh */
