/* ataDrv.h - ATA/IDE (LOCAL and PCMCIA) disk controller header */

/* Copyright 1984-1996 Wind River Systems, Inc. */
/*
modification history
--------------------
01f,30oct97,db   added macro ATA_SWAP for big endian targets. changed some 
                 elements in ATA_CTRL from short to UINT32.
01e,10dec97,ms   added usrAtaConfig prototype and ataResources import
01e,01nov96,hdn  added support for PCMCIA
01d,25sep96,hdn  added support for ATA-2
01c,18mar96,hdn  added ataShowInit().
01b,01mar96,hdn  cleaned up.
01a,02mar95,hdn  written based on ideDrv.h.
*/

#ifndef __INCpcataDrvh
#define __INCpcataDrvh

#ifdef __cplusplus
extern "C" {
#endif

#ifndef _ASMLANGUAGE


#include "dosFsLib.h"
#include "blkIo.h"
#include "wdLib.h"
#include "private/semLibP.h"
#include "drv/pcmcia/pccardLib.h"

IMPORT ATA_RESOURCE ataResources[];
/* define swap macro for little/big endian machines */

#if _BYTE_ORDER == _BIG_ENDIAN
#   define ATA_SWAP(x) LONGSWAP(x)
#else
#   define ATA_SWAP(x) (x)
#endif

#define IDE_LOCAL		0 	/* ctrl type: LOCAL(IDE) */
#define ATA_PCMCIA		1	/* ctrl type: PCMCIA */

#define ATA_MAX_CTRLS		2	/* max number of ATA controller */
#define ATA_MAX_DRIVES		2	/* max number of ATA drives */

typedef struct ataParams 
    {
    short config;		/* general configuration */
    short cylinders;		/* number of cylinders */
    short removcyl;		/* number of removable cylinders */
    short heads;		/* number of heads */
    short bytesTrack;		/* number of unformatted bytes/track */
    short bytesSec;		/* number of unformatted bytes/sector */
    short sectors;		/* number of sectors/track */
    short bytesGap;		/* minimum bytes in intersector gap */
    short bytesSync;		/* minimum bytes in sync field */
    short vendstat;		/* number of words of vendor status */
    char serial[20];		/* controller serial number */
    short type;			/* controller type */
    short size;			/* sector buffer size, in sectors */
    short bytesEcc;		/* ecc bytes appended */
    char rev[8];		/* firmware revision */
    char model[40];		/* model name */
    short multiSecs;		/* RW multiple support. bits 7-0 ia max secs */
    short reserved48;		/* reserved */
    short capabilities;		/* capabilities */
    short reserved50;		/* reserved */
    short pioMode;		/* PIO data transfer cycle timing mode */
    short dmaMode;		/* single word DMA data transfer cycle timing */
    short valid;		/* field validity */
    short currentCylinders;	/* number of current logical cylinders */
    short currentHeads;		/* number of current logical heads */
    short currentSectors;	/* number of current logical sectors / track */
    short capacity0;		/* current capacity in sectors */
    short capacity1;		/* current capacity in sectors */
    short multiSet;		/* multiple sector setting */
    short sectors0;		/* total number of user addressable sectors */
    short sectors1;		/* total number of user addressable sectors */
    short singleDma;		/* single word DMA transfer */
    short multiDma;		/* multi word DMA transfer */
    short advancedPio;		/* flow control PIO transfer modes supported */
    short cycletimeDma;		/* minimum multiword DMA transfer cycle time */
    short cycletimeMulti;	/* recommended multiword DMA cycle time */
    short cycletimePioNoIordy;	/* min PIO transfer cycle time wo flow ctl */
    short cycletimePioIordy;	/* min PIO transfer cycle time w IORDY */
    short reserved69;		/* reserved */
    short reserved70;		/* reserved */
    short reserved71[57];	/* reserved */
    short vendor[32];		/* vendor specific */
    short reserved160[96];	/* reserved */
    } ATA_PARAM;

typedef struct ataDrive
    {
    ATA_PARAM	param;		/* geometry parameter */
    short	okMulti;	/* MULTI: TRUE if supported */
    short	okIordy;	/* IORDY: TRUE if supported */
    short	okDma;		/* DMA:   TRUE if supported */
    short	okLba;		/* LBA:   TRUE if supported */
    short	multiSecs;	/* supported max sectors for multiple RW */
    short	pioMode;	/* supported max PIO mode */
    short	singleDmaMode;	/* supported max single word DMA mode */
    short	multiDmaMode;	/* supported max multi word DMA mode */
    short	rwMode;		/* RW mode: PIO[0,1,2,3,4] or DMA[0,1,2] */
    short	rwBits;		/* RW bits: 16 or 32 */
    short	rwPio;		/* RW PIO unit: single or multi sector */
    short	rwDma;		/* RW DMA unit: single or multi word */
    } ATA_DRIVE;

typedef struct ataCtrl
    {
    ATA_DRIVE	drive[ATA_MAX_DRIVES];	/* drives per controller */
    SEMAPHORE	syncSem;	/* binary sem for syncronization */
    SEMAPHORE	muteSem;	/* mutex  sem for mutual-exclusion */
    WDOG_ID	wdgId;		/* watch dog */
    BOOL	wdgOkay;	/* watch dog status */
    int		semTimeout;	/* timeout seconds for sync semaphore */
    int		wdgTimeout;	/* timeout seconds for watch dog */
    int		ctrlType;	/* type of controller */
    BOOL	installed;	/* TRUE if a driver is installed */
    BOOL	changed;	/* TRUE if a card is installed */
    int		intLevel;	/* interrupt level */
    int		intCount;	/* interrupt count */
    int		intStatus;	/* interrupt status */
    int		drives;		/* number of drives in the controller */
    UINT32	data;		/* (RW) data register (16 bits)	*/
    UINT32	error;		/* (R)  error register		*/
    UINT32	feature;	/* (W)  feature or write-precompensation */
    UINT32	seccnt;		/* (RW) sector count		*/
    UINT32	sector;		/* (RW) first sector number	*/
    UINT32	cylLo;		/* (RW) cylinder low byte	*/
    UINT32	cylHi;		/* (RW) cylinder high byte	*/
    UINT32	sdh;		/* (RW) sector size/drive/head	*/
    UINT32	command;	/* (W)  command register	*/
    UINT32	status;		/* (R)  immediate status	*/
    UINT32	aStatus;	/* (R)  alternate status	*/
    UINT32	dControl;	/* (W)  disk controller control	*/
    UINT32	dAddress;	/* (R)  disk controller address */
    } ATA_CTRL;

typedef struct ataDev
    {
    BLK_DEV blkDev;		/* must be here */
    int ctrl;			/* ctrl no.  0 - 1 */
    int drive;			/* drive no. 0 - 1 */
    int blkOffset;		/* sector offset */
    } ATA_DEV;

typedef struct ataType
    {
    int cylinders;		/* number of cylinders */
    int heads;			/* number of heads */
    int sectors;		/* number of sectors per track */
    int bytes;			/* number of bytes per sector */
    int precomp;		/* precompensation cylinder */
    } ATA_TYPE;

typedef struct ataRaw
    {				/* this is for ATARAWACCESS ioctl */
    UINT cylinder;		/* cylinder (0 -> (cylindres-1)) */
    UINT head;			/* head (0 -> (heads-1)) */
    UINT sector;		/* sector (1 -> sectorsTrack) */
    char *pBuf;			/* pointer to buffer (bytesSector * nSecs) */
    UINT nSecs;			/* number of sectors (1 -> sectorsTrack) */
    UINT direction;		/* read=0, write=1 */
    } ATA_RAW;


#define ATA_SEM_TIMEOUT_DEF	5       /* default timeout for ATA sync sem */
#define ATA_WDG_TIMEOUT_DEF	5       /* default timeout for ATA watch dog */


/* ATA registers */

#define	ATA_DATA(base0)		(base0 + 0) /* (RW) data register (16 bits) */
#define ATA_ERROR(base0)	(base0 + 1) /* (R)  error register	    */
#define	ATA_FEATURE(base0)	(base0 + 1) /* (W)  feature/precompensation */
#define	ATA_SECCNT(base0)	(base0 + 2) /* (RW) sector count	    */
#define	ATA_SECTOR(base0)	(base0 + 3) /* (RW) first sector number	    */
#define	ATA_CYL_LO(base0)	(base0 + 4) /* (RW) cylinder low byte	    */
#define	ATA_CYL_HI(base0)	(base0 + 5) /* (RW) cylinder high byte	    */
#define	ATA_SDH(base0)		(base0 + 6) /* (RW) sector size/drive/head  */
#define	ATA_COMMAND(base0)	(base0 + 7) /* (W)  command register	    */
#define	ATA_STATUS(base0) 	(base0 + 7) /* (R)  immediate status	    */
#define	ATA_A_STATUS(base1)	(base1 + 0) /* (R)  alternate status	    */
#define	ATA_D_CONTROL(base1)	(base1 + 0) /* (W)  disk controller control */
#define	ATA_D_ADDRESS(base1)	(base1 + 1) /* (R)  disk controller address */


/* diagnostic code */

#define ATA_DIAG_OK		0x01

/* control register */

#define ATA_CTL_4BIT	 	0x8	/* use 4 head bits (wd1003) */
#define ATA_CTL_RST 		0x4	/* reset controller */
#define ATA_CTL_IDS 		0x2	/* disable interrupts */

/* status register */

#define	ATA_STAT_BUSY		0x80	/* controller busy */
#define	ATA_STAT_READY		0x40	/* selected drive ready */
#define	ATA_STAT_WRTFLT		0x20	/* write fault */
#define	ATA_STAT_SEEKCMPLT	0x10	/* seek complete */
#define	ATA_STAT_DRQ		0x08	/* data request */
#define	ATA_STAT_ECCCOR		0x04	/* ECC correction made in data */
#define	ATA_STAT_INDEX		0x02	/* index pulse from selected drive */
#define	ATA_STAT_ERR		0x01	/* error detect */

/* size/drive/head register: addressing mode CHS or LBA */

#define ATA_SDH_IBM		0xa0	/* chs, 512 bytes sector, ecc */
#define ATA_SDH_LBA		0xe0	/* lba, 512 bytes sector, ecc */

/* commands */

#define	ATA_CMD_RECALIB		0x10	/* recalibrate */
#define	ATA_CMD_SEEK		0x70	/* seek */
#define	ATA_CMD_READ		0x20	/* read sectors with retries */
#define	ATA_CMD_WRITE		0x30	/* write sectors with retries */
#define	ATA_CMD_FORMAT		0x50	/* format track */
#define	ATA_CMD_DIAGNOSE	0x90	/* execute controller diagnostic */
#define	ATA_CMD_INITP		0x91	/* initialize drive parameters */
#define	ATA_CMD_READP		0xEC	/* identify */
#define	ATA_CMD_SET_FEATURE 	0xEF	/* set features */
#define	ATA_CMD_SET_MULTI	0xC6	/* set multi */
#define	ATA_CMD_READ_MULTI	0xC4	/* read multi */
#define	ATA_CMD_WRITE_MULTI	0xC5	/* write multi */

/* sub command of ATA_CMD_SET_FEATURE */

#define ATA_SUB_ENABLE_8BIT	0x01	/* enable 8bit data transfer */
#define ATA_SUB_ENABLE_WCACHE	0x02	/* enable write cache */
#define ATA_SUB_SET_RWMODE	0x03	/* set transfer mode */
#define ATA_SUB_DISABLE_RETRY	0x33	/* disable retry */
#define ATA_SUB_SET_LENGTH	0x44	/* length of vendor specific bytes */
#define ATA_SUB_SET_CACHE	0x54	/* set cache segments */
#define ATA_SUB_DISABLE_LOOK	0x55	/* disable read look-ahead feature */
#define ATA_SUB_DISABLE_REVE	0x66	/* disable reverting to power on def */
#define ATA_SUB_DISABLE_ECC	0x77	/* disable ECC */
#define ATA_SUB_DISABLE_8BIT	0x81	/* disable 8bit data transfer */
#define ATA_SUB_DISABLE_WCACHE	0x82	/* disable write cache */
#define ATA_SUB_ENABLE_ECC	0x88	/* enable ECC */
#define ATA_SUB_ENABLE_RETRY	0x99	/* enable retries */
#define ATA_SUB_ENABLE_LOOK	0xaa	/* enable read look-ahead feature */
#define ATA_SUB_SET_PREFETCH	0xab	/* set maximum prefetch */
#define ATA_SUB_SET_4BYTES	0xbb	/* 4 bytes of vendor specific bytes */
#define ATA_SUB_ENABLE_REVE	0xcc	/* enable reverting to power on def */

/* transfer modes of ATA_SUB_SET_RWMODE */

#define ATA_PIO_DEF_W		0x00	/* PIO default trans. mode */
#define ATA_PIO_DEF_WO		0x01	/* PIO default trans. mode, no IORDY */
#define ATA_PIO_W_0		0x08	/* PIO flow control trans. mode 0 */
#define ATA_PIO_W_1		0x09	/* PIO flow control trans. mode 1 */
#define ATA_PIO_W_2		0x0a	/* PIO flow control trans. mode 2 */
#define ATA_PIO_W_3		0x0b	/* PIO flow control trans. mode 3 */
#define ATA_PIO_W_4		0x0c	/* PIO flow control trans. mode 4 */
#define ATA_DMA_SINGLE_0	0x10	/* singleword DMA mode 0 */
#define ATA_DMA_SINGLE_1	0x11	/* singleword DMA mode 1 */
#define ATA_DMA_SINGLE_2	0x12	/* singleword DMA mode 2 */
#define ATA_DMA_MULTI_0		0x20	/* multiword DMA mode 0 */
#define ATA_DMA_MULTI_1		0x21	/* multiword DMA mode 1 */
#define ATA_DMA_MULTI_2		0x22	/* multiword DMA mode 2 */
#define ATA_MAX_RW_SECTORS	0x100	/* max sectors per transfer */

/* configuration flags: transfer mode, bits, unit, geometry */

#define ATA_PIO_DEF_0		ATA_PIO_DEF_W	/* PIO default mode */
#define ATA_PIO_DEF_1		ATA_PIO_DEF_WO	/* PIO default mode, no IORDY */
#define ATA_PIO_0		ATA_PIO_W_0	/* PIO mode 0 */
#define ATA_PIO_1		ATA_PIO_W_1	/* PIO mode 1 */
#define ATA_PIO_2		ATA_PIO_W_2	/* PIO mode 2 */
#define ATA_PIO_3		ATA_PIO_W_3	/* PIO mode 3 */
#define ATA_PIO_4		ATA_PIO_W_4	/* PIO mode 4 */
#define ATA_PIO_AUTO		0x000d		/* PIO max supported mode */
#define ATA_DMA_0		0x0002		/* DMA mode 0 */
#define ATA_DMA_1		0x0003		/* DMA mode 1 */
#define ATA_DMA_2		0x0004		/* DMA mode 2 */
#define ATA_DMA_AUTO		0x0005		/* DMA max supported mode */
#define ATA_MODE_MASK		0x000F		/* transfer mode mask */

#define ATA_BITS_16		0x0040		/* RW bits size, 16 bits */
#define ATA_BITS_32		0x0080		/* RW bits size, 32 bits */
#define ATA_BITS_MASK		0x00c0		/* RW bits size mask */

#define ATA_PIO_SINGLE		0x0010		/* RW PIO single sector */
#define ATA_PIO_MULTI		0x0020		/* RW PIO multi sector */
#define ATA_PIO_MASK		0x0030		/* RW PIO mask */

#define ATA_DMA_SINGLE		0x0400		/* RW DMA single word */
#define ATA_DMA_MULTI		0x0800		/* RW DMA multi word */
#define ATA_DMA_MASK		0x0c00		/* RW DMA mask */

#define ATA_GEO_FORCE		0x0100		/* set geometry in the table */
#define ATA_GEO_PHYSICAL	0x0200		/* set physical geometry */
#define ATA_GEO_CURRENT		0x0300		/* set current geometry */
#define ATA_GEO_MASK		0x0300		/* geometry mask */


/* function declarations */

#if defined(__STDC__) || defined(__cplusplus)

extern STATUS	ataDrv		(int ctrl, int drives, int vector, int level,
				 BOOL configType, int semTimeout,
				 int wdgTimeout);
extern BLK_DEV	*ataDevCreate	(int ctrl, int drive, int nBlks, int offset);
extern STATUS	ataRawio	(int ctrl, int drive, ATA_RAW *pAtaRaw);
extern void	ataShowInit	(void);
extern STATUS	ataShow		(int ctrl, int drive);
extern int	usrAtaPartition	(int ctrl, int drive, DOS_PART_TBL *pPart);
extern STATUS   usrAtaConfig	(int ctrl, int drive, char *fileName);
extern void     usrAtaInit	(void);

#else

extern STATUS	ataDrv		();
extern BLK_DEV	*ataDevCreate	();
extern STATUS	ataRawio	();
extern void	ataShowInit	();
extern STATUS	ataShow		();
extern int	usrAtaPartition	();
extern STATUS   usrAtaConfig	();
extern void     usrAtaInit	();

#endif  /* __STDC__ */


#endif  /* _ASMLANGUAGE */

#ifdef __cplusplus
}
#endif

#endif /* __INCpcataDrvh */
