/* tyIoctlPep.h - special I/O control features for tty drivers */

/* Copyright 1990-1994, PEP Modular Computers */

/*
modification history
--------------------
01f,17aug93,haw  added defines for different modes
01e,28jul92,haw  added FIOSETSEM, FIORELSEM, FIORESET
01d,07jul92,haw  added FIO_HW_FLOW_CTRL, FIO_RTS_CTS_HS
01c,28jan92,haw  Changed definitions to a more clear style,
                 made endif ANSI style
01b,02sep91,haw  Fixed documentation, changed sequence of defines
01a,25jul90,pep  Original writing
*/

#ifndef INCtyIoctlPeph
#define INCtyIoctlPeph

#ifdef __cplusplus 
extern "C" { 
#endif /* __cplusplus */ 

/* thresholds for RTS/CTS handshake */

#define RTS_UPPER_THRESHOLD     0.9     /* obsolete */
#define RTS_LOWER_THRESHOLD     0.1     /* obsolete */

#define HS_UPPER_THRESHOLD      0.9
#define HS_LOWER_THRESHOLD      0.1

/* special definitions for the state of hardware lines */

#define HIGH                      1
#define LOW                       0

/* additional I/O control calls supported by PEP */

#define FIOPARITY               100     /* set parity */
#define FIOSTOPBITS             101     /* set number of stop bits */
#define FIOCHARSIZE             102     /* set character size */
#define FIOHANDSHAKE            103     /* obsolete */
#define FIOSET_485              104     /* RS 485 piggy back in use or not */

#define FIO_HW_FLOW_CTRL        103     /* hardware flow control (DTR/CTS) */
#define FIO_RTS_CTS_HS          105     /* RTS/CTS handshake */

#define FIOSETSEM               110     /* set use of semaphore */
#define FIORELSEM               111     /* release use of semaphore */

#define FIORESET                120     /* reset a channel */

/* arguments for I/O control call FIOPARITY */

#define NO_PARITY                 0     /* obsolete */
#define ODD_PARITY                1     /* obsolete */
#define EVEN_PARITY               2     /* obsolete */

#define PAR_NO                    0
#define PAR_ODD                   1
#define PAR_EVEN                  2

/* arguments for I/O control call FIOSTOPBITS */

#define ONE_STOP_BIT              0     /* obsolete */
#define TWO_STOP_BITS             1     /* obsolete */
#define THREE_HALF_STOP_BITS      2     /* obsolete */

#define STOP_BIT_ONE              0
#define STOP_BITS_TWO             1
#define STOP_BITS_1X5             2

/* arguments for I/O control call FIOCHARSIZE */

#define CHAR_SIZE_7               0
#define CHAR_SIZE_8               1

/* different modes and different interfaces */

#define NORMAL_MODE  0
#define HW_FLOW_CTRL 1
#define SC_485       2   
#define RTS_CTS_HS   3

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif  /* INCtyIoctlPeph */
