/* templateSio.h - header file for template serial driver */

/* Copyright 1984-1997 Wind River Systems, Inc. */

/*
modification history
--------------------
01d,01jul97,db	added registers and defines for modem control. 
01c,24feb97,dat  used SIO_CHAN as first structure element,
		instead of SIO_DRV_FUNCS *.
01b,17dec96,dat added 'options' to chan structure.
01a,02aug95,ms  written.
*/

#ifndef __INCtemplateSioh
#define __INCtemplateSioh

#include "sioLib.h"

/* device and channel structures */

typedef struct
    {
    /* must be first */

    SIO_CHAN		sio;		/* standard SIO_CHAN element */

    /* callbacks */

    STATUS	        (*getTxChar) ();
    STATUS	        (*putRcvChar) ();
    void *	        getTxArg;
    void *	        putRcvArg;

    /* register addresses */

    volatile char *     cr;             /* channel control register */
    volatile char *     dr;             /* channel data register */
    volatile char *     sr;             /* channel status register */
    volatile char *	ms;		/* channel modem status register */
    volatile char *	mc;		/* channel modem control register */ 
    volatile short *    br;             /* channel baud constant register */

    /* misc */

    int                 mode;           /* current mode (interrupt or poll) */
    int                 baudFreq;       /* input clock frequency */
    int			options;	/* Hardware options */
    } TEMPLATE_CHAN;

typedef struct
    {
    TEMPLATE_CHAN	portA;          /* DUSRAT has two channels */
    TEMPLATE_CHAN	portB;
    volatile char *     masterCr;        /* master control register */
    } TEMPLATE_DUSART;

/* definitions */

	/* master control register definitions */

#define TEMPLATE_RESET_CHIP	0x1

	/* channel control register definitions */

#define TEMPLATE_RESET_TX	0x1	/* reset the transmitter */
#define TEMPLATE_RESET_ERR	0x2	/* reset error condition */
#define TEMPLATE_RESET_INT	0x4	/* acknoledge the interrupt */
#define	TEMPLATE_INT_ENABLE	0x8	/* enable interrupts */

	/* channel status register definitions */

#define TEMPLATE_TX_READY	0x1	/* txmitter ready for another char */
#define TEMPLATE_RX_AVAIL	0x2	/* character has arrived */

	/* channel modem status register definitions */

#define	TEMPLATE_MS_RTS		0x1	/* RTS signal asserted */
#define TEMPLATE_MS_DTR		0x2	/* DTR signal asserted */

	/* channel modem control register definitions */

#define TEMPLATE_MC_RTS		0x1	/* enable RTS */
#define TEMPLATE_MC_DTR		0x2	/* enable DTR */

/* function prototypes */

#if defined(__STDC__)

extern void 	templateDevInit	(TEMPLATE_DUSART *pDusart); 
extern void	templateIntRcv	(TEMPLATE_CHAN *pChan);
extern void	templateIntTx	(TEMPLATE_CHAN *pChan);
extern void	templateIntErr	(TEMPLATE_CHAN *pChan);

#else   /* __STDC__ */

extern void 	templateDevInit	();
extern void	templateIntRcv	();
extern void	templateIntTx	();
extern void	templateIntErr	();

#endif  /* __STDC__ */

#endif  /* __INCtemplateSioh */
