/* n8571Timer.h - National Semiconductor real time clock */

/* Copyright 1990-1994, PEP Modular Computers GmbH */

/*
modification history
--------------------
01d,07jun93,haw  moved to this place, made all registers volatile
01c,19dec91,haw  added constant RTC_ACCESS_WIDTH to support all CPUs
01b,02sep91,haw  changed char to UINT8
01a,19mar90,trl  written
*/

#ifndef INCn8571Timerh
#define INCn8571Timerh

#ifdef __cplusplus 
extern "C" { 
#endif /* __cplusplus */ 

/* registers */

#ifndef _ASMLANGUAGE
#define DP8571_MSR(base)                ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*0)
#define DP8571_TIM0_CNTRL(base)         ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*1)
#define DP8571_REALTIME_MODE(base)      ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*1)
#define DP8571_TIM1_CNTRL(base)         ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*2)
#define DP8571_OUTPUT_MODE(base)        ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*2)
#define DP8571_PER_FLAG(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*3)
#define DP8571_INT_CNTRL0(base)         ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*3)
#define DP8571_INT_ROUTING(base)        ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*4)
#define DP8571_INT_CNTRL1(base)         ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*4)
#define DP8571_100s_SEC(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*5)
#define DP8571_SEC_CNT(base)            ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*6)
#define DP8571_MIN_CNT(base)            ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*7)
#define DP8571_HOUR_CNT(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*8)
#define DP8571_DAY_OF_MONTH_CNT(base)   ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*9)
#define DP8571_MONTH_CNT(base)          ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*10)
#define DP8571_YEAR_CNT(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*11)
#define DP8571_UNITS_JULIAN_CNT(base)   ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*12)
#define DP8571_100s_JULIAN_CNT(base)    ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*13)
#define DP8571_DAY_OF_WEEK_CNT(base)    ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*14)
#define DP8571_TIM0_LSB(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*15)
#define DP8571_TIM0_MSB(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*16)
#define DP8571_TIM1_LSB(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*17)
#define DP8571_TIM1_MSB(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*18)
#define DP8571_SEC_CMP(base)            ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*19)
#define DP8571_MIN_CMP(base)            ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*20)
#define DP8571_HOUR_CMP(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*21)
#define DP8571_DAY_OF_MONTH_CMP(base)   ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*22)
#define DP8571_MONTH_CMP(base)          ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*23)
#define DP8571_DAY_OF_WEEK_CMP(base)    ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*24)
#define DP8571_SEC_TIME_SAVE(base)      ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*25)
#define DP8571_MIN_TIME_SAVE(base)      ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*26)
#define DP8571_HOUR_TIME_SAVE(base)     ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*27)
#define DP8571_DAY_OF_MONTH_SAVE(base)  ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*28)
#define DP8571_MONTH_TIME_SAVE(base)    ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*29)
#define DP8571_ONE_BYTE_RAM(base)       ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*30)
#define DP8571_TEST_REG(base)           ((volatile UINT8 *) (base) + RTC_ACCESS_WIDTH*31)
#else /* !_ASMLANGUAGE */
#define DP8571_MSR                      (RTC_ACCESS_WIDTH*0)
#define DP8571_TIM0_CNTRL               (RTC_ACCESS_WIDTH*1)
#define DP8571_REALTIME_MODE            (RTC_ACCESS_WIDTH*1)
#define DP8571_TIM1_CNTRL               (RTC_ACCESS_WIDTH*2)
#define DP8571_OUTPUT_MODE              (RTC_ACCESS_WIDTH*2)
#define DP8571_PER_FLAG                 (RTC_ACCESS_WIDTH*3)
#define DP8571_INT_CNTRL0               (RTC_ACCESS_WIDTH*3)
#define DP8571_INT_ROUTING              (RTC_ACCESS_WIDTH*4)
#define DP8571_INT_CNTRL1               (RTC_ACCESS_WIDTH*4)
#endif /* !_ASMLANGUAGE */

/* main status register */

#define DP8571_INT_PENDING                  0x01
#define DP8571_PWR_FAIL_INT                 0x02
#define DP8571_PERIODIC_INT                 0x04
#define DP8571_ALARM_INT                    0x08
#define DP8571_TIMER0_INT                   0x10
#define DP8571_TIMER1_INT                   0x20
#define DP8571_REG_SET_1_SEL                0x40
#define DP8571_RAM_PAGE_SEL                 0x80

/* timer 0/1 control register */

#define DP8571_TIMER_START_STOP             0x01
#define DP8571_MODE_SEL_M0                  0x02
#define DP8571_MODE_SEL_M1                  0x04
#define DP8571_INPUT_CLK_SEL_C0             0x08
#define DP8571_INPUT_CLK_SEL_C1             0x10
#define DP8571_INPUT_CLK_SEL_C2             0x20
#define DP8571_TIMER_READ                   0x40
#define DP8571_COUNT_HOLD_GATE              0x80

/* periodic flag register */

#define DP8571_MINUTES_FLAG                 0x01
#define DP8571_10s_SECONDS_FLAG             0x02
#define DP8571_SECONDS_FLAG                 0x04
#define DP8571_10e_SECONDS_FLAG             0x08
#define DP8571_100e_SECONDS_FLAG            0x10
#define DP8571_MILLISECONDS_FLAG            0x20
#define DP8571_OSCILLATOR_FAILED            0x40
#define DP8571_TEST_MODE                    0x80

/* interrupt routing register */

#define DP8571_PWR_FAIL_ROUTE               0x01
#define DP8571_PERIODIC_ROUTE               0x02
#define DP8571_ALARM_ROUTE                  0x04
#define DP8571_TIMER0_ROUTE                 0x08
#define DP8571_TIMER1_ROUTE                 0x10
#define DP8571_PWR_FAIL_DELAY               0x20
#define DP8571_LOW_BATTERY_FLAG             0x40
#define DP8571_TIME_SAVE_ENABLE             0x80

/* real time mode register */

#define DP8571_LEAP_YEAR_LSB                0x01
#define DP8571_LEAP_YEAR_MSB                0x02
#define DP8571_12_24_HOUR_MODE              0x04
#define DP8571_CLK_START_STOP               0x08
#define DP8571_INT_OP                       0x10
#define DP8571_TIMER_PF_OP                  0x20
#define DP8571_OSCILLATOR_FREQ1             0x40
#define DP8571_OSCILLATOR_FREQ2             0x80

/* output mode register */

#define DP8571_T1_ACTIVE_HIGH               0x01
#define DP8571_T1_PUSH_PULL                 0x02
#define DP8571_INT_ACTIVE_HIGH              0x04
#define DP8571_INT_PUSH_PULL                0x08
#define DP8571_MFO_ACTIVE_HIGH              0x10
#define DP8571_MFO_PUSH_PULL                0x20
#define DP8571_MFO_TIMER0                   0x40
#define DP8571_MFO_OSCILLATOR               0x80

/* interrupt control register 0 */

#define DP8571_MINUTES_ENABLE               0x01
#define DP8571_10s_SECONDS_ENABLE           0x02
#define DP8571_SECONDS_ENABLE               0x04
#define DP8571_10e_SECONDS_ENABLE           0x08
#define DP8571_100e_SECONDS_ENABLE          0x10
#define DP8571_MILLISECONDS_ENABLE          0x20
#define DP8571_TIMER0_ENABLE                0x40
#define DP8571_TIMER1_ENABLE                0x80

/* interrupt control register 1 */

#define DP8571_SECOND_CMP_ENABLE            0x01
#define DP8571_MINUTE_CMP_ENABLE            0x02
#define DP8571_HOURS_CMP_ENABLE             0x04
#define DP8571_DOM_CMP_ENABLE               0x08
#define DP8571_MONTH_CMP_ENABLE             0x10
#define DP8571_DOY_CMP_ENABLE               0x20
#define DP8571_ALARM_INT_ENABLE             0x40
#define DP8571_PWR_FAIL_INT_ENABLE          0x80

/* miscellaneous */

#define DP8571_PAGE0_RAM_START              0x13
#define DP8571_PAGE1_RAM_START              0x01
#define DP8571_INT_MASK                     0xc0

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* INCn8571Timerh */
