/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCos_circh
#define __INCos_circh

/********************************************
os_circ.h

OSPF circuit structure definitions

copyright phase2 networks inc, 1994
all rights reserved

SID: 1.9
Revision History:


    1.9	96/03/29 09:54:56 root
	make ht,etc unsigned

    1.8	96/02/22 22:08:36 root
	add external api fncs

    1.7	96/02/06 22:29:28 root
	extern api mods

    1.6	95/11/21 08:14:04 jpp
	fix vlink first hop over unnum link

    1.5	95/11/09 09:44:40 root
	add mospf

    1.4	95/10/19 14:30:31 jpp
	mod VDEADINT

    1.3	95/10/03 14:25:19 root
	add ipoperstate param, vcauto, c_authfails

    1.2	95/05/02 14:18:57 root
	add tos

    1.1	94/12/04 09:37:55 root
	date and time created 94/12/04 09:37:55 by root

*********************************************/

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

typedef struct circuit{

    struct circuit      *c_fwd;     /* links */
    struct circuit      *c_bwd;     /* links */
    struct circuit      *c_hfwd;     /* hash links */
    struct area         *c_area;        /*ptr to area*/
    void                *c_intf;        /* client i/f struct*/
    int                  c_admst;       /* admin st */
    int                  c_state;       /* oper state*/
    int                  c_ipstate;     /* IP oper state*/
    int                  c_type;
    dword                c_cost;        /* for link */
#if ALL_METRICS
    /* non-default tos metrics */
    dword				c_costmon;	/* monetary cost */
    dword				c_costrel;	/* reliability */
    dword				c_costtp;		/* throughput */
    dword				c_costdel;	/* delay */
#endif
    IPNA                 c_ipaddr;  /*ip address */
    ipa                  c_drrtid;  /* dr rtrid */
    ipa                  c_dripa;       /* dr ip add */
    ipa                  c_bdr;     /* bdr ipadd */
    int                  c_drstate;     /* dr state */
    int                  c_dr_trig;     /* need to re-elect DR */
    struct neighbor      *c_nbr_fwd;    /* neigh list*/
    struct neighbor      *c_nbr_bwd;    /* neigh list*/
    unsigned int         c_ht;      /* hello time interval*/
    struct ospf_timer    *c_httimer;        /* hello timer */
    unsigned int         c_deadint; /* dead time */
    int                  c_rtrpri;  /* priority */
    int                  c_wait;        /* wait time*/
    struct ospf_timer    *c_waittimer;  /* wait timer */
    int                  c_rxmt;        /* rxmit time*/
    int				c_transdel;	/* iftransdelay */
    int				c_events;		/* counter */
    int				c_auth_fails;		/* counter */
                         /* virtual link params */
    ipa                  c_vcrtid;  /* router id */
    ipa                  c_vcdest;  /* id addr */
    ipa				c_vcnhop;	 /* physical next rtr */
    struct circuit	 *c_vcnc;		/* real next circ */
    struct area         *c_vcarea;  /* transit area */
	int				c_vcauto;		/* was autocreate ? */
					/* NBMA params */
    unsigned int		c_poll;
    int				c_pmult;	    /* hellos till poll*/
    authkey_t                c_auth;
    struct lsa_ack      *c_ack_fwd;    /* delayed lsa ack list */
    struct lsa_ack      *c_ack_bwd;    /* dalayed lsa ack list */
    struct nbma_dst	    *c_nbma_fwd;   /* nbma dest list */
    struct nbma_dst	    *c_nbma_bwd;   /* nbma dest list */
}OS_CIRC, *os_circ_pt;

/* struct for destinations on an NBMA circ */
typedef struct nbma_dst{
	struct nbma_dst	*n_fwd;		/* links */
	struct nbma_dst	*n_bwd;		
	ipa				n_ipa;		/* ip addr */
	int				n_candr;		/* dr eligible */
}NBMA_DST, *nbma_dst_pt;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#define IM_DR(c) ((c)->c_drstate == CIRC_IDR)
#define IM_BDR(c) ((c)->c_drstate == CIRC_IBACKUP_DR)

/*circuit physical states */
#define CIRC_DOWN       1       /* initial state */
#define CIRC_UP     2       /*alive or vc has route*/

/* interface states */
#define CIRC_IDOWN	1
#define CIRC_IWAIT 	3     /* we are waiting to elect DR */
#define CIRC_IPTPT	4	 /* ptpt up */
#define CIRC_IDR     5      /* we are the DR */
#define CIRC_IBACKUP_DR 6    /* we are the backup DR */
#define CIRC_IDR_OTHER 7     /* we are no kind of DR */

#define CIRC_STPTPT		4

/* dr election flags */
#define CIRC_NEED_DR        1
#define CIRC_FULL_NBR       2
#define CIRC_FULL_CHG       4

/* circuit events */
#define CEVENT_STATE        1


/* tos metrics */
#define OTOS_MON		2
#define OTOS_REL		4
#define OTOS_TP		8
#define OTOS_DEL		0x10

/* virtual circuit events */
#define VCEVENT_UP      1
#define VCEVENT_DOWN    2
#define VCEVENT_MOD     3
#define VCEVENT_CNCTD   4
#define VCEVENT_DISCNCTD    5


/* defaults */
#define CIRC_DEF_COST   	10
#define CIRC_DEF_PRI    	1
#define CIRC_DEF_HT     	10
#define CIRC_DEF_DEADINT 40
#define CIRC_DEF_VDEADINT 60
#define CIRC_DEF_RXMT  	5
#define CIRC_DEF_TRANS	1
#define CIRC_DEF_POLL	120

#define OSPF_MAX_PACKET_SIZE(cir) 1480

#endif  /* __INCos_circh */
