/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCos_dbdh
#define __INCos_dbdh

/********************************************
os_dbd.h

OSPF database description packet definitions

copyright phase2 networks inc. 1994
all rights reserved

SID: 1.2
Revision History:


    1.2	95/11/09 09:44:43 root
	add mospf

    1.1	94/12/04 09:37:57 root
	date and time created 94/12/04 09:37:57 by root

********************************************/
#ifndef OSPF_DBD_H
#define OSPF_DBD_H 1



typedef struct db_descript_packet db_descript_packet;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

/* data base description packet format */

#define DB_DESC_HEADER_SIZE 8
struct db_descript_packet
{
  byte dbd_filler[2];               /* 2 bytes of zeros (0) -- must be 0   */
  byte dbd_options;                  /* Options, see appendix A of rfc 1583 */
  byte dbd_flags;                    /* I,M, and MS flags                   */
  byte dbd_seq[4];             /* Sequence number                     */
  byte dbd_lstates[1]; /* List of Link States                 */
};

typedef struct db_packet {
	struct db_packet *db_fwd;     /* link these packets together */
	struct db_packet *db_bwd;
	int cur_size;		      /* how big is the packet so far? */
	ospf_packet *ospf_header;     /* pointer to ospf header within packet*/
	db_descript_packet *dbd_header; /* ptr to dbdesc header within packet*/
	lsa_pt cur_lsa;		       	/* ptr to next lsa within packet */
	ibd_pt the_packet; /* the packet, proper */
} DB_packet;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

/*  MACROS to parse data base description packets */

/* we assume that i, m, and ms, have values 0/1 only */
#define DB_MAKE_FLAGS(i,m,ms) ( ((i)<<2) | ((m)<<1) | (ms))

#define DB_FILLER(packet) \
 ( *(uint_16 *)((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE)->dbd_filler) )

#define DB_OPTIONS(packet) \
 ( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_options ))
#define DB_OPTIONS_T(packet) \
 ( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_options ) & 0x01)
#define DB_OPTIONS_E(packet) \
 (( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_options )>>1)& 0x01)

#define DB_OPTIONS_MC(packet) \
 (( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_options )& MC_OPT)?1:0)

#define DB_I_BIT(packet) \
 (( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_flags)&0x04)>>2 )

#define DB_M_BIT(packet) \
 (( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_flags)&0x02)>>1 )

#define DB_MS_BIT(packet) \
 ( (((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_flags)&0x01 )

#define DB_SEQUENCE_NUM(packet) \
 ( n2u32(((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE))->dbd_seq) )

#define DB_CONTENT_LENGTH(packet) (OSPF_PACKET_LENGTH(packet)-OSPF_HEADER_SIZE-DB_DESC_HEADER_SIZE)

#define DB_LS_HEADER(packet) \
 ((db_descript_packet *)((byte*)(packet) + OSPF_HEADER_SIZE+DB_DESC_HEADER_SIZE)) 

#define DB_FIRST_LSA(packet) \
 ( OSPF_PACKET_LENGTH(packet) > OSPF_HEADER_SIZE+DB_DESC_HEADER_SIZE ? \
 ((LSA *)((byte*)(packet) + OSPF_HEADER_SIZE+DB_DESC_HEADER_SIZE)) : \
  (LSA*)NULL) 

#define DB_NEXT_LSA(packet, lsa) \
 ( OSPF_PAST_END(packet,lsa,LSA_HEADER_SIZE) ? \
 NULL : \
 ((LSA*)((byte*)lsa+LSA_HEADER_SIZE)) )

#define LSA_TYPE(lsa) ((lsa)->ls_type)
#define LSA_LSID(lsa) (n2ipa((lsa)->ls_id))
#define LSA_ADVRTR(lsa) (n2ipa((lsa)->ls_artr))
#define LSA_AGE(lsa) (n2u16((lsa)->ls_age))

#define LSA_HEADER_SIZE LSA_HLEN
#endif
#endif /* __INCos_dbdh */
