/* Copyright 1990-1992 Wind River Systems, Inc. */
/*
modification history
-------------------------
01a,30jun97,rjc added pragma align stuff
*/

#ifndef __INCos_neighh
#define __INCos_neighh

/***********************************************
os_neigh.h

Definitions for OSPF neighbor structure

copyright phase2 networks inc, 1994
all rights reserved

SID: 1.2
Revision History:


    1.2	95/11/09 09:45:14 root
	add mospf

    1.1	94/12/04 09:38:28 root
	date and time created 94/12/04 09:38:28 by root

************************************************/
#ifndef NEIGHBOR_H
#define NEIGHBOR_H

/*******************************************************************
 *
 * declarations for the neighbor data structure
 *
 *******************************************************************/

typedef enum {
  NEIGHBOR_NULL_STATE,
  NEIGHBOR_DOWN_STATE, NEIGHBOR_ATTEMPT_STATE,
  NEIGHBOR_INIT_STATE, NEIGHBOR_2WAY_STATE,
  NEIGHBOR_EX_START_STATE,
  NEIGHBOR_EXCHANGE_STATE, NEIGHBOR_LOADING_STATE ,
  NEIGHBOR_FULL_STATE
} ospf_neighbor_states;
#define NS_EXCHANGE NEIGHBOR_EXCHANGE_STATE
#define NS_LOADING NEIGHBOR_LOADING_STATE

typedef enum {
  /* NEIGHBOR EVENTS */ 
  HELLO_RECEIVED_EVENT,
  START_EVENT, TWO_WAY_EVENT,
  NEGOTIATION_DONE_EVENT, EXCHANGE_DONE_EVENT, BAD_LS_REQ_EVENT,
  LOADING_DONE_EVENT, ADJ_OK_EVENT, SEQ_NUM_MISMATCH_EVENT,
  ONE_WAY_EVENT, KILL_NBR_EVENT, INACTIVITY_TIMER_EVENT, LL_DOWN_EVENT,
  /* INTERFACE EVENTS */
  INTERFACE_UP_EVENT, WAIT_TIMER_EVENT, BACKUP_SEEN_EVENT,
  NEIGHBOR_CHANGED_EVENT, LOOP_IND_EVENT, UNLOOP_IND_EVENT, 
  INTERFACE_DOWN_EVENT
} ospf_events;

typedef enum { MASTER, SLAVE } master_slave_type;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 1                 /* tell gcc960 not to optimize alignments */
#endif  /* CPU_FAMILY==I960 */

typedef struct neighbor {
  struct neighbor	*nb_fwd;		/* links */
  struct neighbor	*nb_bwd;		/* links */
  OS_CIRC *interface;
  ospf_neighbor_states nb_state; /* current state of our conversation */
  ipa nb_rtid;			/* router id of the neighbor */
  ipa nb_ipa;			/* IP address of the neighoring router */
  otimer_pt inactivity_timer;	/* the inactivity timer */
  otimer_pt rxmt_timer;		/* timer for retransmitting LSAs */
  int rxmt_timer_is_set;	/* flag: whether the timer is active */
  master_slave_type master_slave; /* are we master or slave inDB exchange */
  dword dd_number;		/* sequence number in DD exchange */
  byte router_priority;  /* neighbor router's priority (from Hello pkt)*/
  byte options_e;	  /* neighbor's E option (from Hello Pkt)  */
  byte options_t;         /* neighbor's T option (from Hello Pkt) */
  byte options_mc;         /* neighbor's MC option (from Hello Pkt) */
  ipa designated_router;  /* neighbor's idea of DR (from Hello Pkt)  */
  ipa backup_router;      /* neigbors's Idea of BackupDR (from Hello pkt) */
  struct retrans_node *retrans_list;     /* LinkState retransmit list */
  struct retrans_node *retrans_listb;     /* LinkState retransmit list */
   DB_packet *ls_summary_list; /* snapshot of LS database, for exchange */
   DB_packet *db_previous_packet; /* packet to retransmit in exchange */
   struct db_req_node *ls_req_list; /* LinkState request list */
   struct db_req_node *ls_req_listb; /* LinkState request list */
   int nb_events;        /* count of state changes */
} NBR, Neighbor, *nbr_pt;

#if ((CPU_FAMILY==I960) && (defined __GNUC__))
#pragma align 0                 /* turn off alignment requirement */
#endif  /* CPU_FAMILY==I960 */

#define NEIGHBORS_AREA(n) ((n)->interface->c_area)
#define IS_POINT_TO_POINT(intf) ( (intf)->c_type == CIRC_PTPT)
#define IS_VIRTUAL_LINK(intf) ( (intf)->c_type == CIRC_VLNK)

#define IS_STUB_AREA(a) ((a)->a_stub)
#define IS_DESIGNATED_ROUTER(n) ((n)->nb_ipa == (n)->interface->c_dripa)
#define ospf_do_seq_num_mismatch(n) ospf_do_bad_ls_req(n)

#define neighbor_interface( neighbor ) \
        ( (neighbor)->interface )
#endif

#endif /* __INCos_neighh */
