/** Copyright (c) 1992  Mentat Inc.
 ** micommon.h 4.1, last change 8/31/93
 **/

/*   
modification history
--------------------
01a,30nov98,sgv  Removed definition of offsetof and included stddef.h
*/

#ifndef	_MICOMMON_
#define	_MICOMMON_

#ifndef WRS
#ifndef lint
static char	micommon_h_sccsid[] = "@(#)micommon.h	4.1";
#endif
#endif /* WRS */

#ifndef __INCstddefh
#include "stddef.h"
#endif

/*
 * micommon.h
 *	This file contains all typedef's, structures, defines, etc. which are used throughout
 *	Mentat software products.  Definitions here are used both for kernel and user code.
 *	Definitions specific to kernel code are in mikernel.h; for user code and libraries
 *	in miuser.h.  Definitions here are not expected to change on different systems.
 *	See led.h for port specific defintions.
 *
 *	ASSUMPTIONS: 
 *	- This file is included by mikernel.h or miuser.h immediately
 *	  after led.h in all MPS code.  KERNEL is defined if included
 *	  from mikernel.h; however, *only* definitions valid for both
 *	  kernel and user code are placed here.
 *
 */

typedef	boolean_t	(*pfb_t)();	/* not 'boolean' */
typedef	int		(*pfi_t)();
typedef	void		(*pfv_t)();
typedef	pfi_t		(*pfpfi_t)();

#define	MAX_INT		((int)(MAX_UINT >> 1))
#define	MAX_LONG	((long)(MAX_ULONG >> 1))
#define	MAX_SHORT	((short)(MAX_USHORT >> 1))
#define	MAX_UINT	((unsigned int)~0)
#define	MAX_ULONG	((unsigned long)~0)
#define	MAX_USHORT	((unsigned short)~0)
#define	MIN_INT		(~MAX_INT)
#define	MIN_LONG	(~MAX_LONG)
#define	MIN_SHORT	(~MAX_SHORT)

/*
 * ------------- Useful definitions found throughout MPS code --------------
 */
#define A_CNT(arr)	(sizeof(arr)/sizeof(arr[0]))
#define	A_END(arr)	(&arr[A_CNT(arr)])
#define	A_LAST(arr)	(&arr[A_CNT(arr)-1])
#define ERR		(-1)
#ifndef	MAX
#define MAX(x1,x2)	((x1) >= (x2) ? (x1) : (x2))
#endif
#ifndef	MIN
#define MIN(x1,x2)	((x1) <= (x2) ? (x1) : (x2))
#endif

#define GET_TYPE_FROM_FLAGS(flags)	(((flags) >> 8) & 0xFF)
#define	SET_TYPE_IN_FLAGS(flags, type)	(flags = ((flags) & ~0xFF00) | (((type) & 0xFF) << 8))

#define	nilp(t)		((t *)0)
#define	nil(t)		((t)0)
#define	noop
#define fallthru
#define	false		((boolean)0)
#define	true		((boolean)1)

#define reg		register

#ifndef	staticf
#define	staticf		static
#endif

#define	U8(x)		((unsigned char)(x))
#define	INT_SIGN_BIT	(0x80000000L)
#define	LONG_SIGN_BIT	(0x80000000L)

#ifndef	OK_32PTR
#define	OK_32PTR(p)	(!((u32)(p) & 0x3))
#endif
#ifndef	OK_16PTR
#define	OK_16PTR(p)	(!((u32)(p) & 0x1))
#endif

#ifndef sizeof_fld
#define	sizeof_fld(t, f)	(sizeof(nilp(t)->f))
#endif

#define	newa(t,cnt)	((t *)calloc((size_t)(cnt), sizeof(t)))
#define getarg(ac,av)	(optind < ac ? av[optind++] : nilp(char))

#define	BE32_EQL(a,b)	(((u8 *)a)[0] == ((u8 *)b)[0]  && ((u8 *)a)[1] == ((u8 *)b)[1]  \
			&& ((u8 *)a)[2] == ((u8 *)b)[2]  && ((u8 *)a)[3] == ((u8 *)b)[3])
#define	BE16_EQL(a,b)	(((u8 *)a)[0] == ((u8 *)b)[0]  && ((u8 *)a)[1] == ((u8 *)b)[1])
#define	BE16_TO_U16(a)	((((u16)((u8 *)a)[0] << (u16)8) | ((u16)((u8 *)a)[1] & 0xFF)) & (u16)0xFFFF)
#define	BE32_TO_U32(a)	((((u32)((u8 *)a)[0] & 0xFF) << (u32)24) | (((u32)((u8 *)a)[1] & 0xFF)  \
			<< (u32)16) | (((u32)((u8 *)a)[2] & 0xFF) << (u32)8)  | ((u32)((u8 *)a)[3] & 0xFF))
#define	U16_TO_BE16(u,a) ((((u8 *)a)[0] = (u8)((u) >> 8)), (((u8 *)a)[1] = (u8)(u)))
#define	U32_TO_BE32(u,a) ((((u8 *)a)[0] = (u8)((u) >> 24)), (((u8 *)a)[1] = (u8)((u) >> 16)), \
			(((u8 *)a)[2] = (u8)((u) >> 8)),(((u8 *)a)[3] = (u8)(u)))


#ifdef	MI_BIG_ENDIAN

#ifndef	ABE32_TO_U32
#define	ABE32_TO_U32(p)		(*((u32 *)p))
#endif

#ifndef	ABE16_TO_U16
#define	ABE16_TO_U16(p)		(*((u16 *)p))
#endif

#ifndef	U16_TO_ABE16
#define	U16_TO_ABE16(u,p)	(*((u16 *)p) = (u))
#endif

#ifndef	U32_TO_ABE16
#define	U32_TO_ABE16(u,p)	U16_TO_ABE16(u,p)
#endif

#ifndef	UA32_TO_U32
#define	UA32_TO_U32(p,u)	((u) = (((u32)((u8 *)p)[0] << 24) | ((u32)((u8 *)p)[1] << 16) \
					| ((u32)((u8 *)p)[2] << 8) | (u32)((u8 *)p)[3]))
#endif

#ifndef	U32_TO_ABE32
#define	U32_TO_ABE32(u,p)	(*((u32 *)p) = (u))
#endif

#else	/* little endian machines */

#ifndef	ABE16_TO_U16
#define	ABE16_TO_U16(p)		BE16_TO_U16(p)
#endif

#ifndef	ABE32_TO_U32
#define	ABE32_TO_U32(p)		BE32_TO_U32(p)
#endif

#ifndef	U16_TO_ABE16
#define	U16_TO_ABE16(u,p)	U16_TO_BE16(u,p)
#endif

#ifndef	U32_TO_ABE16
#define	U32_TO_ABE16(u,p)	U16_TO_ABE16(u,p)
#endif

#ifndef	U32_TO_ABE32
#define	U32_TO_ABE32(u,p)	U32_TO_BE32(u,p)
#endif

#ifndef	UA32_TO_U32
#define	UA32_TO_U32(p,u)	((u) = (((u32)((u8 *)p)[3] << 24) | ((u32)((u8 *)p)[2] << 16) \
					| ((u32)((u8 *)p)[1] << 8) | (u32)((u8 *)p)[0]))
#endif

#endif		/* not MI_BIG_ENDIAN */

/*
 * Include definition of _IO() macro and all Mentat ioctl command prefixes.
 * Be sure to examine miioccom.h for possible ioctl command code collisions
 * with values on your system.
 */
#include <miioccom.h>

/*
 * Pick up environment-specific definitions of module and device names, etc.
 */
#include <modnames.h>

#endif		/* _MICOMMON_ */
